<?php
/**
 * Template part for displaying posts with the "metro" display
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Phase
 * @version 1.2.8
 */
extract( wp_parse_args( $template_args, array(
	'layout' => '',
	'overlay_color' => 'auto',
	'overlay_custom_color' => '',
	'overlay_opacity' => 88,
	'overlay_text_color' => '',
	'overlay_text_custom_color' => '',
) ) );
$text_style = '';

if ( function_exists( 'wvc_convert_color_class_to_hex_value' ) && $overlay_text_color && 'overlay' === $layout ) {
	$text_color = wvc_convert_color_class_to_hex_value( $overlay_text_color, $overlay_text_custom_color );
	if ( $text_color ) {
		$text_style .= 'color:' . phase_sanitize_color( $text_color ) . ';';
	}
}

$dominant_color = phase_get_image_dominant_color( get_post_thumbnail_id() );
$actual_overlay_color = '';

if ( 'auto' === $overlay_color ) {

	$actual_overlay_color = $dominant_color;

} elseif ( function_exists( 'wvc_convert_color_class_to_hex_value' ) ) {
	$actual_overlay_color = wvc_convert_color_class_to_hex_value( $overlay_color, $overlay_custom_color );
}

$overlay_tone_class = 'overlay-tone-' . phase_get_color_tone( $actual_overlay_color );
$featured = get_post_meta( get_the_ID(), '_post_featured', true );
?>
<figure <?php phase_post_attr( array( $overlay_tone_class ) ); ?>>
	<div class="entry-box">
		<div class="entry-outer">
			<div class="entry-container">
				<a class="entry-link-mask" href="<?php the_permalink(); ?>"></a>
				<div class="entry-image">
					<div class="entry-cover">
						<?php
							$metro_size = apply_filters( 'phase_metro_thumbnail_size', 'phase-photo' );

							if ( $featured || phase_is_latest_post( 'artist' ) ) {
								$metro_size = 'large';
							}

							$size = ( phase_is_gif( get_post_thumbnail_id() ) ) ? 'full' : $metro_size;

							echo phase_background_img( array( 'background_img_size' => $size, ) );
							remove_filter( 'phase_metro_thumbnail_size', 10, 1 );
						?>
					</div><!-- entry-cover -->
				</div>
				<div class="entry-inner">
					<div class="entry-inner-padding">
						<?php
							
							if ( $dominant_color && 'auto' === $overlay_color ) {
								$overlay_custom_color = $dominant_color;
							}

							/**
							 * Overlay
							 */
							echo phase_background_overlay( array(
								'overlay_color' => $overlay_color,
								'overlay_custom_color' => $overlay_custom_color,
								'overlay_opacity' => $overlay_opacity, )
							);
						?>
						<div style="<?php echo phase_esc_style_attr( $text_style ); ?>" class="entry-summary">
							<h3 class="entry-title"><a href="<?php the_permalink(); ?>" style="<?php echo phase_esc_style_attr( $text_style ); ?>"><?php the_title(); ?></a></h3>
							<div class="entry-taxonomy">
								<?php echo get_the_term_list( get_the_ID(), 'artist_genre', '', ' <span class="artist-taxonomy-separator">/</span> ', '' ); ?>
							</div><!-- .entry-taxonomy -->
						</div><!--  .entry-summary  -->
					</div><!-- .entry-inner-padding -->
				</div><!-- .entry-inner -->
			</div><!-- .entry-container -->
		</div><!-- .entry-outer -->
	</div><!-- .entry-box -->
</figure><!-- #post-## -->