<?php
/**
 * The category filter for artist posts
 *
 * @package WordPress
 * @subpackage Phase
 * @version 1.2.8
 */

// Get template vars
extract( wp_parse_args( $filter_args, array(
	'artist_genre_include' => '',
	'artist_genre_exclude' => '',
	'artist_category_filter_text_alignment' => 'center',
) ) );

/* Term query args */
$terms_args = array(
	'taxonomy' => 'artist_genre',
	'hide_empty' => true,
);

/* If artist types are defined, add them to the arguments */
if ( $artist_genre_include ) {

	$artist_genres_ids = array();
	$artist_genres_array = phase_list_to_array( $artist_genre_include );

	if ( array() !== $artist_genres_array ) {
		foreach ( $artist_genres_array as $slug ) {

			$term = get_term_by( 'slug', $slug, 'artist_genre' );

			if ( is_object( $term ) ) {
				$artist_genres_ids[] = $term->term_id;
			}
		}
	}

	$terms_args['include'] = $artist_genres_ids;
}

/* If exlucded artist types are defined, add them to the arguments */
if ( $artist_genre_exclude ) {

	$artist_genres_ids = array();
	$artist_genres_array = phase_list_to_array( $artist_genre_exclude );

	if ( array() !== $artist_genres_array ) {
		foreach ( $artist_genres_array as $slug ) {

			$term = get_term_by( 'slug', $slug, 'artist_genre' );

			if ( is_object( $term ) ) {
				$artist_genres_ids[] = $term->term_id;
			}
		}
	}

	$terms_args['exclude'] = $artist_genres_ids;
}

// Get terms
$terms = get_terms( $terms_args );

if ( array() === $terms ) {
	return;
}

$filter_class = 'category-filter category-filter-artist';

$filter_class .= " category-filter-text-align-$artist_category_filter_text_alignment";

$artists_url = ( phase_get_artists_url() ) ? phase_get_artists_url() : home_url();

$all_active_class = ( ! is_tax( 'artist_genre' ) ) ? 'active' : '';
?>
<div class="<?php echo phase_sanitize_html_classes( $filter_class ); ?>">
	<ul>
		<li><a class="filter-link <?php echo esc_attr( $all_active_class ); ?>" href="<?php echo esc_url( $artists_url  ); ?>" data-filter="artist"><?php esc_html_e( 'All', 'phase' ) ?></a></li>
		<?php foreach ( $terms as $term ) :
			$term_active_class = ( $term->slug === get_query_var( 'artist_genre' ) ) ? 'active' : '';
		?>
			<li>
				<a class="filter-link <?php echo esc_attr( $term_active_class ); ?>" data-filter="artist_genre-<?php echo sanitize_title( $term->slug ); ?>" href="<?php echo esc_url( get_term_link( $term ) ); ?>"><?php echo sanitize_text_field( $term->name ); ?></a>
			</li>
		<?php endforeach; ?>
	</ul>
</div><!-- .category-filter -->