<?php
/**
 * Template part for displaying posts with the "modern masonry" display
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Phase
 * @version 1.2.8
 */
$has_media = false;
$slideshow = false;

extract( wp_parse_args( $template_args, array(
	'post_display_elements' => 'show_thumbnail,show_date,show_text,show_author,show_category',
) ) );

$post_display_elements = phase_list_to_array( $post_display_elements );
$show_thumbnail = ( in_array( 'show_thumbnail', $post_display_elements ) );
$show_date = ( in_array( 'show_date', $post_display_elements ) );
$show_text = ( in_array( 'show_text', $post_display_elements ) );
$show_author = ( in_array( 'show_author', $post_display_elements ) );
$show_category = ( in_array( 'show_category', $post_display_elements ) );
$show_tags = ( in_array( 'show_tags', $post_display_elements ) );
$show_extra_meta = ( in_array( 'show_extra_meta', $post_display_elements ) );

$format = get_post_format();

?>
<article <?php phase_post_attr(); ?>>
	<a href="<?php the_permalink(); ?>" class="entry-link-mask"></a>
	<div class="entry-box">
		<div class="entry-container">
			<?php
				/**
				 * Image post format
				 */
				if ( 'image' === $format ) {

					if ( phase_is_instagram_post() ) {

						/**
						 * Instagram Image
						 */

						echo phase_get_instagram_image();

						$has_media = true;

					} elseif ( phase_has_post_thumbnail() ) {

						/**
						 * Image parallax
						 */
						echo phase_background_img( array(
							'background_img' => 'large',
							'background_img' => phase_get_featured_image_id(),
							//'background_effect' => apply_filters( 'phase_masonry_modern_image_format_effect', 'parallax' ),
							'placeholder_fallback' => true,
						) );

						$has_media = true;
					}

				} elseif ( 'video' === $format ) {

					if ( phase_background_video() ) { // if we can get a video background

						echo phase_background_video();

						$has_media = true;

					} elseif ( wp_oembed_get( phase_get_first_video_url() ) ) {

						echo wp_oembed_get( phase_get_first_video_url() );

						$has_media = true;
					}

				} elseif ( 'gallery' === $format && phase_background_slideshow() ) {

					echo phase_background_slideshow( array(
						'slideshow_image_size' => 'large',
						'slideshow_img_count' => 3,
					) );

					$has_media = true;
					$slideshow = true;

				} elseif ( 'audio' === $format && phase_featured_media() ) {

					echo phase_featured_media();

					$has_media = true;

				} elseif ( phase_is_short_post_format() ) {

					$has_media = true;

					if ( preg_match( '/twitter/', phase_get_first_url() ) ) {

						/**
						 * Embed Tweet
						 */
						echo wp_oembed_get( phase_get_first_url() );

					} else {
						?>
						<div class="entry-image">
							<?php
								echo phase_background_img( array(
									'background_img_size' => 'medium',
									'placeholder_fallback' => true,
								) );
							?>
						</div><!-- .entry-image -->
						<div class="entry-masonry_modern-overlay"></div>
						<?php
					}

				}
			?>
			<?php if ( phase_has_post_thumbnail() && '' == $format ) : ?>
				<div class="entry-image">
					<?php if ( $show_category ) : ?>
						<a class="category-label" href="<?php echo phase_get_first_category_url(); ?>"><?php echo phase_get_first_category(); ?></a>
					<?php endif; ?>
					<?php
						if ( is_sticky() && ! is_paged() ) {
							echo '<span class="sticky-post" title="' . esc_attr( __( 'Featured', 'phase' ) ) . '"></span>';
						}
					?>
					<?php the_post_thumbnail( 'phase-masonry' ); ?>
				</div><!-- .entry-image -->
			<?php endif; ?>

			<?php if ( 'aside' === $format || 'status' === $format && ! preg_match( '/twitter/', phase_get_first_url() ) ) : ?>

				<div class="entry-summary">
					<div class="entry-summary-inner">
						<div class="author-meta">
							<?php
								/**
								 * Avatar
								 */
								echo get_avatar( get_the_author_meta( 'user_email' ), 20 );
								printf(
									'<span class="author vcard">by %s</span>',
									get_the_author()
								);
							?>
						</div>
						<h2 class="entry-title"><?php echo phase_sample( get_the_content(), 33 ); ?></h2>
					</div><!-- .entry-summary-inner -->
				</div><!-- .entry-summary -->

			<?php elseif ( 'quote' === $format && ! preg_match( '/twitter/', phase_get_first_url() ) ) : ?>

				<div class="entry-summary">
					<div class="entry-summary-inner">
						<h2 class="entry-title">
							<?php echo phase_get_first_quote(); ?>
						</h2>
					</div><!-- .entry-summary-inner -->
				</div><!-- .entry-summary -->

			<?php elseif ( 'link' === $format ) : ?>

				<div class="entry-summary">
					<div class="entry-summary-inner">
						<h2 class="entry-title">
							<a target="_blank" href="<?php echo phase_get_first_url(); ?>" class="entry-link">
								<?php the_title(); ?>
							</a>
						</h2>
					</div><!-- .entry-summary-inner -->
				</div><!-- .entry-summary -->

			<?php elseif (
				'audio' === $format && phase_is_single_audio_player()
			) : ?>

				<div class="entry-masonry_modern-overlay"></div>
				<?php if ( $show_category ) : ?>
					<a class="category-label" href="<?php echo phase_get_first_category_url(); ?>"><?php echo phase_get_first_category(); ?></a>
				<?php endif; ?>
				<div class="entry-summary">
					<div class="entry-summary-inner">
						<span class="entry-date">
							<?php phase_entry_date(); ?>
						</span>
						<?php the_title( '<h2 class="entry-title">', '</h2>' ); ?>
						<span class="view-more">
							<?php echo apply_filters( 'phase_view_post_text', esc_html__( 'View post', 'phase' ) ); ?>
						</span>
					</div><!-- .entry-summary-inner -->
				</div><!-- .entry-summary -->

			<?php elseif ( 'image' === $format && phase_has_post_thumbnail() && ! preg_match( '/instagr/', phase_get_first_url() ) ) : ?>

				<div class="entry-masonry_modern-overlay"></div>
				<?php if ( $show_category ) : ?>
					<a class="category-label" href="<?php echo phase_get_first_category_url(); ?>"><?php echo phase_get_first_category(); ?></a>
				<?php endif; ?>
				<div class="entry-summary">
					<div class="entry-summary-inner">
						<span class="entry-date">
							<?php phase_entry_date(); ?>
						</span>
						<?php the_title( '<h2 class="entry-title">', '</h2>' ); ?>
						<span class="view-more">
							<?php echo apply_filters( 'phase_view_post_text', esc_html__( 'View post', 'phase' ) ); ?>
						</span>
					</div><!-- .entry-summary-inner -->
				</div><!-- .entry-summary -->

			<?php elseif ( 'video' === $format && phase_background_video() ) : ?>

				<div class="entry-masonry_modern-overlay"></div>
				<?php if ( $show_category ) : ?>
					<a class="category-label" href="<?php echo phase_get_first_category_url(); ?>"><?php echo phase_get_first_category(); ?></a>
				<?php endif; ?>
				<div class="entry-summary">
					<div class="entry-summary-inner">
						<span class="entry-date">
							<?php phase_entry_date(); ?>
						</span>
						<?php the_title( '<h2 class="entry-title">', '</h2>' ); ?>
						<span class="view-more">
							<?php echo apply_filters( 'phase_view_post_text', esc_html__( 'View post', 'phase' ) ); ?>
						</span>
					</div><!-- .entry-summary-inner -->
				</div><!-- .entry-summary -->

			<?php elseif ( 'gallery' === $format ) : ?>

				<div class="entry-masonry_modern-overlay"></div>
				<?php if ( $show_category ) : ?>
					<a class="category-label" href="<?php echo phase_get_first_category_url(); ?>"><?php echo phase_get_first_category(); ?></a>
				<?php endif; ?>
				<?php if ( $slideshow ) : ?>
					<div class="slideshow-gallery-direction-nav">
						<a href="#" class="slideshow-gallery-direction-nav-prev">
							<span class="slideshow-gallery-direction-nav-prev-icon"></span>
						</a>
						<a href="#" class="slideshow-gallery-direction-nav-next">
							<span class="slideshow-gallery-direction-nav-next-icon"></span>
						</a>
					</div>
				<?php endif; ?>
				<div class="entry-summary">
					<div class="entry-summary-inner">
						<span class="entry-date">
							<?php phase_entry_date(); ?>
						</span>
						<?php the_title( '<h2 class="entry-title">', '</h2>' ); ?>
						<span class="view-more">
							<?php echo apply_filters( 'phase_view_post_text', esc_html__( 'View post', 'phase' ) ); ?>
						</span>
					</div><!-- .entry-summary-inner -->
				</div><!-- .entry-summary -->

			<?php elseif ( '' == $format || ! $has_media ) : // standard ?>

				<div class="entry-summary">
					<div class="entry-summary-inner">
						<span class="entry-date">
							<?php phase_entry_date(); ?>
						</span>
						<h2 class="entry-title">
							<?php if ( ! phase_has_post_thumbnail() ) : ?>
								<?php
									if ( is_sticky() && ! is_paged() ) {
										echo '<span class="sticky-post" title="' . esc_html__( 'Featured', 'phase' ) . '"></span>';
									}
								?>
							<?php endif; ?>
							<?php the_title(); ?>
						</h2>
						<?php if ( $show_text ) : ?>
							<div class="entry-excerpt">
								<?php do_action( 'phase_post_masonry_excerpt', $post_excerpt_length ); ?>
							</div><!-- .entry-excerpt -->
						<?php endif; ?>
						<?php if ( $show_category && ( ! phase_has_post_thumbnail() || ! $show_thumbnail ) ) : ?>
						<div class="entry-category-list">
							<?php echo get_the_term_list( get_the_ID(), 'category', esc_html__( 'In', 'phase' ) . ' ', esc_html__( ', ', 'phase' ), '' ) ?>

						</div>
					<?php endif; ?>
					</div><!-- .entry-summary-inner -->
					<?php if ( $show_author || $show_tags || $show_extra_meta || phase_edit_post_link( false ) ) : ?>
						<div class="entry-meta">
							<?php if ( $show_author ) : ?>
								<?php phase_get_author_avatar(); ?>
							<?php endif; ?>
							<?php if ( $show_tags ) : ?>
								<?php phase_entry_tags(); ?>
							<?php endif; ?>
							<?php if ( $show_extra_meta ) : ?>
								<?php phase_get_extra_meta(); ?>
							<?php endif; ?>
							<?php phase_edit_post_link(); ?>
						</div><!-- .entry-meta -->
					<?php endif; ?>
				</div><!-- .entry-summary -->
			<?php endif; ?>
		</div><!-- .entry-container -->
	</div><!-- .entry-box -->
</article><!-- #post-## -->