<?php
/**
 * Template part for displaying the post metro modern layout
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Phase
 * @version 1.2.8
 */
$show_caption = true;

extract( wp_parse_args( $template_args, array(
	'post_excerpt_length' => 'shorten',
	'post_display_elements' => 'show_thumbnail,show_date,show_category',
) ) );

$post_display_elements = phase_list_to_array( $post_display_elements );
$show_thumbnail = ( in_array( 'show_thumbnail', $post_display_elements ) );
$show_date = ( in_array( 'show_date', $post_display_elements ) );
$show_text = ( in_array( 'show_text', $post_display_elements ) );
$show_author = ( in_array( 'show_author', $post_display_elements ) );
$show_category = ( in_array( 'show_category', $post_display_elements ) );
$show_tags = ( in_array( 'show_tags', $post_display_elements ) );
$show_extra_meta = ( in_array( 'show_extra_meta', $post_display_elements ) );

$format = get_post_format();

$the_permalink = ( 'link' === $format && phase_get_first_url() ) ? phase_get_first_url() : get_the_permalink();

$target = ( 'link' === $format && phase_get_first_url() ) ? '_blank' : '_self';

$featured = get_post_meta( get_the_ID(), '_post_featured', true );
?>
<article <?php phase_post_attr(); ?>>
	<div class="entry-box">
		<a class="entry-link-mask" href="<?php echo esc_url( $the_permalink ); ?>" target="<?php echo esc_attr( $target ); ?>"></a>
		<div class="entry-outer">
			<div class="entry-container">
				
				<?php if ( 'image' === $format ) {
					
					if ( $show_category ) : ?>
						<a class="category-label" href="<?php echo phase_get_first_category_url(); ?>"><?php echo phase_get_first_category(); ?></a>
					<?php endif;

					if ( phase_is_instagram_post() ) {
						echo phase_get_instagram_image();
					} else {
						?>
						<div class="entry-image">
							<div class="entry-cover">
								<?php
									$metro_size = apply_filters( 'phase_metro_thumbnail_size', 'phase-photo' );

									if ( $featured || phase_is_latest_post() ) {
											$metro_size = 'large';
										}

									$size = ( phase_is_gif( get_post_thumbnail_id() ) ) ? 'full' : $metro_size;
									echo phase_background_img( array( 'background_img_size' => $size, ) );
								?>
							</div><!-- entry-cover -->
						</div><!-- entry-image -->
						<?php
					}

					$show_caption = false;

				} elseif ( 'gallery' === $format && phase_background_slideshow() ) {

					if ( $show_category ) : ?>
						<a class="category-label" href="<?php echo phase_get_first_category_url(); ?>"><?php echo phase_get_first_category(); ?></a>
					<?php endif;

					echo phase_background_slideshow( array(
						'slideshow_image_size' => 'phase-photo',
						'slideshow_img_count' => 3,
					) );

					?>
					<div class="slideshow-gallery-direction-nav">
						<a href="#" class="slideshow-gallery-direction-nav-prev">
							<span class="slideshow-gallery-direction-nav-prev-icon"></span>
						</a>
						<a href="#" class="slideshow-gallery-direction-nav-next">
							<span class="slideshow-gallery-direction-nav-next-icon"></span>
						</a>
					</div>
					<?php

					$show_caption = false;

				} elseif ( 'video' === $format ) {

					if ( $show_category ) : ?>
						<a class="category-label" href="<?php echo phase_get_first_category_url(); ?>"><?php echo phase_get_first_category(); ?></a>
					<?php endif;

					if ( phase_background_video() ) { // if we can get a video background

						echo phase_background_video();

						$show_caption = false;

					} else {

						?>
						<div class="entry-cover">
							<?php
								echo phase_background_img( array(
									'background_img_size' => 'medium',
									'placeholder_fallback' => true,
								) );
							?>
						</div><!-- entry-cover -->
						<div class="entry-metro_modern-overlay"></div>
						<?php

						$show_caption = false;
					}

					?>
					<div class="entry-metro_modern-overlay"></div>
					<a href="<?php echo phase_get_first_video_url() ?>" class="lightbox-video">
						<span class="video-play-button"></span>
					</a>
					<span class="video-title"><?php the_title(); ?></span>
					<?php

				} elseif ( 'audio' === $format && phase_featured_media() ) {

					if ( $show_category ) : ?>
						<a class="category-label" href="<?php echo phase_get_first_category_url(); ?>"><?php echo phase_get_first_category(); ?></a>
					<?php endif;

					if ( phase_is_single_audio_player() ) {
						$show_caption = false;
						?>
						<div class="entry-image">
							<div class="entry-cover">
								<?php
									echo phase_background_img( array(
										'background_img_size' => 'medium',
										'placeholder_fallback' => true,
									) );
								?>
							</div><!-- entry-cover -->
						</div><!-- entry-image -->
						<div class="entry-metro_modern-overlay"></div>
						<div class="entry-summary">
							<div class="entry-summary-inner">
								<h2 class="entry-title">
									<?php echo the_title(); ?>
								</h2>
							</div><!-- .entry-summary-inner -->
						</div><!-- .entry-summary -->
						<?php
					}

					echo phase_featured_media();

				} elseif ( 'aside' === $format || 'status' === $format ) {
					$show_caption = false;
					?>
					<div class="entry-cover">
						<?php
							echo phase_background_img( array(
								'background_img_size' => 'medium',
								'placeholder_fallback' => true,
							) );
						?>
					</div><!-- entry-cover -->
					<div class="entry-metro_modern-overlay"></div>
					<div class="entry-metro_modern-overlay-gradient"></div>
					<div class="entry-summary">
						<div class="entry-summary-inner">
							<div class="author-meta">
								<?php
									/**
									 * Avatar
									 */
									echo get_avatar( get_the_author_meta( 'user_email' ), 20 );
									printf(
										'<span class="author vcard">by %s</span>',
										get_the_author()
									);
								?>
							</div>
							<h2 class="entry-title"><?php echo phase_sample( get_the_content(), 33 ); ?></h2>
						</div><!-- .entry-summary-inner -->
					</div><!-- .entry-summary -->
					<?php

				} elseif ( 'quote' === $format ) {
					$show_caption = false;
					?>
					<div class="entry-cover">
						<?php
							echo phase_background_img( array(
								'background_img_size' => 'medium',
								'placeholder_fallback' => true,
							) );
						?>
					</div><!-- entry-cover -->
					<div class="entry-metro_modern-overlay"></div>
					<div class="entry-metro_modern-overlay-gradient"></div>
					<div class="entry-summary">
						<div class="entry-summary-inner">
							<h2 class="entry-title">
								<?php echo phase_get_first_quote(); ?>
							</h2>
						</div><!-- .entry-summary-inner -->
					</div><!-- .entry-summary -->
					<?php

				} elseif ( 'link' === $format ) {
					$show_caption = false;
					?>
					<div class="entry-cover">
						<?php
							echo phase_background_img( array(
								'background_img_size' => 'medium',
								'placeholder_fallback' => true,
							) );
						?>
					</div><!-- entry-cover -->
					<div class="entry-metro_modern-overlay"></div>
					<div class="entry-summary">
						<div class="entry-summary-inner">
							<h2 class="entry-title">
								<?php the_title(); ?>
							</h2>
						</div><!-- .entry-summary-inner -->
					</div><!-- .entry-summary -->
					<?php

				// Anytime else
				} else { ?>
					<div class="entry-image">
						<div class="entry-cover">
							<?php
								echo phase_background_img( array(
									'background_img_size' => 'medium',
									'placeholder_fallback' => true,
								) );
							?>
						</div><!-- entry-cover -->
						<div class="entry-metro_modern-overlay"></div>
					</div>
				<?php } ?>
				
				<?php if ( $show_caption ) : ?>
					<div class="entry-inner">
						<?php if ( $show_category ) : ?>
							<a class="category-label" href="<?php echo phase_get_first_category_url(); ?>"><?php echo phase_get_first_category(); ?></a>
						<?php endif; ?>
						<?php
							if ( is_sticky() && ! is_paged() ) {
								echo '<span class="sticky-post" title="' . esc_attr( __( 'Featured', 'phase' ) ) . '"></span>';
							}
						?>
						<?php if ( $show_caption ) : ?>
							<div class="entry-summary">
								<div class="entry-summary-inner">
									<?php if ( $show_date ) : ?>
										<span class="entry-date">
											<?php phase_entry_date(); ?>
										</span>
									<?php endif; ?>
									<h2 class="entry-title">
										<?php the_title(); ?>
									</h2>
									<?php if ( $show_text ) : ?>
										<div class="entry-excerpt">
											<?php echo phase_sample( get_the_excerpt(), 5 ); ?>
										</div><!-- .entry-excerpt -->
									<?php endif; ?>
									<?php if ( $show_author || $show_tags || $show_extra_meta ) : ?>
										<div class="entry-meta">
											<?php if ( $show_author ) : ?>
												<?php phase_get_author_avatar(); ?>
											<?php endif; ?>
											<?php if ( $show_tags ) : ?>
												<?php phase_entry_tags(); ?>
											<?php endif; ?>
											<?php if ( $show_extra_meta ) : ?>
												<?php phase_get_extra_meta(); ?>
											<?php endif; ?>
											<?php //phase_edit_post_link(); ?>
										</div><!-- .entry-meta -->
									<?php endif; ?>
								</div><!-- .entry-summary-inner -->
							</div><!--  .entry-summary  -->
						<?php endif; ?>
					</div>
				<?php endif ?>
			</div><!-- .entry-container -->
		</div><!-- .entry-outer -->
	</div><!-- .entry-box -->
</article><!-- #post-## -->