<?php
/**
 * Theme configuration file
 *
 * @package WordPress
 * @subpackage Phase
 * @version 1.2.8
 */

/**
 * Default Google fonts option
 */
function phase_set_default_google_font() {
	return 'Oswald:400:700|Playfair+Display:400:700|Raleway:400,700|Poppins:400,600,700,800,900';
}
add_filter( 'phase_default_google_fonts', 'phase_set_default_google_font' );

/**
 * Set color scheme
 *
 * Add csutom color scheme
 *
 * @param array $color_scheme
 * @param array $color_scheme
 */
function phase_set_color_schemes( $color_scheme ) {

	//unset( $color_scheme['default'] );

	$color_scheme['light'] = array(
		'label'  => esc_html__( 'Light', 'phase' ),
		'colors' => array(
			'#0c0c0c', // body_bg
			'#ffffff', // page_bg
			'#151515', // submenu_background_color
			'#ffffff', // submenu_font_color
			'#35c5d5', // '#D7CEC7', // accent
			'#444444', // main_text_color
			'#4c4c4c', // secondary_text_color
			'#0d0d0d', // strong_text_color
			'#cc9602', // secondary accent
		)
	);

	$color_scheme['dark'] = array(
		'label'  => esc_html__( 'Dark - Turquoise', 'phase' ),
		'colors' => array(
			'#1B1B1B', // body_bg
			'#232322', // page_bg
			'#212121', // submenu_background_color
			'#ffffff', // submenu_font_color
			'#35c5d5', // accent
			'#f4f4f4', // main_text_color
			'#ffffff', // secondary_text_color
			'#ffffff', // strong_text_color
			'#AD6058', // secondary accent
		)
	);

	$color_scheme['dark_green'] = array(
		'label'  => esc_html__( 'Dark - Electric Green', 'phase' ),
		'colors' => array(
			'#1B1B1B', // body_bg
			'#232322', // page_bg
			'#212121', // submenu_background_color
			'#ffffff', // submenu_font_color
			'#2BFB9C', // accent
			'#f4f4f4', // main_text_color
			'#ffffff', // secondary_text_color
			'#ffffff', // strong_text_color
			'#AD6058', // secondary accent
		)
	);

	$color_scheme['dark_pink'] = array(
		'label'  => esc_html__( 'Dark - Violent Pink', 'phase' ),
		'colors' => array(
			'#1B1B1B', // body_bg
			'#232322', // page_bg
			'#212121', // submenu_background_color
			'#ffffff', // submenu_font_color
			'#fb00ee', // accent
			'#f4f4f4', // main_text_color
			'#ffffff', // secondary_text_color
			'#ffffff', // strong_text_color
			'#AD6058', // secondary accent
		)
	);

	return $color_scheme;
}
add_filter( 'phase_color_schemes', 'phase_set_color_schemes' );

/**
 * Add additional theme support
 */
function phase_additional_theme_support() {

	/**
	 * Enable WooCommerce support
	 */
	add_theme_support( 'woocommerce' );
}
add_action( 'after_setup_theme', 'phase_additional_theme_support' );

/**
 * Set default WordPress option
 */
function phase_set_default_wp_options() {

	update_option( 'medium_size_w', 500 );
	update_option( 'medium_size_h', 286 );

	update_option( 'thread_comments_depth', 2 );
}
add_action( 'phase_default_wp_options_init', 'phase_set_default_wp_options' );

/**
 * Filter WooCommerce image sizes
 *
 * @param array $woocommerce_thumbnails
 * @param array $woocommerce_thumbnails
 */
function phase_set_woocommerce_image_sizes( $woocommerce_thumbnails ) {

	$woocommerce_thumbnails = array(
		'catalog' => array(
			'width' 	=> '500',	// px
			'height'	=> '752',	// px
			'crop'	=> 1 		// true
		),

		'single' => array(
			'width' 	=> '709',	// px
			'height'	=> '1067',	// px
			'crop'	=> 1 		// true
		),

		'thumbnail' => array(
			'width' 	=> '200',	// px
			'height'	=> '301',	// px
			'crop'	=> 1 		// true
		),
	);

	return $woocommerce_thumbnails;
}
add_filter( 'phase_woocommerce_thumbnail_sizes', 'phase_set_woocommerce_image_sizes' );

/**
 * Set mod files to include
 */
function phase_customizer_set_mod_files( $mod_files ) {
	$mod_files = array(
		'loading',
		'logo',
		'layout',
		'colors',
		'navigation',
		'socials',
		'fonts',
		'header',
		'header-image',
		'blog',
		'artists',
		'discography',
		'events',
		'videos',
		'albums',
		'shop',
		'background-image',
		'footer',
		'footer-bg',
		'wvc',
		'extra',
	);

	return $mod_files;
}
add_filter( 'phase_customizer_mod_files', 'phase_customizer_set_mod_files' );