<?php
/**
 * Phase metaboxes
 *
 * @package WordPress
 * @subpackage Phase
 * @version 1.2.8
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Register metaboxes
 *
 * Pass a metabox array to generate metabox with the Phase_Metabox class
 * @see inc/admin/lib/class-metabox.php
 */
function phase_register_metabox() {

	$body_metaboxes = array(
		'site_settings' => array(
			'title' => esc_html__( 'General', 'phase' ),
			'page' => apply_filters( 'phase_site_settings_post_types', array( 'post', 'page', 'plugin', 'video', 'product', 'gallery', 'theme', 'work', 'show', 'release', 'wpm_playlist', 'event', 'artist' ) ),

			'metafields' => array(
				array(
					'label'	=> esc_html__( 'Site Layout', 'phase' ),
					'id'	=> '_post_site_layout',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'wide' => esc_html__( 'Wide', 'phase' ),
						'boxed' => esc_html__( 'Boxed', 'phase' ),
						'frame' => esc_html__( 'Frame', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Accent Color', 'phase' ),
					'id'	=> '_post_accent_color',
					'type'	=> 'colorpicker',
				),

				array(
					'label' => esc_html__( 'Loading Animation Type', 'phase' ),
					'id' => '_post_loading_animation_type',
					'type' => 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'overlay' => esc_html__( 'Overlay', 'phase' ),
		 				'phase' => esc_html__( 'Overlay with text animation', 'phase' ),
		 				'none' => esc_html__( 'None', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Body Background', 'phase' ),
					'id'	=> '_post_body_background_img',
					'type'	=> 'image',
				),
			),
		),
	);

	if ( class_exists( 'Wolf_Visual_Composer' ) && class_exists( 'Wolf_Vc_Content_Block' ) && defined( 'WPB_VC_VERSION' ) ) {
		// Content block option
		$content_block_posts = get_posts( 'post_type="wvc_content_block"&numberposts=-1' );

		$content_blocks = array(
			'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
			'none' => esc_html__( 'None', 'phase' ),
		);
		if ( $content_block_posts ) {
			foreach ( $content_block_posts as $content_block_options ) {
				$content_blocks[ $content_block_options->ID ] = $content_block_options->post_title;
			}
		} else {
			$content_blocks[0] = esc_html__( 'No Content Block Yet', 'phase' );
		}

		$body_metaboxes['site_settings']['metafields'][] = array(
			'label'	=> esc_html__( 'Post-header Block', 'phase' ),
			'id'	=> '_post_after_header_block',
			'type'	=> 'select',
			'choices' => $content_blocks,
		);

		$body_metaboxes['site_settings']['metafields'][] = array(
			'label'	=> esc_html__( 'Pre-footer Block', 'phase' ),
			'id'	=> '_post_before_footer_block',
			'type'	=> 'select',
			'choices' => $content_blocks,
		);

	}

	$header_metaboxes = array(
		'header_settings' => array(
			'title' => esc_html__( 'Header', 'phase' ),
			'page' => apply_filters( 'phase_header_settings_post_types', array( 'post', 'page', 'plugin', 'video', 'gallery', 'theme', 'work', 'show', 'release', 'wpm_playlist', 'event', 'artist' ) ),

			'metafields' => array(

				array(
					'label'	=> esc_html__( 'Header Layout', 'phase' ),
					'id'	=> '_post_hero_layout',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'standard' => esc_html__( 'Standard', 'phase' ),
						'big' => esc_html__( 'Big', 'phase' ),
						'small' => esc_html__( 'Small', 'phase' ),
						'fullheight' => esc_html__( 'Full Height', 'phase' ),
						'none' => esc_html__( 'No Header', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Title Font Family', 'phase' ),
					'id'	=> '_post_hero_title_font_family',
					'type'	=> 'font_family',
				),

				array(
					'label'	=> esc_html__( 'Font Transform', 'phase' ),
					'id'	=> '_post_hero_title_font_transform',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'uppercase' => esc_html__( 'Uppercase', 'phase' ),
						'none' => esc_html__( 'None', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Big Text', 'phase' ),
					'id'	=> '_post_hero_title_bigtext',
					'type'	=> 'checkbox',
					'desc' => esc_html__( 'Enable "Big Text" for the title?', 'phase' ),
				),

				array(
					'label'	=> esc_html__( 'Font Tone', 'phase' ),
					'id'	=> '_post_hero_font_tone',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'light' => esc_html__( 'Light', 'phase' ),
						'dark' => esc_html__( 'Dark', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Background Type', 'phase' ),
					'id'	=> '_post_hero_background_type',
					'type'	=> 'select',
					'choices' => array(
						'featured-image' => esc_html__( 'Featured Image', 'phase' ),
						'image' => esc_html__( 'Image', 'phase' ),
						'video' => esc_html__( 'Video', 'phase' ),
						'slideshow' => esc_html__( 'Slideshow', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Slideshow Images', 'phase' ),
					'id'	=> '_post_hero_slideshow_ids',
					'type'	=> 'multiple_images',
					'dependency' => array( 'element' => '_post_hero_background_type', 'value' => array( 'slideshow' ) ),
				),

				array(
					'label'	=> esc_html__( 'Background', 'phase' ),
					'id'	=> '_post_hero_background',
					'type'	=> 'background',
					'dependency' => array( 'element' => '_post_hero_background_type', 'value' => array( 'image' ) ),
				),

				array(
					'label'	=> esc_html__( 'Background Effect', 'phase' ),
					'id'	=> '_post_hero_background_effect',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'zoomin' => esc_html__( 'Zoom', 'phase' ),
						'parallax' => esc_html__( 'Parallax', 'phase' ),
						'none' => esc_html__( 'None', 'phase' ),
					),
					'dependency' => array( 'element' => '_post_hero_background_type', 'value' => array( 'image' ) ),
				),

				array(
					'label'	=> esc_html__( 'Video URL', 'phase' ),
					'id'	=> '_post_hero_background_video_url',
					'type'	=> 'video',
					'dependency' => array( 'element' => '_post_hero_background_type', 'value' => array( 'video' ) ),
					'desc' => esc_html__( 'A mp4 or YouTube URL. The featured image will be used as image fallback when the video cannot be displayed.', 'phase' ),
				),

				array(
					'label'	=> esc_html__( 'Overlay', 'phase' ),
					'id'	=> '_post_hero_overlay',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'custom' => esc_html__( 'Custom', 'phase' ),
						'none' => esc_html__( 'None', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Overlay Color', 'phase' ),
					'id'	=> '_post_hero_overlay_color',
					'type'	=> 'colorpicker',
					//'value' 	=> '#000000',
					'dependency' => array( 'element' => '_post_hero_overlay', 'value' => array( 'custom' ) ),
				),

				array(
					'label'	=> esc_html__( 'Overlay Opacity (in percent)', 'phase' ),
					'id'	=> '_post_hero_overlay_opacity',
					'desc'	=> esc_html__( 'Adapt the header overlay opacity if needed', 'phase' ),
					'type'	=> 'int',
					'placeholder'	=> 40,
					'dependency' => array( 'element' => '_post_hero_overlay', 'value' => array( 'custom' ) ),
				),

			),
		),
	);

	$menu_metaboxes = array(
			'menu_settings' => array(
				'title' => esc_html__( 'Menu', 'phase' ),
				'page' => apply_filters( 'phase_menu_settings_post_types', array( 'post', 'page', 'plugin', 'video', 'product', 'gallery', 'theme', 'work', 'show', 'release', 'wpm_playlist', 'event', 'artist' ) ),

			'metafields' => array(
				array(
					'label'	=> esc_html__( 'Menu Layout', 'phase' ),
					'id'	=> '_post_menu_layout',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'top-right' => esc_html__( 'Top Right', 'phase' ),
						'top-justify' => esc_html__( 'Top Justify', 'phase' ),
						'top-justify-left' => esc_html__( 'Top Justify Left', 'phase' ),
						'centered-logo' => esc_html__( 'Centered', 'phase' ),
						'top-left' => esc_html__( 'Top Left', 'phase' ),
						'offcanvas' => esc_html__( 'Off Canvas', 'phase' ),
						'overlay' => esc_html__( 'Overlay', 'phase' ),
						'lateral' => esc_html__( 'Lateral', 'phase' ),
						'none' => esc_html__( 'No Menu', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Menu Width', 'phase' ),
					'id'	=> '_post_menu_width',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'wide' => esc_html__( 'Wide', 'phase' ),
						'boxed' => esc_html__( 'Boxed', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Menu Style', 'phase' ),
					'id'	=> '_post_menu_style',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'solid' => esc_html__( 'Solid', 'phase' ),
						'semi-transparent-white' => esc_html__( 'Semi-transparent White', 'phase' ),
						'semi-transparent-black' => esc_html__( 'Semi-transparent Black', 'phase' ),
						'transparent' => esc_html__( 'Transparent', 'phase' ),
						//'none' => esc_html__( 'No Menu', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Menu Skin', 'phase' ),
					'id'	=> '_post_menu_skin',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'light' => esc_html__( 'Light', 'phase' ),
						'dark' => esc_html__( 'Dark', 'phase' ),
						//'none' => esc_html__( 'No Menu', 'phase' ),
					),
				),

				'menu_sticky_type' => array(
					'id' =>'_post_menu_sticky_type',
					'label' => esc_html__( 'Sticky Menu', 'phase' ),
					'type' => 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'none' => esc_html__( 'Disabled', 'phase' ),
						'soft' => esc_html__( 'Sticky on scroll up', 'phase' ),
						'hard' => esc_html__( 'Always sticky', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Sticky Menu Skin', 'phase' ),
					'id'	=> '_post_menu_skin',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'light' => esc_html__( 'Light', 'phase' ),
						'dark' => esc_html__( 'Dark', 'phase' ),
						//'none' => esc_html__( 'No Menu', 'phase' ),
					),
				),

				array(
					'id' => '_post_menu_cta_content_type',
					'label' => esc_html__( 'Additional Content', 'phase' ),
					'type' => 'select',
					'default' => 'icons',
					'choices' => array_merge(
						array(
							'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						),
						apply_filters( 'phase_menu_cta_content_type_options', array(
							'search_icon' => esc_html__( 'Search Icon', 'phase' ),
							'secondary-menu' => esc_html__( 'Secondary Menu', 'phase' ),
						) ),
						array( 'none' => esc_html__( 'None', 'phase' ) )
					),
				),

				array(
					'id' => '_post_side_panel_position',
					'label' => esc_html__( 'Side Panel', 'phase' ),
					'type' => 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'none' => esc_html__( 'None', 'phase' ),
						'right' => esc_html__( 'At Right', 'phase' ),
						'left' => esc_html__( 'At Left', 'phase' ),
					),
					'desc' => esc_html__( 'Note that it will be disable with a vertical menu layout (overlay, offcanvas etc...).', 'phase' ),
				),

				array(
					'id' => '_post_logo_visibility',
					'label' => esc_html__( 'Logo Visibility', 'phase' ),
					'type' => 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'always' => esc_html__( 'Always', 'phase' ),
						'sticky_menu' => esc_html__( 'When menu is sticky only', 'phase' ),
						'hidden' => esc_html__( 'Hidden', 'phase' ),
					),
				),

				array(
					'id' => '_post_menu_items_visibility',
					'label' => esc_html__( 'Menu Items Visibility', 'phase' ),
					'type' => 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'show' => esc_html__( 'Visible', 'phase' ),
						'hidden' => esc_html__( 'Hidden', 'phase' ),
					),
					'desc' => esc_html__( 'If, for some reason, you need to hide the menu items but leave the logo, additional content and side panel.', 'phase' ),
				),

				'menu_breakpoint' => array(
					'id' =>'_post_menu_breakpoint',
					'label' => esc_html__( 'Mobile Menu Breakpoint', 'phase' ),
					'type' => 'text',
					'desc' => esc_html__( 'Use this field if you want to overwrite the mobile menu breakpoint.', 'phase' ),
				),
			),
		)
	);

	$footer_metaboxes = array(
		'footer_settings' => array(
				'title' => esc_html__( 'Footer', 'phase' ),
				'page' => apply_filters( 'phase_menu_settings_post_types', array( 'post', 'page', 'plugin', 'video', 'product', 'gallery', 'theme', 'work', 'show', 'release', 'wpm_playlist', 'event' ) ),

			'metafields' => array(
				array(
					'label'	=> esc_html__( 'Page Footer', 'phase' ),
					'id'	=> '_post_footer_type',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'hidden' => esc_html__( 'No Footer', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Hide Bottom Bar', 'phase' ),
					'id'	=> '_post_bottom_bar_hidden',
					'type'	=> 'select',
					'choices' => array(
						'' => esc_html__( 'No', 'phase' ),
						'yes' => esc_html__( 'Yes', 'phase' ),
					),
				),
			),
		)
	);

	/************** Page options ******************/
	$page_metaboxes = array(

		'page_settings' => array(

			'title' => esc_html__( 'Page', 'phase' ),
			'page' => array( 'page', 'artist' ),
			'metafields' => array(
				array(
					'label'	=> '',
					'id'	=> '_post_subheading',
					'type'	=> 'text',
				),
			),
		),
	);

	if ( class_exists( 'Wolf_Playlist_Manager' ) ) {
		// Player option
		$playlist_posts = get_posts( 'post_type="wpm_playlist"&numberposts=-1' );

		$playlist = array( '' => esc_html__( 'None', 'phase' ) );
		if ( $playlist_posts ) {
			foreach ( $playlist_posts as $playlist_options ) {
				$playlist[ $playlist_options->ID ] = $playlist_options->post_title;
			}
		} else {
			$playlist[0] = esc_html__( 'No Playlist Yet', 'phase' );
		}

		$page_metaboxes['page_settings']['metafields'][] = array(
			'label'	=> esc_html__( 'Sticky Playlist', 'phase' ),
			'id'	=> '_post_sticky_playlist_id',
			'type'	=> 'select',
			'choices' => $playlist,
		);

		$page_metaboxes['page_settings']['metafields'][] = array(
			'label'	=> esc_html__( 'Sticky Playlist Skin', 'phase' ),
			'id'	=> '_post_sticky_playlist_skin',
			'type'	=> 'select',
			'choices' => array(
				'dark' => esc_html__( 'Dark', 'phase' ),
				'light' => esc_html__( 'Light', 'phase' ),
			),
		);
	}


	/************** Post options ******************/

	$post_metaboxes = array(
		'post_settings' => array(
			'title' => esc_html__( 'Post', 'phase' ),
			'page' => array( 'post' ),
			'metafields' => array(
				array(
					'label'	=> esc_html__( 'Post Layout', 'phase' ),
					'id'	=> '_post_layout',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'sidebar-right' => esc_html__( 'Sidebar Right', 'phase' ),
						'sidebar-left' => esc_html__( 'Sidebar Left', 'phase' ),
						'no-sidebar' => esc_html__( 'No Sidebar', 'phase' ),
						'fullwidth' => esc_html__( 'Full width', 'phase' ),
					),
				),
				array(
					'label'	=> esc_html__( 'Featured', 'phase' ),
					'id'	=> '_post_featured',
					'type'	=> 'checkbox',
					'desc'	=> esc_html__( 'Will be displayed bigger in the "metro" layout..', 'phase' ),
				),
			),
		),
	);

	/************** Videos options ******************/

	$video_metaboxes = array(
		'video_options' => array(
			'title' => esc_html__( 'Video', 'phase' ),
			'page' => array( 'video' ),
			'metafields' => array(
				array(
					'label'	=> esc_html__( 'Layout', 'phase' ),
					'id'	=> '_post_layout',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'standard' => esc_html__( 'Standard', 'phase' ),
						'sidebar-right' => esc_html__( 'Sidebar Right', 'phase' ),
						'sidebar-left' => esc_html__( 'Sidebar Left', 'phase' ),
						'fullwidth' => esc_html__( 'Full Width', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Menu Font Tone', 'phase' ),
					'id'	=> '_post_hero_font_tone',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'light' => esc_html__( 'Light', 'phase' ),
						'dark' => esc_html__( 'Dark', 'phase' ),
					),
					'desc' => esc_html__( 'By default the menu style is set to "solid" on single video page. If you change the menu style, you may need to adujst the menu color tone here.', 'phase' ),
				),
			),
		),
	);

	/************** Product options ******************/
	$product_metaboxes = array(

		'product_options' => array(
			'title' => esc_html__( 'Product', 'phase' ),
			'page' => array( 'product' ),
			'metafields' => array(

				array(
					'label'	=> esc_html__( 'Layout', 'phase' ),
					'id'	=> '_post_product_single_layout',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'standard' => esc_html__( 'Standard', 'phase' ),
						'sidebar-right' => esc_html__( 'Sidebar Right', 'phase' ),
						'sidebar-left' => esc_html__( 'Sidebar Left', 'phase' ),
						'fullwidth' => esc_html__( 'Full Width', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'MP3', 'phase' ),
					'id'	=> '_post_product_mp3',
					'type'	=> 'file',
					'desc' => esc_html__( 'If you want to display a player for a song you want to sell, paste the mp3 URL here.', 'phase' ),
				),

				array(
					'label'	=> esc_html__( 'Menu Font Tone', 'phase' ),
					'id'	=> '_post_hero_font_tone',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'light' => esc_html__( 'Light', 'phase' ),
						'dark' => esc_html__( 'Dark', 'phase' ),
					),
					'desc' => esc_html__( 'By default the menu style is set to "solid" on single product page. If you change the menu style, you may need to adujst the menu color tone here.', 'phase' ),
				),

				array(
					'label'	=> esc_html__( 'Image Zoom', 'phase' ),
					'id'	=> '_post_product_disable_easyzoom',
					'type'	=> 'checkbox',
					'desc' => esc_html__( 'Disable image zoom on this product if it\'s enabled in the customizer.', 'phase' ),
				),
			),
		),
	);

	/************** Gallery options ******************/
	$gallery_metaboxes = array(

		'gallery_settings' => array(
			'title' => esc_html__( 'Gallery', 'phase' ),
			'page' => array( 'gallery' ),
			'metafields' => array(
				array(
					'label'	=> esc_html__( 'Gallery Layout', 'phase' ),
					'id'	=> '_post_layout',
					'type'	=> 'select',
					'choices' => array(
						'standard' => esc_html__( 'Standard', 'phase' ),
						'large-width' => esc_html__( 'Large width', 'phase' ),
						'full-width' => esc_html__( 'Full window', 'phase' ),
					),
				),
			),
		),
	);

	/************** Portfolio options ******************/
	$work_metaboxes = array(

		'work_options' => array(
			'title' => esc_html__( 'Work', 'phase' ),
			'page' => array( 'work' ),
			'metafields' => array(

				array(
					'label'	=> esc_html__( 'Client', 'phase' ),
					'id'	=> '_work_client',
					'type'	=> 'text',
				),

				array(
					'label'	=> esc_html__( 'Link', 'phase' ),
					'id'	=> '_work_link',
					'type'	=> 'text',
				),

				array(
					'label'	=> esc_html__( 'Width', 'phase' ),
					'id'	=> '_post_width',
					'type'	=> 'select',
					'choices' => array(
						'standard' => esc_html__( 'Standard', 'phase' ),
						'wide' => esc_html__( 'Wide', 'phase' ),
						'fullwidth' => esc_html__( 'Full Width', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Layout', 'phase' ),
					'id'	=> '_post_layout',
					'type'	=> 'select',
					'choices' => array(
						'centered' => esc_html__( 'Centered', 'phase' ),
						'sidebar-right' => esc_html__( 'Excerpt & Info at Right', 'phase' ),
						'sidebar-left' => esc_html__( 'Excerpt & Info at Left', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Excerpt & Info Position', 'phase' ),
					'id'	=> '_post_work_info_position',
					'type'	=> 'select',
					'choices' => array(
						'after' => esc_html__( 'After Content', 'phase' ),
						'before' => esc_html__( 'Before Content', 'phase' ),
						'none' => esc_html__( 'Hidden', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Featured', 'phase' ),
					'id'	=> '_post_featured',
					'type'	=> 'checkbox',
					'desc'	=> esc_html__( 'May be used depending on layout option.', 'phase' ),
				),
			),
		),
	);

	/************** Product options ******************/

	$product_options = array();
	$product_options[] = esc_html__( 'WooCommerce not installed', 'phase' );

	if ( class_exists( 'WooCommerce' ) ) {
		$product_posts = get_posts( 'post_type="product"&numberposts=-1' );

		$product_options = array();
		if ( $product_posts ) {
			
			$product_options[] = esc_html__( 'Not linked', 'phase' );
			
			foreach ( $product_posts as $product ) {
				$product_options[ $product->ID ] = $product->post_title;
			}
		} else {
			$product_options[ esc_html__( 'No product yet', 'phase' ) ] = 0;
		}
	}

	
	$release_metaboxes = array(
		'release_options' => array(
			'title' => esc_html__( 'Release', 'phase' ),
			'page' => array( 'release' ),
			'metafields' => array(
				array(
					'label'	=> esc_html__( 'Release Width', 'phase' ),
					'id'	=> '_post_width',
					'type'	=> 'select',
					'choices' => array(
						'standard' => esc_html__( 'Standard', 'phase' ),
						'wide' => esc_html__( 'Wide', 'phase' ),
						//'fullwidth' => esc_html__( 'Full Width', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Release Layout', 'phase' ),
					'id'	=> '_post_layout',
					'type'	=> 'select',
					'choices' => array(
						'sidebar-left' => esc_html__( 'Content Right', 'phase' ),
						'sidebar-right' => esc_html__( 'Content Left', 'phase' ),
						//'centered' => esc_html__( 'Centered', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'WooCommerce Product ID', 'phase' ),
					'id'	=> '_post_wc_product_id',
					'type'	=> 'select',
					'choices' => $product_options,
					'desc'	=> esc_html__( 'You can link this release to a WooCommerce product to add an "Add to cart" button.', 'phase' ),
				),

				array(
					'label'	=> esc_html__( 'Featured', 'phase' ),
					'id'	=> '_post_featured',
					'type'	=> 'checkbox',
					'desc'	=> esc_html__( 'May be used depending on layout option.', 'phase' ),
				),
			),
		),
	);


	/************** Artist options ******************/
	$artist_metaboxes = array(

		'artist_options' => array(
			'title' => esc_html__( 'Artist', 'phase' ),
			'page' => array( 'artist' ),
			'metafields' => array(

				array(
					'label'	=> esc_html__( 'Width', 'phase' ),
					'id'	=> '_post_width',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'standard' => esc_html__( 'Standard', 'phase' ),
						'wide' => esc_html__( 'Wide', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Layout', 'phase' ),
					'id'	=> '_post_layout',
					'type'	=> 'select',
					'choices' => array(
						'' => '&mdash; ' . esc_html__( 'Default', 'phase' ) . ' &mdash;',
						'sidebar-left' => esc_html__( 'Excerpt & Info at Left', 'phase' ),
						'sidebar-right' => esc_html__( 'Excerpt & Info at Right', 'phase' ),
						//'centered' => esc_html__( 'Centered', 'phase' ),
						'custom' => esc_html__( 'Custom', 'phase' ),
					),
				),

				array(
					'label'	=> esc_html__( 'Hide Pagination', 'phase' ),
					'id'	=> '_artist_hide_pagination',
					'type'	=> 'checkbox',
				),

				array(
					'label'	=> esc_html__( 'Artist Location', 'phase' ),
					'id'	=> '_artist_location',
					'type'	=> 'text',
				),

				array(
					'label'	=> esc_html__( 'Website URL', 'phase' ),
					'id'	=> '_artist_website_url',
					'type'	=> 'text',
				),
			),
		),
	);

	$artists_socials = ( function_exists( 'wvc_get_team_member_socials' ) ) ? wvc_get_team_member_socials() : array( 'facebook', 'twitter', 'instagram', 'youtube', 'spotify', 'soundcloud', 'bandsintown', 'vimeo', 'email' );

	$artist_metaboxes['artist_socials'] = array(
		'title' => esc_html__( 'Artist Socials', 'phase' ),
		'page' => array( 'artist' ),
		'metafields' => array(),
	);

	foreach ( $artists_socials as $social ) {
		$artist_metaboxes['artist_socials']['metafields'][ $social ] = array(
			'label'	=> ucfirst( esc_attr( $social ) ),
			'id'	=> '_artist_' . esc_attr( $social ),
			'type'	=> 'text',
		);

		if ( 'twitter' === $social ) {
			$artist_metaboxes['artist_socials']['metafields'][ $social ]['desc'] = esc_html__( 'Will be used for the "Updates" artist tab.', 'phase' );
		}
	}

	if ( class_exists( 'Wolf_Playlist_Manager' ) ) {
		$artist_playlist_fileld = array(
			'label'	=> esc_html__( 'Artist Playlist', 'phase' ),
			'id'	=> '_artist_playlist_id',
			'type'	=> 'select',
			'choices' => $playlist,
		);

		array_unshift( $artist_metaboxes['artist_options']['metafields'], $artist_playlist_fileld );
	}

	// One pager option
	$one_page_metaboxes = array(
		'one_page_settings' => array(
			'title' => esc_html__( 'One-Page', 'phase' ),
			'page' => array( 'post', 'page', 'work', 'artist' ),
			'metafields' => array(
				array(
					'label'	=> esc_html__( 'One-Page Navigation', 'phase' ),
					'id'	=> '_post_one_page_menu',
					'type'	=> 'select',
					'choices' => array(
						'' => esc_html__( 'No', 'phase' ),
						'replace_main_nav' => esc_html__( 'Yes', 'phase' ),
					),
					'desc'	=> phase_kses( __( 'Activate to replace the main menu by a one-page scroll navigation. <strong>NB: Every row must have a unique name set in the row settings "Advanced" tab.</strong>', 'phase' ) ),
				),
				array(
					'label'	=> esc_html__( 'One-Page Bullet Navigation', 'phase' ),
					'id'	=> '_post_scroller',
					'type'	=> 'checkbox',
					'desc'	=> phase_kses( __( 'Activate to create a section scroller navigation. <strong>NB: Every row must have a unique name set in the row settings "Advanced" tab.</strong>', 'phase' ) ),
				),
				array(
					'label'	=> esc_html__( 'Enable fullPage animations', 'phase' ),
					'id'	=> '_post_fullpage',
					'type'	=> 'checkbox',
					'desc'	=> esc_html__( 'Activate to enable advanced scroll animations between sections. Some of your row setting may be disabled to suit the global page design.', 'phase' ),
				),
			),
		),
	);

	$all_metaboxes = array_merge(
		apply_filters( 'phase_body_metaboxes', $body_metaboxes ),
		apply_filters( 'phase_post_metaboxes', $post_metaboxes ),
		apply_filters( 'phase_page_metaboxes', $page_metaboxes ),
		apply_filters( 'phase_product_metaboxes', $product_metaboxes ),
		apply_filters( 'phase_gallery_metaboxes', $gallery_metaboxes ),
		apply_filters( 'phase_work_metaboxes', $work_metaboxes ),
		apply_filters( 'phase_release_metaboxes', $release_metaboxes ),
		apply_filters( 'phase_video_metaboxes', $video_metaboxes ),
		apply_filters( 'phase_artist_metaboxes', $artist_metaboxes ),
		apply_filters( 'phase_header_metaboxes', $header_metaboxes ),
		apply_filters( 'phase_menu_metaboxes', $menu_metaboxes ),
		apply_filters( 'phase_footer_metaboxes', $footer_metaboxes )
	);

	if ( class_exists( 'Wolf_Visual_Composer' ) && defined( 'WPB_VC_VERSION' ) ) {
		$all_metaboxes = $all_metaboxes + apply_filters( 'phase_one_page_metaboxes', $one_page_metaboxes );
	}

	if ( class_exists( 'Wolf_Metaboxes' ) ) {
		new Wolf_Metaboxes( apply_filters( 'phase_metaboxes', $all_metaboxes ) );
	}
}
phase_register_metabox();