<?php
/**
 * Visual Composer post modules
 *
 * @package WordPress
 * @subpackage Phase
 * @version 1.2.8
 */

if ( ! defined( 'ABSPATH' ) || ! class_exists( 'Wolf_Visual_Composer' ) || ! defined( 'WPB_VC_VERSION' ) ) {
	return;
}

$order_by_values = array(
	'',
	esc_html__( 'Date', 'phase' ) => 'date',
	esc_html__( 'ID', 'phase' ) => 'ID',
	esc_html__( 'Author', 'phase' ) => 'author',
	esc_html__( 'Title', 'phase' ) => 'title',
	esc_html__( 'Modified', 'phase' ) => 'modified',
	esc_html__( 'Random', 'phase' ) => 'rand',
	esc_html__( 'Comment count', 'phase' ) => 'comment_count',
	esc_html__( 'Menu order', 'phase' ) => 'menu_order',
);

$order_way_values = array(
	'',
	esc_html__( 'Descending', 'phase' ) => 'DESC',
	esc_html__( 'Ascending', 'phase' ) => 'ASC',
);

$shared_gradient_colors = ( function_exists( 'wvc_get_shared_gradient_colors' ) ) ? wvc_get_shared_gradient_colors() : array();
$shared_colors = ( function_exists( 'wvc_get_shared_colors' ) ) ? wvc_get_shared_colors() : array();

/**
 * Post Loop Module
 */
vc_map(
	array(
		'name' => esc_html__( 'Posts', 'phase' ),
		'description' => esc_html__( 'Display your posts using the theme layouts', 'phase' ),
		'base' => 'wvc_post_index',
		'category' => esc_html__( 'Content' , 'phase' ),
		'icon' => 'fa fa-th',
		'weight' => 999,
		'params' =>
		//array_merge(
			array(

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Index ID', 'phase' ),
					'value' => 'index-' . rand( 0,99999 ),
					'param_name' => 'el_id',
					'description' => esc_html__( 'A unique identifier for the post module (required).', 'phase' ),
				),

				array(
					'param_name' => 'post_display',
					'heading' => esc_html__( 'Post Display', 'phase' ),
					'type' => 'dropdown',
					'value' => array_flip( apply_filters( 'phase_post_display_options', array(
						'standard' => esc_html__( 'Standard', 'phase' ),
					) ) ),
					'std' => 'grid',
					'admin_label' => true,
				),

				array(
					'param_name' => 'post_alternate_thumbnail_position',
					'heading' => esc_html__( 'Alternate thumbnail position', 'phase' ),
					'type' => 'checkbox',
					'dependency' => array(
						'element' => 'post_display',
						'value' => array( 'lateral' )
					),
				),

				array(
					'param_name' => 'post_module',
					'heading' => esc_html__( 'Module', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Grid', 'phase' ) => 'grid',
						esc_html__( 'Carousel', 'phase' ) => 'carousel',
					),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'post_display',
						'value' => array( 'grid_classic', 'grid_modern' )
					),
				),

				array(
					'param_name' => 'post_excerpt_length',
					'heading' => esc_html__( 'Post Excerpt Lenght', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Shorten', 'phase' ) => 'shorten',
						esc_html__( 'Full', 'phase' ) => 'full',
					),
					'dependency' => array(
						'element' => 'post_display',
						'value' => array( 'masonry' ),
					),
				),

				array(
					'param_name' => 'post_display_elements',
					'heading' => esc_html__( 'Elements', 'phase' ),
					'type' => 'checkbox',
					'value' => array(
						esc_html__( 'Thumbnail', 'phase' ) => 'show_thumbnail',
						esc_html__( 'Date', 'phase' ) => 'show_date',
						esc_html__( 'Text', 'phase' ) => 'show_text',
						esc_html__( 'Category', 'phase' ) => 'show_category',
						esc_html__( 'Author', 'phase' ) => 'show_author',
						esc_html__( 'Tags', 'phase' ) => 'show_tags',
						esc_html__( 'Extra Meta', 'phase' ) => 'show_extra_meta',
					),
					'std' => 'show_thumbnail,show_date,show_text,show_author,show_category',
					// 'dependency' => array(
					// 	'element' => 'post_display',
					// 	'value' => array( 'masonry', 'grid_classic', 'grid_modern', 'mosaic', 'metro', 'standard' ),
					// ),
					'description' => esc_html__( 'Note that some options may be ignored depending on the post display.', 'phase' ),
					'admin_label' => true,
				),

				array(
					'param_name' => 'post_excerpt_type',
					'heading' => esc_html__( 'Post Excerpt Type', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Auto', 'phase' ) => 'auto',
						esc_html__( 'Manual', 'phase' ) => 'manual',
					),
					'description' => sprintf(
						wp_kses_post( __( 'When using the manual excerpt, you must split your post using a "<a href="%s">More Tag</a>".', 'phase' ) ),
						esc_url( 'https://en.support.wordpress.com/more-tag/' )
					),
					'dependency' => array(
						'element' => 'post_display',
						'value' => array( 'standard', 'standard_modern' ),
					),
				),

				array(
					'param_name' => 'grid_padding',
					'heading' => esc_html__( 'Padding', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Yes', 'phase' ) => 'yes',
						esc_html__( 'No', 'phase' ) => 'no',
					),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'post_display',
						'value_not_equal_to' => array( 'standard', 'standard_modern', 'masonry_modern' ),
						// value_not_equal_to
					),
				),

				// array(
				// 	'heading' => esc_html__( 'Category Filter', 'phase' ),
				// 	'param_name' => 'post_category_filter',
				// 	'type' => 'checkbox',
				// 	'admin_label' => true,
				// ),

				array(
					'param_name' => 'pagination',
					'heading' => esc_html__( 'Pagination', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'None', 'phase' ) => 'none',
						esc_html__( 'Load More', 'phase' ) => 'load_more',
						esc_html__( 'Numeric Pagination', 'phase' ) => 'standard_pagination',
						esc_html__( 'Link to Blog Archives', 'phase' ) => 'link_to_blog',
					),
					'admin_label' => true,
					//'dependency' => array( 'element' => 'post_module', 'value' => array( 'grid' ) ),
				),

				array(
					'heading' => esc_html__( 'Animation', 'phase' ),
					'param_name' => 'item_animation',
					'type' => 'dropdown',
					'value' => array_flip( phase_get_animations() ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Posts Per Page', 'phase' ),
					'param_name' => 'posts_per_page',
					'type' => 'wvc_textfield',
					'value' => get_option( 'posts_per_page' ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
					'param_name' => 'inline_style',
					'type' => 'wvc_textfield',
					//'admin_label' => true,
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Offset', 'phase' ),
					'param_name' => 'offset',
					'description' => esc_html__( 'The amount of posts that should be skipped in the beginning of the query. If an offset is set, sticky posts will be ignored.', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
					'admin_label' => true,
				),

				array(
					'type' => 'checkbox',
					'heading' => esc_html__( 'Ignore Sticky Posts', 'phase' ),
					'param_name' => 'ignore_sticky_posts',
					'description' => esc_html__( 'It will still include the sticky posts but it will not prioritize them in the query.', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'checkbox',
					'heading' => esc_html__( 'Exclude Sticky Posts', 'phase' ),
					'description' => esc_html__( 'It will still exclude the sticky posts.', 'phase' ),
					'param_name' => 'exclude_sticky_posts',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Category', 'phase' ),
					'param_name' => 'category',
					'description' => esc_html__( 'Include only one or several categories. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Tags', 'phase' ),
					'param_name' => 'tag',
					'description' => esc_html__( 'Include only one or several tags. Paste tag slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-tag, other-tag', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Order by', 'phase' ),
					'param_name' => 'orderby',
					'value' => $order_by_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Select how to sort retrieved posts. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Sort order', 'phase' ),
					'param_name' => 'order',
					'value' => $order_way_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Designates the ascending or descending order. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Post IDs', 'phase' ),
					'description' => esc_html__( 'By default, your last posts will be displayed. You can choose the posts you want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'include_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Post IDs', 'phase' ),
					'description' => esc_html__( 'You can choose the posts you don\'t want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'exclude_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'param_name' => 'columns',
					'heading' => esc_html__( 'Columns', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Auto', 'phase' ) => 'default',
						esc_html__( 'Two', 'phase' ) => 2,
						esc_html__( 'Three', 'phase' ) => 3,
						esc_html__( 'Four', 'phase' ) => 4,
						esc_html__( 'Six', 'phase' ) => 6,
						esc_html__( 'One', 'phase' ) => 1,
					),
					'std' => 'default',
					'admin_label' => true,
					'description' => esc_html__( 'By default, columns are set automatically depending on the container\'s width. Set a column count here to overwrite the default behavior.', 'phase' ),
					'dependency' => array(
						'element' => 'post_display',
						'value_not_equal_to' => array( 'standard', 'standard_modern', 'lateral', 'list' ),
					),
					'group' => esc_html__( 'Extra', 'phase' ),
				),
			),
			//),

			// 	array(
			// 		'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
			// 		'param_name' => 'inline_style',
			// 		'type' => 'wvc_textfield',
			// 		//'admin_label' => true,
			// 	),
			// ),
		//)
	)
);
class WPBakeryShortCode_Wvc_Post_Index extends WPBakeryShortCode {}

if ( class_exists( 'Wolf_Portfolio' ) ) {

/**
 * Work Loop Module
 */
vc_map(
	array(
		'name' => esc_html__( 'Works', 'phase' ),
		'description' => esc_html__( 'Display your works using the theme layouts', 'phase' ),
		'base' => 'wvc_work_index',
		'category' => esc_html__( 'Content' , 'phase' ),
		'icon' => 'fa fa-th',
		'weight' => 999,
		'params' =>
		//array_merge(
			array(

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Index ID', 'phase' ),
					'value' => 'index-' . rand( 0,99999 ),
					'param_name' => 'el_id',
					'description' => esc_html__( 'A unique identifier for the post module (required).', 'phase' ),
				),

				array(
					'param_name' => 'work_display',
					'heading' => esc_html__( 'Work Display', 'phase' ),
					'type' => 'dropdown',
					'value' => array_flip( apply_filters( 'phase_work_display_options', array(
						'grid' => esc_html__( 'Grid', 'phase' ),
					) ) ),
					'admin_label' => true,
				),

				array(
					'param_name' => 'work_module',
					'heading' => esc_html__( 'Module', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Grid', 'phase' ) => 'grid',
						esc_html__( 'Carousel', 'phase' ) => 'carousel',
					),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'work_display',
						'value' => array( 'grid' )
					),
				),

				array(
					'param_name' => 'work_thumbnail_size',
					'heading' => esc_html__( 'Thumbnail Size', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Default Thumbnail', 'phase' ) => 'standard',
						esc_html__( 'Landscape', 'phase' ) => 'landscape',
						esc_html__( 'Square', 'phase' ) => 'square',
						esc_html__( 'Portrait', 'phase' ) => 'portrait',
					),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'work_display',
						'value' => array( 'grid' ),
						// value_not_equal_to
					),
				),

				array(
					'param_name' => 'work_layout',
					'heading' => esc_html__( 'Layout', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Classic', 'phase' ) => 'standard',
						esc_html__( 'Overlay', 'phase' ) => 'overlay',
						//esc_html__( 'Flip Box', 'phase' ) => 'flip-box',
					),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'work_display',
						'value_not_equal_to' => array( 'list_minimal' )
					),
				),

				array(
					'param_name' => 'grid_padding',
					'heading' => esc_html__( 'Padding', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Yes', 'phase' ) => 'yes',
						esc_html__( 'No', 'phase' ) => 'no',
					),
					'admin_label' => true,
					'dependency' => array( 'element' => 'work_layout', 'value' => array( 'overlay', 'flip-box' ) ),
				),

				array(
					'heading' => esc_html__( 'Caption Text Alignement', 'phase' ),
					'param_name' => 'caption_text_alignment',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Center', 'phase' ) => 'center',
						esc_html__( 'Left', 'phase' ) => 'left',
						esc_html__( 'Right', 'phase' ) => 'right',
					),
					'dependency' => array(
						'element' => 'work_display',
						'value_not_equal_to' => array( 'list_minimal' )
					),
				),

				array(
					'heading' => esc_html__( 'Caption Vertical Alignement', 'phase' ),
					'param_name' => 'caption_v_align',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Middle', 'phase' ) => 'middle',
						esc_html__( 'Bottom', 'phase' ) => 'bottom',
						esc_html__( 'Top', 'phase' ) => 'top',
					),
					'dependency' => array(
						'element' => 'work_display',
						'value_not_equal_to' => array( 'list_minimal' )
					),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Overlay Color', 'phase' ),
					'param_name' => 'overlay_color',
					'value' => array_merge(
							array( esc_html__( 'Auto', 'phase' ) => 'auto', ),
							$shared_gradient_colors,
							$shared_colors,
							array( esc_html__( 'Custom color', 'phase' ) => 'custom', )
					),
					'std' => apply_filters( 'wvc_default_item_overlay_color', 'black' ),
					'description' => esc_html__( 'Select an overlay color.', 'phase' ),
					'param_holder_class' => 'wvc_colored-dropdown',
					'dependency' => array( 'element' => 'work_layout', 'value' => array( 'overlay', 'flip-box' ) ),
				),

				// Overlay color
				array(
					'type' => 'colorpicker',
					'heading' => esc_html__( 'Overlay Custom Color', 'phase' ),
					'param_name' => 'overlay_custom_color',
					//'value' => '#000000',
					'dependency' => array( 'element' => 'overlay_color', 'value' => array( 'custom' ), ),
				),

				// Overlay opacity
				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Overlay Opacity in Percent', 'phase' ),
					'param_name' => 'overlay_opacity',
					'description' => '',
					'value' => 40,
					'std' => apply_filters( 'wvc_default_item_overlay_opacity', 40 ),
					'dependency' => array( 'element' => 'work_layout', 'value' => array( 'overlay', 'flip-box' ), ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Overlay Text Color', 'phase' ),
					'param_name' => 'overlay_text_color',
					'value' => array_merge(
						$shared_colors,
						$shared_gradient_colors,
						array( esc_html__( 'Custom color', 'phase' ) => 'custom', )
					),
					'std' => apply_filters( 'wvc_default_item_overlay_text_color', 'white' ),
					'description' => esc_html__( 'Select an overlay color.', 'phase' ),
					'param_holder_class' => 'wvc_colored-dropdown',
					'dependency' => array( 'element' => 'work_layout', 'value' => array( 'overlay', 'flip-box' ) ),
				),

				// Overlay color
				array(
					'type' => 'colorpicker',
					'heading' => esc_html__( 'Overlay Custom Text Color', 'phase' ),
					'param_name' => 'overlay_text_custom_color',
					//'value' => '#000000',
					'dependency' => array( 'element' => 'overlay_text_color', 'value' => array( 'custom' ), ),
				),

				array(
					'heading' => esc_html__( 'Category Filter', 'phase' ),
					'param_name' => 'work_category_filter',
					'type' => 'checkbox',
					'description' => esc_html__( 'The pagination will be disabled.', 'phase' ),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'work_display',
						'value_not_equal_to' => array( 'list_minimal' )
					),
				),

				array(
					'heading' => esc_html__( 'Filter Text Alignement', 'phase' ),
					'param_name' => 'work_category_filter_text_alignment',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Center', 'phase' ) => 'center',
						esc_html__( 'Left', 'phase' ) => 'left',
						esc_html__( 'Right', 'phase' ) => 'right',
					),
					'dependency' => array(
						'element' => 'work_category_filter',
						'value' => array( 'true' ),
					),
				),

				array(
					'heading' => esc_html__( 'Animation', 'phase' ),
					'param_name' => 'item_animation',
					'type' => 'dropdown',
					'value' => array_flip( phase_get_animations() ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Number of Posts', 'phase' ),
					'param_name' => 'posts_per_page',
					'type' => 'wvc_textfield',
					//'placeholder' => get_option( 'posts_per_page' ),
					'description' => esc_html__( 'Leave empty to display all post at once.', 'phase' ),
					//'std' => '-1',
					'admin_label' => true,
				),

				array(
					'param_name' => 'pagination',
					'heading' => esc_html__( 'Pagination', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'None', 'phase' ) => 'none',
						esc_html__( 'Load More', 'phase' ) => 'load_more',
						esc_html__( 'Link to Portfolio', 'phase' ) => 'link_to_portfolio',
					),
					'admin_label' => true,
					'dependency' => array( 'element' => 'work_module', 'value' => array( 'grid' ) ),
				),

				array(
					'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
					'param_name' => 'inline_style',
					'type' => 'wvc_textfield',
					//'admin_label' => true,
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Include Category', 'phase' ),
					'param_name' => 'work_type_include',
					'description' => esc_html__( 'Enter one or several categories. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Category', 'phase' ),
					'param_name' => 'work_type_exclude',
					'description' => esc_html__( 'Enter one or several categories. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Offset', 'phase' ),
					'description' => esc_html__( '.', 'phase' ),
					'param_name' => 'offset',
					'description' => esc_html__( 'The amount of posts that should be skipped in the beginning of the query.', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Order by', 'phase' ),
					'param_name' => 'orderby',
					'value' => $order_by_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Select how to sort retrieved posts. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Sort order', 'phase' ),
					'param_name' => 'order',
					'value' => $order_way_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Designates the ascending or descending order. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Post IDs', 'phase' ),
					'description' => esc_html__( 'By default, your last posts will be displayed. You can choose the posts you want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'include_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Post IDs', 'phase' ),
					'description' => esc_html__( 'You can choose the posts you don\'t want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'exclude_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'param_name' => 'columns',
					'heading' => esc_html__( 'Columns', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Auto', 'phase' ) => 'default',
						esc_html__( 'Two', 'phase' ) => 2,
						esc_html__( 'Three', 'phase' ) => 3,
						esc_html__( 'Four', 'phase' ) => 4,
						esc_html__( 'Six', 'phase' ) => 6,
						esc_html__( 'One', 'phase' ) => 1,
					),
					'std' => 'default',
					'admin_label' => true,
					'description' => esc_html__( 'By default, columns are set automatically depending on the container\'s width. Set a column count here to overwrite the default behavior.', 'phase' ),
					'dependency' => array(
						'element' => 'post_display',
						'value_not_equal_to' => array( 'standard', 'standard_modern' ),
					),
					'group' => esc_html__( 'Extra', 'phase' ),
				),
			),
			//),

			// 	array(
			// 		'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
			// 		'param_name' => 'inline_style',
			// 		'type' => 'wvc_textfield',
			// 		//'admin_label' => true,
			// 	),
			// ),
		//)
	)
);

class WPBakeryShortCode_Wvc_Work_Index extends WPBakeryShortCode {}
} // end Portfolio plugin check

if ( class_exists( 'WooCommerce' ) ) {

/**
 * Product Loop Module
 */
vc_map(
	array(
		'name' => esc_html__( 'Products', 'phase' ),
		'description' => esc_html__( 'Display your pages using the theme layouts', 'phase' ),
		'base' => 'wvc_product_index',
		'category' => esc_html__( 'Content' , 'phase' ),
		'icon' => 'fa fa-th',
		'weight' => 999,
		'params' =>
		//array_merge(
			array(

				array(
					'type' => 'hidden',
					'heading' => esc_html__( 'ID', 'phase' ),
					'value' => 'items-' . rand( 0,99999 ),
					'param_name' => 'el_id',
				),

				array(
					'param_name' => 'product_display',
					'heading' => esc_html__( 'Product Display', 'phase' ),
					'type' => 'dropdown',
					'value' => array_flip( apply_filters( 'phase_product_display_options', array(
						'grid_classic' => esc_html__( 'Classic', 'phase' ),
					) ) ),
					'std' => 'grid_classic',
					'admin_label' => true,
				),

				array(
					'param_name' => 'product_text_align',
					'heading' => esc_html__( 'Product Text Alignement', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						'' => '',
						esc_html__( 'Center', 'phase' ) => 'center',
						esc_html__( 'Left', 'phase' ) => 'left',
						esc_html__( 'Right', 'phase' ) => 'right',
					),
					//'std' => '',
					'admin_label' => true,
					'dependency' => array( 'element' => 'product_display', 'value' => array( 'grid_classic' ) ),
				),

				array(
					'param_name' => 'product_meta',
					'heading' => esc_html__( 'Type', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'All', 'phase' ) => 'all',
						esc_html__( 'Featured', 'phase' ) => 'featured',
						esc_html__( 'On Sale', 'phase' ) => 'onsale',
						esc_html__( 'Best Selling', 'phase' ) => 'best_selling',
						esc_html__( 'Top Rated', 'phase' ) => 'top_rated',
					),
					'admin_label' => true,
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Category', 'phase' ),
					'param_name' => 'product_cat',
					'description' => esc_html__( 'Include only one or several categories. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'admin_label' => true,
				),

				array(
					'param_name' => 'product_module',
					'heading' => esc_html__( 'Module', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Grid', 'phase' ) => 'grid',
						esc_html__( 'Carousel', 'phase' ) => 'carousel',
					),
					'admin_label' => true,
					//'dependency' => array( 'element' => 'work_layout', 'value' => array( 'overlay', 'flip-box' ) ),
				),

				array(
					'param_name' => 'grid_padding',
					'heading' => esc_html__( 'Padding', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Yes', 'phase' ) => 'yes',
						esc_html__( 'No', 'phase' ) => 'no',
					),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Animation', 'phase' ),
					'param_name' => 'item_animation',
					'type' => 'dropdown',
					'value' => array_flip( phase_get_animations() ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Posts Per Page', 'phase' ),
					'param_name' => 'posts_per_page',
					'type' => 'wvc_textfield',
					'placeholder' => get_option( 'posts_per_page' ),
					'description' => esc_html__( 'Leave empty to display all post at once.', 'phase' ),
					'std' => get_option( 'posts_per_page' ),
					'admin_label' => true,
				),

				array(
					'param_name' => 'pagination',
					'heading' => esc_html__( 'Pagination', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'None', 'phase' ) => 'none',
						esc_html__( 'Load More', 'phase' ) => 'load_more',
						esc_html__( 'Numeric Pagination', 'phase' ) => 'standard_pagination',
						esc_html__( 'Link to Shop', 'phase' ) => 'link_to_shop',
					),
					'admin_label' => true,
					'dependency' => array( 'element' => 'product_module', 'value' => array( 'grid' ) ),
				),

				array(
					'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
					'param_name' => 'inline_style',
					'type' => 'wvc_textfield',
					//'admin_label' => true,
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Offset', 'phase' ),
					'param_name' => 'offset',
					'description' => esc_html__( 'The amount of posts that should be skipped in the beginning of the query. If an offset is set, sticky posts will be ignored.', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
					'admin_label' => true,
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Order by', 'phase' ),
					'param_name' => 'orderby',
					'value' => $order_by_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Select how to sort retrieved products. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Sort order', 'phase' ),
					'param_name' => 'order',
					'value' => $order_way_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Designates the ascending or descending order. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Post IDs', 'phase' ),
					'description' => esc_html__( 'By default, your last posts will be displayed. You can choose the posts you want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'include_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Post IDs', 'phase' ),
					'description' => esc_html__( 'You can choose the posts you don\'t want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'exclude_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'param_name' => 'columns',
					'heading' => esc_html__( 'Columns', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Auto', 'phase' ) => 'default',
						esc_html__( 'Two', 'phase' ) => 2,
						esc_html__( 'Three', 'phase' ) => 3,
						esc_html__( 'Four', 'phase' ) => 4,
						esc_html__( 'Six', 'phase' ) => 6,
						esc_html__( 'One', 'phase' ) => 1,
					),
					'std' => 'default',
					'admin_label' => true,
					'description' => esc_html__( 'By default, columns are set automatically depending on the container\'s width. Set a column count here to overwrite the default behavior.', 'phase' ),
					'dependency' => array(
						'element' => 'post_display',
						'value_not_equal_to' => array( 'standard', 'standard_modern' ),
					),
					'group' => esc_html__( 'Extra', 'phase' ),
				),
			),
			//),

			// 	array(
			// 		'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
			// 		'param_name' => 'inline_style',
			// 		'type' => 'wvc_textfield',
			// 		//'admin_label' => true,
			// 	),
			// ),
		//)
	)
);

class WPBakeryShortCode_Wvc_Product_Index extends WPBakeryShortCode {}

} // end WC check

if ( class_exists( 'Wolf_Videos' ) ) {
/**
 * Videos Loop Module
 */
vc_map(
	array(
		'name' => esc_html__( 'Videos', 'phase' ),
		'description' => esc_html__( 'Display your videos using the theme layouts', 'phase' ),
		'base' => 'wvc_video_index',
		'category' => esc_html__( 'Content' , 'phase' ),
		'icon' => 'fa fa-th',
		'weight' => 999,
		'params' =>
		//array_merge(
			array(

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Index ID', 'phase' ),
					'value' => 'index-' . rand( 0,99999 ),
					'param_name' => 'el_id',
					'description' => esc_html__( 'A unique identifier for the post module (required).', 'phase' ),
				),

				array(
					'param_name' => 'video_display',
					'heading' => esc_html__( 'Videos Display', 'phase' ),
					'type' => 'dropdown',
					'value' => array_flip( apply_filters( 'phase_video_display_options', array(
						'grid' => esc_html__( 'Grid', 'phase' ),
					) ) ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Show video on hover', 'phase' ),
					'param_name' => 'video_preview',
					'type' => 'checkbox',
					'admin_label' => true,
					'value' => 'yes',
					'dependency' => array( 'element' => 'video_module', 'value' => array( 'grid' ) ),
				),

				array(
					'param_name' => 'video_module',
					'heading' => esc_html__( 'Module', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Grid', 'phase' ) => 'grid',
						esc_html__( 'Carousel', 'phase' ) => 'carousel',
					),
					'admin_label' => true,
					//'dependency' => array( 'element' => 'video_display', 'value' => array( 'grid' ) ),
				),

				array(
					'param_name' => 'grid_padding',
					'heading' => esc_html__( 'Padding', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Yes', 'phase' ) => 'yes',
						esc_html__( 'No', 'phase' ) => 'no',
					),
					'admin_label' => true,
				),

				array(
					'param_name' => 'video_onclick',
					'heading' => esc_html__( 'On Click', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Open Video in Lightbox', 'phase' ) => 'lightbox',
						esc_html__( 'Go to the Video Page', 'phase' ) => 'default',
					),
					'admin_label' => true,
					//'dependency' => array( 'element' => 'video_display', 'value' => array( 'grid' ) ),
				),

				array(
					'heading' => esc_html__( 'Category Filter', 'phase' ),
					'param_name' => 'video_category_filter',
					'type' => 'checkbox',
					'admin_label' => true,
					'description' => esc_html__( 'The pagination will be disabled.', 'phase' ),
					'dependency' => array( 'element' => 'video_module', 'value' => array( 'grid' ) ),
				),

				array(
					'heading' => esc_html__( 'Filter Text Alignement', 'phase' ),
					'param_name' => 'video_category_filter_text_alignment',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Center', 'phase' ) => 'center',
						esc_html__( 'Left', 'phase' ) => 'left',
						esc_html__( 'Right', 'phase' ) => 'right',
					),
					'dependency' => array(
						'element' => 'video_category_filter',
						'value' => array( 'true' ),
					),
				),

				array(
					'heading' => esc_html__( 'Animation', 'phase' ),
					'param_name' => 'item_animation',
					'type' => 'dropdown',
					'value' => array_flip( phase_get_animations() ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Number of Posts', 'phase' ),
					'param_name' => 'posts_per_page',
					'type' => 'wvc_textfield',
					//'placeholder' => get_option( 'posts_per_page' ),
					'description' => esc_html__( 'Leave empty to display all post at once.', 'phase' ),
					//'std' => '-1',
					'admin_label' => true,
				),

				array(
					'param_name' => 'pagination',
					'heading' => esc_html__( 'Pagination', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'None', 'phase' ) => 'none',
						esc_html__( 'Load More', 'phase' ) => 'load_more',
						esc_html__( 'Numeric Pagination', 'phase' ) => 'standard_pagination',
						esc_html__( 'Link to Video Archives', 'phase' ) => 'link_to_videos',
					),
					// 'dependency' => array(
					// 	'element' => 'video_category_filter',
					// 	'not_equal_to' => array( true )
					// ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
					'param_name' => 'inline_style',
					'type' => 'wvc_textfield',
					//'admin_label' => true,
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Include Category', 'phase' ),
					'param_name' => 'video_type_include',
					'description' => esc_html__( 'Enter one or several categories. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Category', 'phase' ),
					'param_name' => 'video_type_exclude',
					'description' => esc_html__( 'Enter one or several categories. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Offset', 'phase' ),
					'description' => esc_html__( '.', 'phase' ),
					'param_name' => 'offset',
					'description' => esc_html__( 'The amount of posts that should be skipped in the beginning of the query.', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Order by', 'phase' ),
					'param_name' => 'orderby',
					'value' => $order_by_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Select how to sort retrieved posts. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Sort order', 'phase' ),
					'param_name' => 'order',
					'value' => $order_way_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Designates the ascending or descending order. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Post IDs', 'phase' ),
					'description' => esc_html__( 'By default, your last posts will be displayed. You can choose the posts you want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'include_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Post IDs', 'phase' ),
					'description' => esc_html__( 'You can choose the posts you don\'t want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'exclude_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'param_name' => 'columns',
					'heading' => esc_html__( 'Columns', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Auto', 'phase' ) => 'default',
						esc_html__( 'Two', 'phase' ) => 2,
						esc_html__( 'Three', 'phase' ) => 3,
						esc_html__( 'Four', 'phase' ) => 4,
						esc_html__( 'Six', 'phase' ) => 6,
						esc_html__( 'One', 'phase' ) => 1,
					),
					'std' => 'default',
					'admin_label' => true,
					'description' => esc_html__( 'By default, columns are set automatically depending on the container\'s width. Set a column count here to overwrite the default behavior.', 'phase' ),
					'dependency' => array(
						'element' => 'post_display',
						'value_not_equal_to' => array( 'standard', 'standard_modern' ),
					),
					'group' => esc_html__( 'Extra', 'phase' ),
				),
			),
			//),

			// 	array(
			// 		'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
			// 		'param_name' => 'inline_style',
			// 		'type' => 'wvc_textfield',
			// 		//'admin_label' => true,
			// 	),
			// ),
		//)
	)
);

class WPBakeryShortCode_Wvc_Video_Index extends WPBakeryShortCode {}
} // end Videos plugin check

if ( class_exists( 'Wolf_Discography' ) ) {
/**
 * Discography Loop Module
 */
vc_map(
	array(
		'name' => esc_html__( 'Releases', 'phase' ),
		'description' => esc_html__( 'Display your releases using the theme layouts', 'phase' ),
		'base' => 'wvc_release_index',
		'category' => esc_html__( 'Content' , 'phase' ),
		'icon' => 'fa fa-th',
		'weight' => 999,
		'params' =>
		//array_merge(
			array(

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Index ID', 'phase' ),
					'value' => 'index-' . rand( 0,99999 ),
					'param_name' => 'el_id',
					'description' => esc_html__( 'A unique identifier for the post module (required).', 'phase' ),
				),

				array(
					'param_name' => 'release_display',
					'heading' => esc_html__( 'Release Display', 'phase' ),
					'type' => 'dropdown',
					'value' => array_flip( apply_filters( 'phase_release_display_options', array(
						'grid' => esc_html__( 'Grid', 'phase' ),
					) ) ),
					'admin_label' => true,
				),

				array(
					'param_name' => 'release_alternate_thumbnail_position',
					'heading' => esc_html__( 'Alternate thumbnail position', 'phase' ),
					'type' => 'checkbox',
					'dependency' => array(
						'element' => 'release_display',
						'value' => array( 'lateral' ),
					),
				),

				array(
					'param_name' => 'release_layout',
					'heading' => esc_html__( 'Layout', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Classic', 'phase' ) => 'standard',
						esc_html__( 'Overlay', 'phase' ) => 'overlay',
						//esc_html__( 'Flip Box', 'phase' ) => 'flip-box',
					),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'release_display',
						'value' => array( 'grid', 'metro', 'masonry' )
					),
				),

				array(
					'param_name' => 'release_module',
					'heading' => esc_html__( 'Module', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Grid', 'phase' ) => 'grid',
						esc_html__( 'Carousel', 'phase' ) => 'carousel',
					),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'release_display', 'value' => array( 'grid' ) ),
				),

				array(
					'param_name' => 'grid_padding',
					'heading' => esc_html__( 'Padding', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Yes', 'phase' ) => 'yes',
						esc_html__( 'No', 'phase' ) => 'no',
					),
					'admin_label' => true,
					'dependency' => array( 'element' => 'release_layout', 'value' => array( 'overlay', 'flip-box' ) ),
				),

				// array(
				// 	'type' => 'dropdown',
				// 	'heading' => esc_html__( 'Text Alignment', 'phase' ),
				// 	'param_name' => 'work_caption_align',
				// 	'value' => array(
				// 		esc_html__( 'Center', 'phase' ) => 'center',
				// 		esc_html__( 'Left', 'phase' ) => 'left',
				// 		esc_html__( 'Right', 'phase' ) => 'right',
				// 	),
				// ),

				// array(
				// 	'type' => 'dropdown',
				// 	'heading' => esc_html__( 'Text Vertical Alignment', 'phase' ),
				// 	'param_name' => 'work_caption_valign',
				// 	'value' => array(
				// 		esc_html__( 'Middle', 'phase' ) => 'middle',
				// 		esc_html__( 'Bottom', 'phase' ) => 'bottom',
				// 		esc_html__( 'Top', 'phase' ) => 'top',
				// 	),
				// ),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Overlay Color', 'phase' ),
					'param_name' => 'overlay_color',
					'value' => array_merge(
							array( esc_html__( 'Auto', 'phase' ) => 'auto', ),
							$shared_gradient_colors,
							$shared_colors,
							array( esc_html__( 'Custom color', 'phase' ) => 'custom', )
					),
					'std' => apply_filters( 'wvc_default_item_overlay_color', 'black' ),
					'description' => esc_html__( 'Select an overlay color.', 'phase' ),
					'param_holder_class' => 'wvc_colored-dropdown',
					'dependency' => array( 'element' => 'release_layout', 'value' => array( 'overlay', 'flip-box' ) ),
				),

				// Overlay color
				array(
					'type' => 'colorpicker',
					'heading' => esc_html__( 'Overlay Custom Color', 'phase' ),
					'param_name' => 'overlay_custom_color',
					//'value' => '#000000',
					'dependency' => array( 'element' => 'overlay_color', 'value' => array( 'custom' ), ),
				),

				// Overlay opacity
				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Overlay Opacity in Percent', 'phase' ),
					'param_name' => 'overlay_opacity',
					'description' => '',
					'value' => 40,
					'std' => apply_filters( 'wvc_default_item_overlay_opacity', 40 ),
					'dependency' => array( 'element' => 'release_layout', 'value' => array( 'overlay', 'flip-box' ), ),
				),

				// Overlay text color
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Overlay Text Color', 'phase' ),
					'param_name' => 'overlay_text_color',
					'value' => array_merge(
						$shared_colors,
						$shared_gradient_colors,
						array( esc_html__( 'Custom color', 'phase' ) => 'custom', )
					),
					'std' => apply_filters( 'wvc_default_item_overlay_text_color', 'white' ),
					'description' => esc_html__( 'Select an overlay color.', 'phase' ),
					'param_holder_class' => 'wvc_colored-dropdown',
					'dependency' => array( 'element' => 'release_layout', 'value' => array( 'overlay', 'flip-box' ), ),
				),

				array(
					'type' => 'colorpicker',
					'heading' => esc_html__( 'Overlay Custom Text Color', 'phase' ),
					'param_name' => 'overlay_text_custom_color',
					//'value' => '#000000',
					'dependency' => array( 'element' => 'overlay_text_color', 'value' => array( 'custom' ), ),
				),

				array(
					'param_name' => 'pagination',
					'heading' => esc_html__( 'Pagination', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'None', 'phase' ) => 'none',
						esc_html__( 'Load More', 'phase' ) => 'load_more',
						esc_html__( 'Numeric Pagination', 'phase' ) => 'standard_pagination',
						esc_html__( 'Link to Discography', 'phase' ) => 'link_to_discography',
					),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Category Filter', 'phase' ),
					'param_name' => 'release_category_filter',
					'type' => 'checkbox',
					'description' => esc_html__( 'The pagination will be disabled.', 'phase' ),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'release_display',
						'value_not_equal_to' => array( 'list_minimal' )
					),
				),

				array(
					'heading' => esc_html__( 'Filter Text Alignement', 'phase' ),
					'param_name' => 'release_category_filter_text_alignment',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Center', 'phase' ) => 'center',
						esc_html__( 'Left', 'phase' ) => 'left',
						esc_html__( 'Right', 'phase' ) => 'right',
					),
					'dependency' => array(
						'element' => 'release_category_filter',
						'value' => array( 'true' ),
					),
				),

				array(
					'heading' => esc_html__( 'Animation', 'phase' ),
					'param_name' => 'item_animation',
					'type' => 'dropdown',
					'value' => array_flip( phase_get_animations() ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Number of Posts', 'phase' ),
					'param_name' => 'posts_per_page',
					'type' => 'wvc_textfield',
					//'placeholder' => get_option( 'posts_per_page' ),
					'description' => esc_html__( 'Leave empty to display all post at once.', 'phase' ),
					//'std' => '-1',
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
					'param_name' => 'inline_style',
					'type' => 'wvc_textfield',
					//'admin_label' => true,
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Include Band', 'phase' ),
					'param_name' => 'band_include',
					'description' => esc_html__( 'Enter one or several bands. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Band', 'phase' ),
					'param_name' => 'band_exclude',
					'description' => esc_html__( 'Enter one or several bands. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Include Label', 'phase' ),
					'param_name' => 'label_include',
					'description' => esc_html__( 'Enter one or several labels. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Label', 'phase' ),
					'param_name' => 'label_exclude',
					'description' => esc_html__( 'Enter one or several labels. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Offset', 'phase' ),
					'description' => esc_html__( '.', 'phase' ),
					'param_name' => 'offset',
					'description' => esc_html__( 'The amount of posts that should be skipped in the beginning of the query.', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Order by', 'phase' ),
					'param_name' => 'orderby',
					'value' => $order_by_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Select how to sort retrieved posts. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Sort order', 'phase' ),
					'param_name' => 'order',
					'value' => $order_way_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Designates the ascending or descending order. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Post IDs', 'phase' ),
					'description' => esc_html__( 'By default, your last posts will be displayed. You can choose the posts you want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'include_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Post IDs', 'phase' ),
					'description' => esc_html__( 'You can choose the posts you don\'t want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'exclude_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'param_name' => 'columns',
					'heading' => esc_html__( 'Columns', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Auto', 'phase' ) => 'default',
						esc_html__( 'Two', 'phase' ) => 2,
						esc_html__( 'Three', 'phase' ) => 3,
						esc_html__( 'Four', 'phase' ) => 4,
						esc_html__( 'Six', 'phase' ) => 6,
						esc_html__( 'One', 'phase' ) => 1,
					),
					'std' => 'default',
					'admin_label' => true,
					'description' => esc_html__( 'By default, columns are set automatically depending on the container\'s width. Set a column count here to overwrite the default behavior.', 'phase' ),
					'dependency' => array(
						'element' => 'post_display',
						'value_not_equal_to' => array( 'standard', 'standard_modern', 'lateral' ),
					),
					'group' => esc_html__( 'Extra', 'phase' ),
				),
			),
			//),

			// 	array(
			// 		'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
			// 		'param_name' => 'inline_style',
			// 		'type' => 'wvc_textfield',
			// 		//'admin_label' => true,
			// 	),
			// ),
		//)
	)
);

class WPBakeryShortCode_Wvc_Release_Index extends WPBakeryShortCode {}
} // end Discography plugin check

if ( class_exists( 'Wolf_Events' ) ) {
/**
 * Events Loop Module
 */
vc_map(
	array(
		'name' => esc_html__( 'Events', 'phase' ),
		'description' => esc_html__( 'Display your events using the theme layouts', 'phase' ),
		'base' => 'wvc_event_index',
		'category' => esc_html__( 'Content' , 'phase' ),
		'icon' => 'fa fa-th',
		'weight' => 999,
		'params' =>
		//array_merge(
			array(

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Index ID', 'phase' ),
					'value' => 'index-' . rand( 0,99999 ),
					'param_name' => 'el_id',
					'description' => esc_html__( 'A unique identifier for the post module (required).', 'phase' ),
				),

				array(
					'param_name' => 'event_display',
					'heading' => esc_html__( 'Event Display', 'phase' ),
					'type' => 'dropdown',
					'value' => array_flip( apply_filters( 'phase_event_display_options', array(
						'list' => esc_html__( 'List', 'phase' ),
					) ) ),
					'admin_label' => true,
				),

				array(
					'param_name' => 'event_module',
					'heading' => esc_html__( 'Module', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Grid', 'phase' ) => 'grid',
						esc_html__( 'Carousel', 'phase' ) => 'carousel',
					),
					'admin_label' => true,
					'dependency' => array( 'element' => 'event_display', 'value' => array( 'grid' ) ),
				),

				array(
					'param_name' => 'event_location',
					'heading' => esc_html__( 'Location', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Location', 'phase' ) => 'location',
						esc_html__( 'Venue', 'phase' ) => 'venue',
					),
					'admin_label' => true,
					'dependency' => array( 'element' => 'event_display', 'value' => array( 'grid' ) ),
				),

				array(
					'param_name' => 'grid_padding',
					'heading' => esc_html__( 'Padding', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Yes', 'phase' ) => 'yes',
						esc_html__( 'No', 'phase' ) => 'no',
					),
					'admin_label' => true,
					'dependency' => array( 'element' => 'event_display', 'value' => array( 'grid' ) ),
				),

				array(
					'param_name' => 'event_thumbnail_size',
					'heading' => esc_html__( 'Thumbnail Size', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Default Thumbnail', 'phase' ) => 'standard',
						esc_html__( 'Landscape', 'phase' ) => 'landscape',
						esc_html__( 'Square', 'phase' ) => 'square',
						esc_html__( 'Portrait', 'phase' ) => 'portrait',
					),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'event_display',
						'value' => array( 'grid' ),
						// value_not_equal_to
					),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Overlay Color', 'phase' ),
					'param_name' => 'overlay_color',
					'value' => array_merge(
							array( esc_html__( 'Auto', 'phase' ) => 'auto', ),
							$shared_gradient_colors,
							$shared_colors,
							array( esc_html__( 'Custom color', 'phase' ) => 'custom', )
					),
					'std' => apply_filters( 'wvc_default_item_overlay_color', 'black' ),
					'description' => esc_html__( 'Select an overlay color.', 'phase' ),
					'param_holder_class' => 'wvc_colored-dropdown',
					'dependency' => array( 'element' => 'event_display', 'value' => array( 'grid') ),
				),

				// Overlay color
				array(
					'type' => 'colorpicker',
					'heading' => esc_html__( 'Overlay Custom Color', 'phase' ),
					'param_name' => 'overlay_custom_color',
					//'value' => '#000000',
					'dependency' => array( 'element' => 'overlay_color', 'value' => array( 'custom' ), ),
				),

				// Overlay opacity
				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Overlay Opacity in Percent', 'phase' ),
					'param_name' => 'overlay_opacity',
					'description' => '',
					'value' => 40,
					'std' => apply_filters( 'wvc_default_item_overlay_opacity', 40 ),
					'dependency' => array( 'element' => 'event_display', 'value' => array( 'grid' ) ),
				),

				// Overlay text color
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Overlay Text Color', 'phase' ),
					'param_name' => 'overlay_text_color',
					'value' => array_merge(
						$shared_colors,
						$shared_gradient_colors,
						array( esc_html__( 'Custom color', 'phase' ) => 'custom', )
					),
					'std' => apply_filters( 'wvc_default_item_overlay_text_color', 'white' ),
					'description' => esc_html__( 'Select an overlay color.', 'phase' ),
					'param_holder_class' => 'wvc_colored-dropdown',
					'dependency' => array( 'element' => 'event_display', 'value' => array( 'grid') ),
				),

				array(
					'type' => 'colorpicker',
					'heading' => esc_html__( 'Overlay Custom Text Color', 'phase' ),
					'param_name' => 'overlay_text_custom_color',
					//'value' => '#000000',
					'dependency' => array( 'element' => 'overlay_text_color', 'value' => array( 'custom' ), ),
				),

				array(
					'param_name' => 'pagination',
					'heading' => esc_html__( 'Pagination', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'None', 'phase' ) => 'none',
						//esc_html__( 'Load More', 'phase' ) => 'load_more',
						esc_html__( 'Link to Event Archives', 'phase' ) => 'link_to_events',
					),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Animation', 'phase' ),
					'param_name' => 'item_animation',
					'type' => 'dropdown',
					'value' => array_flip( phase_get_animations() ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Number of Posts', 'phase' ),
					'param_name' => 'posts_per_page',
					'type' => 'wvc_textfield',
					//'placeholder' => get_option( 'posts_per_page' ),
					'description' => esc_html__( 'Leave empty to display all post at once.', 'phase' ),
					//'std' => '-1',
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
					'param_name' => 'inline_style',
					'type' => 'wvc_textfield',
					//'admin_label' => true,
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Timeline', 'phase' ),
					'param_name' => 'timeline',
					'value' => array(
						esc_html__( 'Future', 'phase' ) => 'future',
						esc_html__( 'Past', 'phase' ) => 'past',
					),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Include Artist', 'phase' ),
					'param_name' => 'artist_include',
					'description' => esc_html__( 'Enter one or several bands. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Artist', 'phase' ),
					'param_name' => 'artist_exclude',
					'description' => esc_html__( 'Enter one or several bands. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Offset', 'phase' ),
					'description' => esc_html__( '.', 'phase' ),
					'param_name' => 'offset',
					'description' => esc_html__( 'The amount of posts that should be skipped in the beginning of the query.', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'param_name' => 'columns',
					'heading' => esc_html__( 'Columns', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Auto', 'phase' ) => 'default',
						esc_html__( 'Two', 'phase' ) => 2,
						esc_html__( 'Three', 'phase' ) => 3,
						esc_html__( 'Four', 'phase' ) => 4,
						esc_html__( 'Six', 'phase' ) => 6,
						esc_html__( 'One', 'phase' ) => 1,
					),
					'std' => 'default',
					'admin_label' => true,
					'description' => esc_html__( 'By default, columns are set automatically depending on the container\'s width. Set a column count here to overwrite the default behavior.', 'phase' ),
					'dependency' => array(
						'element' => 'post_display',
						'value_not_equal_to' => array( 'standard', 'standard_modern' ),
					),
					'group' => esc_html__( 'Extra', 'phase' ),
				),
			),
			//),

			// 	array(
			// 		'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
			// 		'param_name' => 'inline_style',
			// 		'type' => 'wvc_textfield',
			// 		//'admin_label' => true,
			// 	),
			// ),
		//)
	)
);

class WPBakeryShortCode_Wvc_Event_Index extends WPBakeryShortCode {}
} // end Events plugin check

if ( class_exists( 'Wolf_Artists' ) ) {

/**
 * Work Loop Module
 */
vc_map(
	array(
		'name' => esc_html__( 'Artists', 'phase' ),
		'description' => esc_html__( 'Display your artists using the theme layouts', 'phase' ),
		'base' => 'wvc_artist_index',
		'category' => esc_html__( 'Content' , 'phase' ),
		'icon' => 'fa fa-th',
		'weight' => 999,
		'params' =>
		//array_merge(
			array(

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Index ID', 'phase' ),
					'value' => 'index-' . rand( 0,99999 ),
					'param_name' => 'el_id',
					'description' => esc_html__( 'A unique identifier for the post module (required).', 'phase' ),
				),

				array(
					'param_name' => 'artist_display',
					'heading' => esc_html__( 'Artist Display', 'phase' ),
					'type' => 'dropdown',
					'value' => array_flip( apply_filters( 'phase_artist_display_options', array(
						'list' => esc_html__( 'List', 'phase' ),
					) ) ),
					'admin_label' => true,
				),

				array(
					'param_name' => 'artist_module',
					'heading' => esc_html__( 'Module', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Grid', 'phase' ) => 'grid',
						esc_html__( 'Carousel', 'phase' ) => 'carousel',
					),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'artist_display',
						'value' => array( 'grid' )
					),
				),

				array(
					'param_name' => 'artist_thumbnail_size',
					'heading' => esc_html__( 'Thumbnail Size', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Default Thumbnail', 'phase' ) => 'standard',
						esc_html__( 'Landscape', 'phase' ) => 'landscape',
						esc_html__( 'Square', 'phase' ) => 'square',
						esc_html__( 'Portrait', 'phase' ) => 'portrait',
					),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'artist_display',
						'value' => array( 'grid', 'offgrid' ),
						// value_not_equal_to
					),
				),

				array(
					'param_name' => 'artist_layout',
					'heading' => esc_html__( 'Layout', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Classic', 'phase' ) => 'standard',
						esc_html__( 'Overlay', 'phase' ) => 'overlay',
						//esc_html__( 'Flip Box', 'phase' ) => 'flip-box',
					),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'artist_display',
						'value_not_equal_to' => array( 'list' )
					),
				),

				array(
					'param_name' => 'grid_padding',
					'heading' => esc_html__( 'Padding', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Yes', 'phase' ) => 'yes',
						esc_html__( 'No', 'phase' ) => 'no',
					),
					'admin_label' => true,
					//'dependency' => array( 'element' => 'artist_layout', 'value' => array( 'overlay', 'flip-box' ) ),
				),

				array(
					'heading' => esc_html__( 'Caption Text Alignement', 'phase' ),
					'param_name' => 'caption_text_alignment',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Center', 'phase' ) => 'center',
						esc_html__( 'Left', 'phase' ) => 'left',
						esc_html__( 'Right', 'phase' ) => 'right',
					),
					'dependency' => array(
						'element' => 'artist_display',
						'value_not_equal_to' => array( 'list_minimal' )
					),
				),

				array(
					'heading' => esc_html__( 'Caption Vertical Alignement', 'phase' ),
					'param_name' => 'caption_v_align',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Middle', 'phase' ) => 'middle',
						esc_html__( 'Bottom', 'phase' ) => 'bottom',
						esc_html__( 'Top', 'phase' ) => 'top',
					),
					'dependency' => array(
						'element' => 'artist_display',
						'value_not_equal_to' => array( 'list_minimal' )
					),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Overlay Color', 'phase' ),
					'param_name' => 'overlay_color',
					'value' => array_merge(
							array( esc_html__( 'Auto', 'phase' ) => 'auto', ),
							$shared_gradient_colors,
							$shared_colors,
							array( esc_html__( 'Custom color', 'phase' ) => 'custom', )
					),
					'std' => apply_filters( 'wvc_default_item_overlay_color', 'black' ),
					'description' => esc_html__( 'Select an overlay color.', 'phase' ),
					'param_holder_class' => 'wvc_colored-dropdown',
					'dependency' => array( 'element' => 'artist_layout', 'value' => array( 'overlay', 'flip-box' ) ),
				),

				// Overlay color
				array(
					'type' => 'colorpicker',
					'heading' => esc_html__( 'Overlay Custom Color', 'phase' ),
					'param_name' => 'overlay_custom_color',
					//'value' => '#000000',
					'dependency' => array( 'element' => 'overlay_color', 'value' => array( 'custom' ), ),
				),

				// Overlay opacity
				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Overlay Opacity in Percent', 'phase' ),
					'param_name' => 'overlay_opacity',
					'description' => '',
					'value' => 40,
					'std' => apply_filters( 'wvc_default_item_overlay_opacity', 40 ),
					'dependency' => array( 'element' => 'artist_layout', 'value' => array( 'overlay', 'flip-box' ), ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Overlay Text Color', 'phase' ),
					'param_name' => 'overlay_text_color',
					'value' => array_merge(
						$shared_colors,
						$shared_gradient_colors,
						array( esc_html__( 'Custom color', 'phase' ) => 'custom', )
					),
					'std' => apply_filters( 'wvc_default_item_overlay_text_color', 'white' ),
					'description' => esc_html__( 'Select an overlay color.', 'phase' ),
					'param_holder_class' => 'wvc_colored-dropdown',
					'dependency' => array( 'element' => 'artist_layout', 'value' => array( 'overlay', 'flip-box' ) ),
				),

				// Overlay color
				array(
					'type' => 'colorpicker',
					'heading' => esc_html__( 'Overlay Custom Text Color', 'phase' ),
					'param_name' => 'overlay_text_custom_color',
					//'value' => '#000000',
					'dependency' => array( 'element' => 'overlay_text_color', 'value' => array( 'custom' ), ),
				),

				array(
					'heading' => esc_html__( 'Category Filter', 'phase' ),
					'param_name' => 'artist_category_filter',
					'type' => 'checkbox',
					'description' => esc_html__( 'The pagination will be disabled.', 'phase' ),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'artist_display',
						'value_not_equal_to' => array( 'list_minimal' )
					),
				),

				array(
					'heading' => esc_html__( 'Filter Text Alignement', 'phase' ),
					'param_name' => 'artist_category_filter_text_alignment',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Center', 'phase' ) => 'center',
						esc_html__( 'Left', 'phase' ) => 'left',
						esc_html__( 'Right', 'phase' ) => 'right',
					),
					'dependency' => array(
						'element' => 'artist_category_filter',
						'value' => array( 'true' ),
					),
				),

				array(
					'heading' => esc_html__( 'Animation', 'phase' ),
					'param_name' => 'item_animation',
					'type' => 'dropdown',
					'value' => array_flip( phase_get_animations() ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Number of Posts', 'phase' ),
					'param_name' => 'posts_per_page',
					'type' => 'wvc_textfield',
					//'placeholder' => get_option( 'posts_per_page' ),
					'description' => esc_html__( 'Leave empty to display all post at once.', 'phase' ),
					//'std' => '-1',
					'admin_label' => true,
				),

				array(
					'param_name' => 'pagination',
					'heading' => esc_html__( 'Pagination', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'None', 'phase' ) => 'none',
						esc_html__( 'Load More', 'phase' ) => 'load_more',
						esc_html__( 'Numeric Pagination', 'phase' ) => 'standard_pagination',
						esc_html__( 'Link to Archives', 'phase' ) => 'link_to_artists',
					),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
					'param_name' => 'inline_style',
					'type' => 'wvc_textfield',
					//'admin_label' => true,
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Include Category', 'phase' ),
					'param_name' => 'artist_genre_include',
					'description' => esc_html__( 'Enter one or several categories. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Category', 'phase' ),
					'param_name' => 'artist_genre_exclude',
					'description' => esc_html__( 'Enter one or several categories. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Offset', 'phase' ),
					'description' => esc_html__( '.', 'phase' ),
					'param_name' => 'offset',
					'description' => esc_html__( 'The amount of posts that should be skipped in the beginning of the query.', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Order by', 'phase' ),
					'param_name' => 'orderby',
					'value' => $order_by_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Select how to sort retrieved posts. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Sort order', 'phase' ),
					'param_name' => 'order',
					'value' => $order_way_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Designates the ascending or descending order. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Post IDs', 'phase' ),
					'description' => esc_html__( 'By default, your last posts will be displayed. You can choose the posts you want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'include_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Post IDs', 'phase' ),
					'description' => esc_html__( 'You can choose the posts you don\'t want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'exclude_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'param_name' => 'columns',
					'heading' => esc_html__( 'Columns', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Auto', 'phase' ) => 'default',
						esc_html__( 'Two', 'phase' ) => 2,
						esc_html__( 'Three', 'phase' ) => 3,
						esc_html__( 'Four', 'phase' ) => 4,
						esc_html__( 'Six', 'phase' ) => 6,
						esc_html__( 'One', 'phase' ) => 1,
					),
					'std' => 'default',
					'admin_label' => true,
					'description' => esc_html__( 'By default, columns are set automatically depending on the container\'s width. Set a column count here to overwrite the default behavior.', 'phase' ),
					'dependency' => array(
						'element' => 'post_display',
						'value_not_equal_to' => array( 'standard', 'standard_modern' ),
					),
					'group' => esc_html__( 'Extra', 'phase' ),
				),
			),
			//),

			// 	array(
			// 		'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
			// 		'param_name' => 'inline_style',
			// 		'type' => 'wvc_textfield',
			// 		//'admin_label' => true,
			// 	),
			// ),
		//)
	)
);

class WPBakeryShortCode_Wvc_Artist_Index extends WPBakeryShortCode {}
} // end Artist plugin check


if ( class_exists( 'Wolf_Albums' ) ) {

/**
 * Albums Loop Module
 */
vc_map(
	array(
		'name' => esc_html__( 'Albums', 'phase' ),
		'description' => esc_html__( 'Display your albums using the theme layouts', 'phase' ),
		'base' => 'wvc_gallery_index',
		'category' => esc_html__( 'Content' , 'phase' ),
		'icon' => 'fa fa-th',
		'weight' => 999,
		'params' =>
		//array_merge(
			array(

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Index ID', 'phase' ),
					'value' => 'index-' . rand( 0,99999 ),
					'param_name' => 'el_id',
					'description' => esc_html__( 'A unique identifier for the post module (required).', 'phase' ),
				),

				array(
					'param_name' => 'gallery_display',
					'heading' => esc_html__( 'Album Display', 'phase' ),
					'type' => 'dropdown',
					'value' => array_flip( apply_filters( 'phase_gallery_display_options', array(
						'grid' => esc_html__( 'Grid', 'phase' ),
					) ) ),
					'admin_label' => true,
				),

				array(
					'param_name' => 'gallery_module',
					'heading' => esc_html__( 'Module', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Grid', 'phase' ) => 'grid',
						esc_html__( 'Carousel', 'phase' ) => 'carousel',
					),
					'admin_label' => true,
					'dependency' => array( 'element' => 'gallery_display', 'value' => array( 'grid' ) ),
				),

				array(
					'param_name' => 'grid_padding',
					'heading' => esc_html__( 'Padding', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Yes', 'phase' ) => 'yes',
						esc_html__( 'No', 'phase' ) => 'no',
					),
					'admin_label' => true,
					//'dependency' => array( 'element' => 'gallery_display', 'value' => array( 'grid' ) ),
				),

				array(
					'param_name' => 'gallery_thumbnail_size',
					'heading' => esc_html__( 'Thumbnail Size', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Default Thumbnail', 'phase' ) => 'standard',
						esc_html__( 'Landscape', 'phase' ) => 'landscape',
						esc_html__( 'Square', 'phase' ) => 'square',
						esc_html__( 'Portrait', 'phase' ) => 'portrait',
					),
					'admin_label' => true,
					'dependency' => array(
						'element' => 'gallery_display',
						'value' => array( 'grid' ),
						// value_not_equal_to
					),
				),

				array(
					'param_name' => 'gallery_layout',
					'heading' => esc_html__( 'Layout', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Classic', 'phase' ) => 'standard',
						esc_html__( 'Overlay', 'phase' ) => 'overlay',
						//esc_html__( 'Flip Box', 'phase' ) => 'flip-box',
					),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Text Alignement', 'phase' ),
					'param_name' => 'caption_text_alignment',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Center', 'phase' ) => 'center',
						esc_html__( 'Left', 'phase' ) => 'left',
						esc_html__( 'Right', 'phase' ) => 'right',
					),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Overlay Color', 'phase' ),
					'param_name' => 'overlay_color',
					'value' => array_merge(
							array( esc_html__( 'Auto', 'phase' ) => 'auto', ),
							$shared_gradient_colors,
							$shared_colors,
							array( esc_html__( 'Custom color', 'phase' ) => 'custom', )
					),
					'std' => apply_filters( 'wvc_default_item_overlay_color', 'black' ),
					'description' => esc_html__( 'Select an overlay color.', 'phase' ),
					'param_holder_class' => 'wvc_colored-dropdown',
					'dependency' => array( 'element' => 'gallery_layout', 'value' => array( 'overlay' ) ),
				),

				// Overlay color
				array(
					'type' => 'colorpicker',
					'heading' => esc_html__( 'Overlay Custom Color', 'phase' ),
					'param_name' => 'overlay_custom_color',
					//'value' => '#000000',
					'dependency' => array( 'element' => 'overlay_color', 'value' => array( 'custom' ), ),
				),

				// Overlay opacity
				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Overlay Opacity in Percent', 'phase' ),
					'param_name' => 'overlay_opacity',
					'description' => '',
					'value' => 40,
					'std' => apply_filters( 'wvc_default_item_overlay_opacity', 40 ),
					'dependency' => array( 'element' => 'gallery_layout', 'value' => array( 'overlay' ) ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Overlay Text Color', 'phase' ),
					'param_name' => 'overlay_text_color',
					'value' => array_merge(
						$shared_colors,
						$shared_gradient_colors,
						array( esc_html__( 'Custom color', 'phase' ) => 'custom', )
					),
					'std' => apply_filters( 'wvc_default_item_overlay_text_color', 'white' ),
					'description' => esc_html__( 'Select an overlay color.', 'phase' ),
					'param_holder_class' => 'wvc_colored-dropdown',
					'dependency' => array( 'element' => 'gallery_layout', 'value' => array( 'overlay' ) ),
				),

				// Overlay color
				array(
					'type' => 'colorpicker',
					'heading' => esc_html__( 'Overlay Custom Text Color', 'phase' ),
					'param_name' => 'overlay_text_custom_color',
					//'value' => '#000000',
					'dependency' => array( 'element' => 'overlay_text_color', 'value' => array( 'custom' ), ),
				),

				array(
					'heading' => esc_html__( 'Animation', 'phase' ),
					'param_name' => 'item_animation',
					'type' => 'dropdown',
					'value' => array_flip( phase_get_animations() ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Category Filter', 'phase' ),
					'param_name' => 'gallery_category_filter',
					'type' => 'checkbox',
					'description' => esc_html__( 'The pagination will be disabled.', 'phase' ),
					'admin_label' => true,
					//'dependency' => array( 'element' => 'gallery_module', 'value' => array( 'grid' ) ),
				),

				array(
					'param_name' => 'pagination',
					'heading' => esc_html__( 'Pagination', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'None', 'phase' ) => 'none',
						esc_html__( 'Load More', 'phase' ) => 'load_more',
						esc_html__( 'Numeric Pagination', 'phase' ) => 'standard_pagination',
						esc_html__( 'Link to Album Archives', 'phase' ) => 'link_to_albums',
					),
					'admin_label' => true,
					//'dependency' => array( 'element' => 'post_module', 'value' => array( 'grid' ) ),
				),

				array(
					'heading' => esc_html__( 'Filter Text Alignement', 'phase' ),
					'param_name' => 'gallery_category_filter_text_alignment',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Center', 'phase' ) => 'center',
						esc_html__( 'Left', 'phase' ) => 'left',
						esc_html__( 'Right', 'phase' ) => 'right',
					),
					'dependency' => array(
						'element' => 'gallery_category_filter',
						'value' => array( 'true' ),
					),
				),

				array(
					'heading' => esc_html__( 'Number of Posts', 'phase' ),
					'param_name' => 'posts_per_page',
					'type' => 'wvc_textfield',
					//'placeholder' => get_option( 'posts_per_page' ),
					'description' => esc_html__( 'Leave empty to display all post at once.', 'phase' ),
					//'std' => '-1',
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
					'param_name' => 'inline_style',
					'type' => 'wvc_textfield',
					//'admin_label' => true,
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Include Category', 'phase' ),
					'param_name' => 'gallery_type_include',
					'description' => esc_html__( 'Enter one or several categories. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Category', 'phase' ),
					'param_name' => 'gallery_type_exclude',
					'description' => esc_html__( 'Enter one or several categories. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Offset', 'phase' ),
					'description' => esc_html__( '.', 'phase' ),
					'param_name' => 'offset',
					'description' => esc_html__( 'The amount of posts that should be skipped in the beginning of the query.', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'param_name' => 'columns',
					'heading' => esc_html__( 'Columns', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Auto', 'phase' ) => 'default',
						esc_html__( 'Two', 'phase' ) => 2,
						esc_html__( 'Three', 'phase' ) => 3,
						esc_html__( 'Four', 'phase' ) => 4,
						esc_html__( 'Six', 'phase' ) => 6,
						esc_html__( 'One', 'phase' ) => 1,
					),
					'std' => 'default',
					'admin_label' => true,
					'description' => esc_html__( 'By default, columns are set automatically depending on the container\'s width. Set a column count here to overwrite the default behavior.', 'phase' ),
					'dependency' => array(
						'element' => 'post_display',
						'value_not_equal_to' => array( 'standard', 'standard_modern' ),
					),
					'group' => esc_html__( 'Extra', 'phase' ),
				),
			),
			//),

			// 	array(
			// 		'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
			// 		'param_name' => 'inline_style',
			// 		'type' => 'wvc_textfield',
			// 		//'admin_label' => true,
			// 	),
			// ),
		//)
	)
);

class WPBakeryShortCode_Wvc_Gallery_Index extends WPBakeryShortCode {}
} // end Gallery plugin check

if ( class_exists( 'Wolf_Photos' ) ) {

/**
 * Photos Loop Module
 */
vc_map(
	array(
		'name' => esc_html__( 'Stock Photos', 'phase' ),
		'description' => esc_html__( 'Display your last stock photos', 'phase' ),
		'base' => 'wvc_attachment_index',
		'category' => esc_html__( 'Content' , 'phase' ),
		'icon' => 'fa fa-th',
		'weight' => 999,
		'params' =>
		//array_merge(
			array(

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Index ID', 'phase' ),
					'value' => 'index-' . rand( 0,99999 ),
					'param_name' => 'el_id',
					'description' => esc_html__( 'A unique identifier for the post module (required).', 'phase' ),
				),

				array(
					'param_name' => 'attachemnt_orderby',
					'heading' => esc_html__( 'Order By', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Recent', 'phase' ) => 'recent',
						esc_html__( 'Popular', 'phase' ) => 'popular',
					),
					'admin_label' => true,
					//'dependency' => array( 'element' => 'attachment_display', 'value' => array( 'grid' ) ),
				),

				array(
					'param_name' => 'attachment_display',
					'heading' => esc_html__( 'Photos Display', 'phase' ),
					'type' => 'dropdown',
					'value' => array_flip( apply_filters( 'phase_attachment_display_options', array(
						'grid' => esc_html__( 'Grid', 'phase' ),
					) ) ),
					'admin_label' => true,
				),

				array(
					'param_name' => 'grid_padding',
					'heading' => esc_html__( 'Padding', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Yes', 'phase' ) => 'yes',
						esc_html__( 'No', 'phase' ) => 'no',
					),
					'admin_label' => true,
					//'dependency' => array( 'element' => 'attachment_display', 'value' => array( 'grid' ) ),
				),

				// array(
				// 	'param_name' => 'attachment_thumbnail_size',
				// 	'heading' => esc_html__( 'Thumbnail Size', 'phase' ),
				// 	'type' => 'dropdown',
				// 	'value' => array(
				// 		esc_html__( 'Default Thumbnail', 'phase' ) => 'standard',
				// 		esc_html__( 'Landscape', 'phase' ) => 'landscape',
				// 		esc_html__( 'Square', 'phase' ) => 'square',
				// 		esc_html__( 'Portrait', 'phase' ) => 'portrait',
				// 	),
				// 	'admin_label' => true,
				// 	'dependency' => array(
				// 		'element' => 'attachment_display',
				// 		'value' => array( 'grid' ),
				// 		// value_not_equal_to
				// 	),
				// ),

				// array(
				// 	'param_name' => 'attachment_layout',
				// 	'heading' => esc_html__( 'Layout', 'phase' ),
				// 	'type' => 'dropdown',
				// 	'value' => array(
				// 		esc_html__( 'Classic', 'phase' ) => 'standard',
				// 		esc_html__( 'Overlay', 'phase' ) => 'overlay',
				// 		//esc_html__( 'Flip Box', 'phase' ) => 'flip-box',
				// 	),
				// 	'admin_label' => true,
				// ),

				array(
					'heading' => esc_html__( 'Text Alignement', 'phase' ),
					'param_name' => 'caption_text_alignment',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Center', 'phase' ) => 'center',
						esc_html__( 'Left', 'phase' ) => 'left',
						esc_html__( 'Right', 'phase' ) => 'right',
					),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Overlay Color', 'phase' ),
					'param_name' => 'overlay_color',
					'value' => array_merge(
							array( esc_html__( 'Auto', 'phase' ) => 'auto', ),
							$shared_gradient_colors,
							$shared_colors,
							array( esc_html__( 'Custom color', 'phase' ) => 'custom', )
					),
					'std' => apply_filters( 'wvc_default_item_overlay_color', 'black' ),
					'description' => esc_html__( 'Select an overlay color.', 'phase' ),
					'param_holder_class' => 'wvc_colored-dropdown',
				),

				// Overlay color
				array(
					'type' => 'colorpicker',
					'heading' => esc_html__( 'Overlay Custom Color', 'phase' ),
					'param_name' => 'overlay_custom_color',
					//'value' => '#000000',
					'dependency' => array( 'element' => 'overlay_color', 'value' => array( 'custom' ), ),
				),

				// Overlay opacity
				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Overlay Opacity in Percent', 'phase' ),
					'param_name' => 'overlay_opacity',
					'description' => '',
					'value' => 40,
					'std' => apply_filters( 'wvc_default_item_overlay_opacity', 40 ),
				),

				// Overlay text color
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Overlay Text Color', 'phase' ),
					'param_name' => 'overlay_text_color',
					'value' => array_merge(
						$shared_colors,
						$shared_gradient_colors,
						array( esc_html__( 'Custom color', 'phase' ) => 'custom', )
					),
					'std' => apply_filters( 'wvc_default_item_overlay_text_color', 'white' ),
					'description' => esc_html__( 'Select an overlay color.', 'phase' ),
					'param_holder_class' => 'wvc_colored-dropdown',
				),

				array(
					'type' => 'colorpicker',
					'heading' => esc_html__( 'Overlay Custom Text Color', 'phase' ),
					'param_name' => 'overlay_text_custom_color',
					//'value' => '#000000',
					'dependency' => array( 'element' => 'overlay_text_color', 'value' => array( 'custom' ), ),
				),

				array(
					'heading' => esc_html__( 'Posts Per Page', 'phase' ),
					'param_name' => 'posts_per_page',
					'type' => 'wvc_textfield',
					'value' => get_option( 'posts_per_page' ),
					'admin_label' => true,
				),

				array(
					'param_name' => 'pagination',
					'heading' => esc_html__( 'Pagination', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'None', 'phase' ) => 'none',
						esc_html__( 'Infinite Scroll', 'phase' ) => 'infinitescroll',
						//esc_html__( 'Load More', 'phase' ) => 'load_more',
						esc_html__( 'Link to Stock Photo Archives', 'phase' ) => 'link_to_attachments',
						esc_html__( 'Auto', 'phase' ) => 'default',
					),
					'admin_label' => true,
					//'dependency' => array( 'element' => 'post_module', 'value' => array( 'grid' ) ),
				),

				// array(
				// 	'heading' => esc_html__( 'Animation', 'phase' ),
				// 	'param_name' => 'item_animation',
				// 	'type' => 'dropdown',
				// 	'value' => array_flip( phase_get_animations() ),
				// 	'admin_label' => true,
				// 	//'dependency' => array(
				// 	//	'element' => 'attachment_display',
				// 		//'value' => array( 'grid' ),
				// 	//	'value_not_equal_to' => array( 'masonry_horizontal' ),
				// 	//),
				// ),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Include Category', 'phase' ),
					'param_name' => 'photo_category_include',
					'description' => esc_html__( 'Enter one or several categories. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Category', 'phase' ),
					'param_name' => 'photo_category_exclude',
					'description' => esc_html__( 'Enter one or several categories. Paste category slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Include Tag', 'phase' ),
					'param_name' => 'photo_tag_include',
					'description' => esc_html__( 'Enter one or several tags. Paste tag slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Tag', 'phase' ),
					'param_name' => 'photo_tag_exclude',
					'description' => esc_html__( 'Enter one or several tags. Paste tag slug(s) separated by a comma', 'phase' ),
					'placeholder' => esc_html__( 'my-category, other-category', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Offset', 'phase' ),
					'description' => esc_html__( '.', 'phase' ),
					'param_name' => 'offset',
					'description' => esc_html__( 'The amount of posts that should be skipped in the beginning of the query.', 'phase' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'param_name' => 'columns',
					'heading' => esc_html__( 'Columns', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Auto', 'phase' ) => 'default',
						esc_html__( 'Two', 'phase' ) => 2,
						esc_html__( 'Three', 'phase' ) => 3,
						esc_html__( 'Four', 'phase' ) => 4,
						esc_html__( 'Six', 'phase' ) => 6,
						esc_html__( 'One', 'phase' ) => 1,
					),
					'std' => 'default',
					'admin_label' => true,
					'description' => esc_html__( 'By default, columns are set automatically depending on the container\'s width. Set a column count here to overwrite the default behavior.', 'phase' ),
					'dependency' => array(
						'element' => 'post_display',
						'value' => array( 'grid', 'masonry' ),
					),
					'group' => esc_html__( 'Extra', 'phase' ),
				),
			),
			//),

			// 	array(
			// 		'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
			// 		'param_name' => 'inline_style',
			// 		'type' => 'wvc_textfield',
			// 		//'admin_label' => true,
			// 	),
			// ),
		//)
	)
);

class WPBakeryShortCode_Wvc_Attachment_Index extends WPBakeryShortCode {}

/**
 * Photos Search Form
 */
vc_map(
	array(
		'name' => esc_html__( 'Stock Photos Search Form', 'phase' ),
		'description' => esc_html__( 'Display your last stock photos', 'phase' ),
		'base' => 'wvc_attachment_search_form',
		'category' => esc_html__( 'Content' , 'phase' ),
		'icon' => 'fa fa-th',
		'weight' => 999,
		'params' => array(
			array(
				'type' => 'checkbox',
				'heading' => esc_html__( 'Display Post Tags', 'phase' ),
				'param_name' => 'attachment_form_photo_tags',
			),
		),
	)
);
class WPBakeryShortCode_Wvc_Attachment_Search_Form extends WPBakeryShortCode {}
} // end photos plugin check


$parent_pages = array( esc_html__( 'No', 'phase' ) => '' );
$all_pages = get_pages();

foreach ( $all_pages as $page ) {

	if ( 0 < count( get_posts( array( 'post_parent' => $page->ID, 'post_type' => 'page' ) ) ) ) {
		$parent_pages[ $page->post_title ] = $page->ID;
	}
}

/**
 * Page Loop Module
 */
vc_map(
	array(
		'name' => esc_html__( 'Pages', 'phase' ),
		'description' => esc_html__( 'Display your pages using the theme layouts', 'phase' ),
		'base' => 'wvc_page_index',
		'category' => esc_html__( 'Content' , 'phase' ),
		'icon' => 'fa fa-th',
		'weight' => 0,
		'params' =>
			array(

				array(
					'type' => 'hidden',
					'heading' => esc_html__( 'ID', 'phase' ),
					'value' => 'items-' . rand( 0,99999 ),
					'param_name' => 'el_id',
				),

				array(
					'param_name' => 'page_display',
					'heading' => esc_html__( 'Page Display', 'phase' ),
					'type' => 'dropdown',
					'value' => array_flip( apply_filters( 'phase_page_display_options', array(
						'grid' => esc_html__( 'Image Grid', 'phase' ),
					) ) ),
					'admin_label' => true,
				),

				// array(
				// 	'param_name' => 'grid_padding',
				// 	'heading' => esc_html__( 'Padding', 'phase' ),
				// 	'type' => 'dropdown',
				// 	'value' => array(
				// 		esc_html__( 'Yes', 'phase' ) => 'yes',
				// 		esc_html__( 'No', 'phase' ) => 'no',
				// 	),
				// 	'admin_label' => true,
				// ),

				array(
					'heading' => esc_html__( 'Animation', 'phase' ),
					'param_name' => 'item_animation',
					'type' => 'dropdown',
					'value' => array_flip( phase_get_animations() ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Number of Page to display', 'phase' ),
					'param_name' => 'posts_per_page',
					'type' => 'wvc_textfield',
					'placeholder' => get_option( 'posts_per_page' ),
					'description' => esc_html__( 'Leave empty to display all post at once.', 'phase' ),
					'std' => get_option( 'posts_per_page' ),
					'admin_label' => true,
				),

				array(
					'heading' => esc_html__( 'Additional CSS inline style', 'phase' ),
					'param_name' => 'inline_style',
					'type' => 'wvc_textfield',
					//'admin_label' => true,
				),

				array(
					'param_name' => 'page_by_parent',
					'heading' => esc_html__( 'Pages By Parent', 'phase' ),
					'type' => 'dropdown',
					'value' => $parent_pages,
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Post IDs', 'phase' ),
					'description' => esc_html__( 'By default, your last posts will be displayed. You can choose the posts you want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'include_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'wvc_textfield',
					'heading' => esc_html__( 'Exclude Post IDs', 'phase' ),
					'description' => esc_html__( 'You can choose the posts you don\'t want to display by entering a list of IDs separated by a comma.', 'phase' ),
					'param_name' => 'exclude_ids',
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Order by', 'phase' ),
					'param_name' => 'orderby',
					'value' => $order_by_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Select how to sort retrieved pages. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Sort order', 'phase' ),
					'param_name' => 'order',
					'value' => $order_way_values,
					'save_always' => true,
					'description' => sprintf( wp_kses_post( __( 'Designates the ascending or descending order. More at %s.', 'phase' ) ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
					'group' => esc_html__( 'Query', 'phase' ),
				),

				array(
					'param_name' => 'columns',
					'heading' => esc_html__( 'Columns', 'phase' ),
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Auto', 'phase' ) => 'default',
						esc_html__( 'Two', 'phase' ) => 2,
						esc_html__( 'Three', 'phase' ) => 3,
						esc_html__( 'Four', 'phase' ) => 4,
						esc_html__( 'Six', 'phase' ) => 6,
						esc_html__( 'One', 'phase' ) => 1,
					),
					'std' => 'default',
					'admin_label' => true,
					'description' => esc_html__( 'By default, columns are set automatically depending on the container\'s width. Set a column count here to overwrite the default behavior.', 'phase' ),
					'dependency' => array(
						'element' => 'post_display',
						'value_not_equal_to' => array( 'standard', 'standard_modern' ),
					),
					'group' => esc_html__( 'Extra', 'phase' ),
				),
			),
	)
);

class WPBakeryShortCode_Wvc_Page_Index extends WPBakeryShortCode {}