<?php
/**
 * Phase customizer font mods
 *
 * @package WordPress
 * @subpackage Phase
 * @version 1.2.8
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Set color schemes
 */
function phase_set_font_mods( $mods ) {

	/**
	 * Get Google Fonts from Font loader
	 */
	$_fonts = apply_filters( 'phase_mods_fonts', phase_get_google_fonts_options() );

	$font_choices = array( 'default' => esc_html__( 'Default', 'phase' ) );

	foreach ( $_fonts as $key => $value ) {
		$font_choices[ $key ] = $key;
	}

	$mods['fonts'] = array(
		'id' => 'fonts',
		'title' => esc_html__( 'Fonts', 'phase' ),
		'icon' => 'editor-textcolor',
		'options' => array(),
	);

	$mods['fonts']['options']['body_font_name'] = array(
		'label' => esc_html__( 'Body Font Name', 'phase' ),
		'id' => 'body_font_name',
		'type' => 'select',
		'choices' => $font_choices,
		'transport' => 'postMessage',
	);

	$mods['fonts']['options']['body_font_size'] = array(
		'label' => esc_html__( 'Body Font Size', 'phase' ),
		'id' => 'body_font_size',
		'type' => 'text',
		'transport' => 'postMessage',
		'description' => esc_html__( 'Don\'t ommit px. Leave empty to use the default font size.', 'phase' ),
	);

	/*************************Menu****************************/

	$mods['fonts']['options']['menu_font_name'] = array(
		'id' => 'menu_font_name',
		'label' => esc_html__( 'Menu Font', 'phase' ),
		'type' => 'select',
		'choices' => $font_choices,
		'transport' => 'postMessage',
	);

	$mods['fonts']['options']['menu_font_weight'] = array(
		'label' => esc_html__( 'Menu Font Weight', 'phase' ),
		'id' => 'menu_font_weight',
		'type' => 'text',
		'transport' => 'postMessage',
	);

	$mods['fonts']['options']['menu_font_transform'] = array(
		'id' => 'menu_font_transform',
		'label' => esc_html__( 'Menu Font Transform', 'phase' ),
		'type' => 'select',
		'choices' => array(
			'none' => esc_html__( 'None', 'phase' ),
			'uppercase' => esc_html__( 'Uppercase', 'phase' ),
		),
		'transport' => 'postMessage',
	);

	$mods['fonts']['options']['submenu_font_transform'] = array(
		'id' => 'submenu_font_transform',
		'label' => esc_html__( 'Submenu Font Transform', 'phase' ),
		'type' => 'select',
		'choices' => array(
			'none' => esc_html__( 'None', 'phase' ),
			'uppercase' => esc_html__( 'Uppercase', 'phase' ),
		),
		'transport' => 'postMessage',
	);

	$mods['fonts']['options']['submenu_font_weight'] = array(
		'label' => esc_html__( 'Submenu Font Weight', 'phase' ),
		'id' => 'submenu_font_weight',
		'type' => 'text',
		'transport' => 'postMessage',
	);

	$mods['fonts']['options']['menu_font_letter_spacing'] = array(
		'label' => esc_html__( 'Menu Letter Spacing (omit px)', 'phase' ),
		'id' => 'menu_font_letter_spacing',
		'type' => 'int',
		'transport' => 'postMessage',
	);

	$mods['fonts']['options']['submenu_font_letter_spacing'] = array(
		'label' => esc_html__( 'Submenu Letter Spacing (omit px)', 'phase' ),
		'id' => 'submenu_font_letter_spacing',
		'type' => 'int',
		'transport' => 'postMessage',
	);

	/*************************Heading****************************/

	$mods['fonts']['options']['heading_font_name'] = array(
		'id' => 'heading_font_name',
		'label' => esc_html__( 'Heading Font', 'phase' ),
		'type' => 'select',
		'choices' => $font_choices,
		'transport' => 'postMessage',
	);

	$mods['fonts']['options']['heading_font_weight'] = array(
		'label' => esc_html__( 'Heading Font weight', 'phase' ),
		'id' => 'heading_font_weight',
		'type' => 'text',
		'description' => esc_html__( 'For example: "400" is normal, "700" is bold.The available font weights depend on the font.', 'phase' ),
		'transport' => 'postMessage',
	);

	$mods['fonts']['options']['heading_font_transform'] = array(
		'id' => 'heading_font_transform',
		'label' => esc_html__( 'Heading Font Transform', 'phase' ),
		'type' => 'select',
		'choices' => array(
			'none' => esc_html__( 'None', 'phase' ),
			'uppercase' => esc_html__( 'Uppercase', 'phase' ),
		),
		'transport' => 'postMessage',
	);

	$mods['fonts']['options']['heading_font_letter_spacing'] = array(
		'label' => esc_html__( 'Heading Letter Spacing (omit px)', 'phase' ),
		'id' => 'heading_font_letter_spacing',
		'type' => 'int',
		'transport' => 'postMessage',
	);

	return $mods;

}
add_filter( 'phase_customizer_mods', 'phase_set_font_mods', 10 );