<?php
/**
 * Phase frontend theme specific functions
 *
 * @package WordPress
 * @subpackage Phase
 * @version 1.2.8
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Add default google font
 */
function phase_add_google_font( $google_fonts ) {

	$default_fonts = array(
		'Special Elite' =>  'Special+Elite',
		'Playfair Display' => 'Playfair+Display:400,700',
		'Poppins' => 'Poppins:400,700',
		'Raleway' => 'Raleway:400,500,700',
		'Open Sans' => 'Open+Sans',
	);

	foreach ( $default_fonts as $key => $value ) {
		if ( ! isset( $google_fonts[ $key ] ) ) {
			$google_fonts[ $key ] = $value;
		}
	}

	return $google_fonts;
}
add_filter( 'phase_google_fonts', 'phase_add_google_font' );

/**
 * Set artists template folder
 */
function phase_set_artists_template_url( $template_url ) {

	return 'artists/';
}
add_filter( 'wolf_artists_template_folder', 'phase_set_artists_template_url' );

/**
 * Set videos template folder
 */
function phase_set_videos_template_url( $template_url ) {

	return 'videos/';
}
add_filter( 'wolf_videos_template_url', 'phase_set_videos_template_url' );

/**
 * Set video display
 *
 * @param string $string
 * @return string
 */
function phase_set_video_display( $string ) {

	return 'grid';
}
add_filter( 'phase_mod_video_display', 'phase_set_video_display', 44 );

/**
 * Set discography template folder
 */
function phase_set_discography_template_url( $template_url ) {

	return 'discography/';
}
add_filter( 'wolf_discography_template_url', 'phase_set_discography_template_url' );
add_filter( 'wolf_discography_url', 'phase_set_discography_template_url' );

/**
 * Set events template folder
 */
function phase_set_events_template_url( $template_url ) {

	return 'events/';
}
add_filter( 'wolf_events_template_url', 'phase_set_events_template_url' );

/**
 * Set albums template folder
 */
function phase_set_albums_template_url( $template_url ) {

	return 'albums/';

}
add_filter( 'wolf_albums_url', 'phase_set_albums_template_url' );

/**
 * Add music elements to page builder
 *
 * @param array $elements
 * @return  array $elements
 */
function phase_add_music_elements( $elements ) {

	$elements[] = 'album-disc';
	$elements[] = 'album-tracklist';
	$elements[] = 'album-tracklist-item';
	$elements[] = 'bandsintown-tracking-button';

	if ( class_exists( 'Wolf_Videos' ) ) {
		$elements[] = 'video-switcher';
	}

	return $elements;
}
add_filter( 'wvc_element_list', 'phase_add_music_elements', 44 );

/*-----------------------------------------------------------------------------------*/

/**
 * @link https://wordpress.stackexchange.com/questions/161788/how-to-modify-a-taxonomy-thats-already-registered#answer-161789
 */

/**
 * Rewrite we_artist taxonomy slug
 */
function phase_we_artist_url_rewrite(){
	add_rewrite_rule( "^artist-events/([^/]*)$",'index.php?we_artist=$matches[1]','top' );
	flush_rewrite_rules();
}
add_action( 'admin_init', 'phase_we_artist_url_rewrite' );

/**
 * Rewrite band taxonomy slug
 */
function phase_band_url_rewrite(){
	add_rewrite_rule( "^artist-releases/([^/]*)$",'index.php?band=$matches[1]','top' );
	flush_rewrite_rules();
}
add_action( 'admin_init', 'phase_band_url_rewrite' );

/**
 * Rewrite video_type taxonomy slug
 */
function phase_change_video_type_taxonomies_slug( $args, $taxonomy ) {
	if ( 'video_type' === $taxonomy ) {
		$args['rewrite']['slug'] = 'artist-videos';
	}
	return $args;
}
add_filter( 'register_taxonomy_args', 'phase_change_video_type_taxonomies_slug', 10, 2 );

/**
 * Rewrite video_type taxonomy slug
 */
function phase_video_type_url_rewrite(){
	add_rewrite_rule( "^artist-videos/([^/]*)$",'index.php?video_type=$matches[1]','top' );
	flush_rewrite_rules();
}
add_action( 'admin_init', 'phase_video_type_url_rewrite' );

/**
 * Rewrite gallery_type taxonomy slug
 */
function phase_gallery_type_url_rewrite(){
	add_rewrite_rule( "^artist-galleries/([^/]*)$",'index.php?gallery_type=$matches[1]','top' );
	flush_rewrite_rules();
}
add_action( 'admin_init', 'phase_gallery_type_url_rewrite' );

/**
 * Overwrite post types taxonomy slug
 *
 * @param array $args
 * @param string $taxonomy
 * @return array $args
 */
function phase_overwrite_post_type_taxonomy_slug( $args, $taxonomy ) {
	
	if ( $taxonomy === 'video_type') {

		$new_labels = array(
			'name' => esc_html__( 'Videos by Artist', 'phase' ),
			'singular_name' => esc_html__( 'Artist', 'phase' ),
			'search_items' => esc_html__( 'Search Artists', 'phase' ),
			'popular_items' => esc_html__( 'Popular Artists', 'phase' ),
			'all_items' => esc_html__( 'All Artists', 'phase' ),
			'parent_item' => esc_html__( 'Parent Artist', 'phase' ),
			'parent_item_colon' => esc_html__( 'Parent Artist:', 'phase' ),
			'edit_item' => esc_html__( 'Edit Artist', 'phase' ),
			'update_item' => esc_html__( 'Update Artist', 'phase' ),
			'add_new_item' => esc_html__( 'Add New Artist', 'phase' ),
			'new_item_name' => esc_html__( 'New Artist', 'phase' ),
			'separate_items_with_commas' => esc_html__( 'Separate videos artists with commas', 'phase' ),
			'add_or_remove_items' => esc_html__( 'Add or remove videos artists', 'phase' ),
			'choose_from_most_used' => esc_html__( 'Choose from the most used videos categories', 'phase' ),
			'not_found' => esc_html__( 'No artist found', 'phase' ),
			'menu_name' => esc_html__( 'Videos by Artist', 'phase' ),
		);
		
		$args['labels'] = $new_labels;
		$args['rewrite']['slug'] = 'artist-videos';
	}

	if ( $taxonomy === 'gallery_type') {

		$new_labels = array(
			'name' => esc_html__( 'Galleries by Artist', 'phase' ),
			'singular_name' => esc_html__( 'Artist', 'phase' ),
			'search_items' => esc_html__( 'Search Artists', 'phase' ),
			'popular_items' => esc_html__( 'Popular Artists', 'phase' ),
			'all_items' => esc_html__( 'All Artists', 'phase' ),
			'parent_item' => esc_html__( 'Parent Artist', 'phase' ),
			'parent_item_colon' => esc_html__( 'Parent Artist:', 'phase' ),
			'edit_item' => esc_html__( 'Edit Artist', 'phase' ),
			'update_item' => esc_html__( 'Update Artist', 'phase' ),
			'add_new_item' => esc_html__( 'Add New Artist', 'phase' ),
			'new_item_name' => esc_html__( 'New Artist', 'phase' ),
			'separate_items_with_commas' => esc_html__( 'Separate galleries artists with commas', 'phase' ),
			'add_or_remove_items' => esc_html__( 'Add or remove galleries artists', 'phase' ),
			'choose_from_most_used' => esc_html__( 'Choose from the most used galleries categories', 'phase' ),
			'not_found' => esc_html__( 'No artist found', 'phase' ),
			'menu_name' => esc_html__( 'Galleries by Artist', 'phase' ),
		);
		
		$args['labels'] = $new_labels;
		$args['rewrite']['slug'] = 'artist-galleries';
	}

	if ( 'band' === $taxonomy ) {
		$args['hierarchical'] = true;
		$args['labels']['name'] = esc_html__( 'Releases by Artist', 'phase' );
		$args['labels']['menu_name'] = esc_html__( 'Releases by Artist', 'phase' );
		$args['rewrite']['slug'] = 'artist-releases';
	}

	if ( 'we_artist' === $taxonomy ) {
		$args['hierarchical'] = true;
		$args['labels']['name'] = esc_html__( 'Events by Artist', 'phase' );
		$args['labels']['menu_name'] = esc_html__( 'Events by Artist', 'phase' );
		$args['rewrite']['slug'] = 'artist-events';
	}

	return $args;
}
add_filter( 'register_taxonomy_args', 'phase_overwrite_post_type_taxonomy_slug', 10, 2 );

/**
 * Disable "label" taxonomy as it is a label theme
 */
function phase_unregister_label_taxonomy() {

	global $wp_taxonomies;
	$taxonomy = 'label';
	
	if ( taxonomy_exists( $taxonomy) ) {
		unset( $wp_taxonomies[ $taxonomy ] );
	}
}
add_action( 'init', 'phase_unregister_label_taxonomy');

/**
 * Overwrite post types menu order
 *
 * @param array $args
 * @param string $post_type
 * @return array $args
 */
function phase_overwrite_post_type_menu_order( $args, $post_type ) {

	if ( 'artist' === $post_type ) {

		$args['menu_position'] = 5.0;
	}

	if ( 'release' === $post_type ) {

		$args['menu_position'] = 5.1;
	}

	if ( 'event' === $post_type ) {

		$args['menu_position'] = 5.2;
	}

	if ( 'video' === $post_type ) {

		$args['menu_position'] = 5.3;
	}

	if ( 'gallery' === $post_type ) {

		$args['menu_position'] = 30;
	}

	if ( 'wpm_playlist' === $post_type ) {
		
		$args['menu_position'] = 35;
	}

	if ( 'wvc_content_block' === $post_type ) {
		
		$args['menu_position'] = 40;
	}

	return $args;
}
add_filter( 'register_post_type_args', 'phase_overwrite_post_type_menu_order', 99, 2 );

/**
 * Reorder admin menu
 */
function custom_menu_order( $menu_ord ) {
	if ( ! $menu_ord ) {
		return true;
	}

	return $menu_ord;
}

add_filter( 'custom_menu_order', 'custom_menu_order' );
add_filter( 'menu_order', 'custom_menu_order' );


/*-----------------------------------------------------------------------------------*/

/**
 * Get available display options for posts
 *
 * @return array
 */
function phase_set_post_display_options() {

	return array(
		'masonry_modern' => esc_html__( 'Masonry', 'phase' ),
		'metro_modern' => esc_html__( 'Metro', 'phase' ),
		'standard' => esc_html__( 'Standard', 'phase' ),
		'grid_classic' => esc_html__( 'Grid', 'phase' ),
		'grid_modern' => esc_html__( 'Grid Modern', 'phase' ),
	);
}
add_filter( 'phase_post_display_options', 'phase_set_post_display_options' );

/**
 * Get available display options for releases
 *
 * @return array
 */
function phase_set_release_display_options() {

	return array(
		'grid' => esc_html__( 'Grid', 'phase' ),
		'metro' => esc_html__( 'Metro', 'phase' ),
		'lateral' => esc_html__( 'Lateral', 'phase' ),
	);
}
add_filter( 'phase_release_display_options', 'phase_set_release_display_options' );

/**
 * Get available display options for events
 *
 * @return array
 */
function phase_set_event_display_options() {

	return array(
		'list' => esc_html__( 'List', 'phase' ),
		'grid' => esc_html__( 'Grid', 'phase' ),
	);
}
add_filter( 'phase_event_display_options', 'phase_set_event_display_options' );

/**
 * Get available display options for artists
 *
 * @return array
 */
function phase_set_artist_display_options() {

	return array(
		'list' => esc_html__( 'List', 'phase' ),
		'grid' => esc_html__( 'Grid', 'phase' ),
		'masonry' => esc_html__( 'Masonry', 'phase' ),
		'metro' => esc_html__( 'Metro', 'phase' ),
		'offgrid' => esc_html__( 'Off-Grid', 'phase' ),
	);
}
add_filter( 'phase_artist_display_options', 'phase_set_artist_display_options' );

/**
 * Get available display options for galleries/albums
 *
 * @return array
 */
function phase_set_gallery_display_options() {

	return array(
		'grid' => esc_html__( 'Grid', 'phase' ),
		'masonry' => esc_html__( 'Masonry', 'phase' ),
	);
}
add_filter( 'phase_gallery_display_options', 'phase_set_gallery_display_options' );

/**
 * Filter post modules
 *
 * @param array $atts
 * @return array $atts
 */
function phase_filter_post_module_atts( $atts ) {

	$post_type = $atts['post_type'];
	$affected_post_types = array( 'release', 'artist', 'gallery' );

	if ( in_array( $post_type, $affected_post_types ) ) {
		if ( isset( $atts[ $post_type . '_display' ] ) && 'offgrid' === $atts[ $post_type . '_display' ] ) {
			$atts['item_animation'] = '';
			$atts[ $post_type . '_layout' ] = 'standard';
		}
	}

	if ( isset( $atts[ $post_type . '_hover_effect' ] ) ) {
		if ( 'cursor' === $atts[ $post_type . '_hover_effect' ] ) {
			
			$atts[ $post_type . '_layout' ] = 'standard';
			
			if ( 'list' === $post_type . '_display' ) {
				$atts[ $post_type . '_display' ] = 'grid';
			}
		}

		if ( 'filmgrain' === $atts[ $post_type . '_hover_effect' ] ) {
			$atts[ $post_type . '_layout' ] = 'overlay';
			$atts[ 'overlay_color' ] = '';
		}

		if ( 'slide-up' === $atts[ $post_type . '_hover_effect' ] ) {
			$atts[ $post_type . '_layout' ] = 'overlay';
		}
	}

	return $atts;
}
add_filter( 'phase_post_module_atts', 'phase_filter_post_module_atts' );

/**
 *  Set default row skin
 *
 * @param string $font_color
 * @return string $font_color
 */
function phase_set_default_wvc_row_font_color( $font_color ) {

	return 'light';
}
add_filter( 'wvc_default_row_font_color', 'phase_set_default_wvc_row_font_color', 40 );

/**
 * No header post types
 */
function phase_filter_no_hero_post_types( $post_types ) {

	$post_types = array( 'product', 'attachment' );

	return $post_types;
}
add_filter( 'phase_no_header_post_types', 'phase_filter_no_hero_post_types', 40 );

/**
 * Read more text
 */
function phase_view_post_text( $string ) {
	return esc_html__( 'Read more', 'phase' );
}
add_filter( 'phase_view_post_text', 'phase_view_post_text' );

/**
 * Discography "band" text
 */
function wolf_set_discography_band_string( $string ) {
	return esc_html__( 'Artist', 'phase' );
}
add_filter( 'wolf_discography_band_string', 'wolf_set_discography_band_string', 40 );

/**
 * Search form placeholder
 */
function phase_set_searchform_placeholder( $string ) {
	return esc_attr_x( 'Search&hellip;', 'placeholder', 'phase' );
}
add_filter( 'phase_searchform_placeholder', 'phase_set_searchform_placeholder', 40 );

/**
 * View more events text
 */
function phase_view_more_events_text( $string ) {
	return esc_html__( 'View more dates', 'phase' );
}
add_filter( 'phase_view_more_events_text', 'phase_view_more_events_text' );

/**
 * Search form placeholder text
 */
function phase_searchform_placeholder_text( $string ) {
	return esc_html__( 'Type your search and hit enter&hellip;', 'phase' );
}
add_filter( 'phase_searchform_placeholder', 'phase_searchform_placeholder_text' );

/**
 * Add form in no result page
 */
function phase_add_no_result_form() {
	get_search_form();
}
add_action( 'phase_no_result_end', 'phase_add_no_result_form' );

/**
 * Set release taxonomy before string
 */
function phase_set_release_tax_before( $string ) {

	return esc_html__( 'by', 'phase' ) . ' ';

}
add_filter( 'phase_release_tax_before', 'phase_set_release_tax_before' );

/**
 * Secondary navigation hook
 *
 * Display cart icons, social icons or secondary menu depending on cuzstimizer option
 */
function phase_output_mobile_complementary_menu( $context = 'desktop' ) {
	if ( 'mobile' === $context ) {
		$cta_content = phase_get_inherit_mod( 'menu_cta_content_type', 'none' );

		/**
		 * Force shop icons on woocommerce pages
		 */
		$is_wc_page_child = is_page() && wp_get_post_parent_id( get_the_ID() ) == phase_get_woocommerce_shop_page_id() && phase_get_woocommerce_shop_page_id();
		$is_wc = phase_is_woocommerce_page() || is_singular( 'product' ) || $is_wc_page_child;

		if ( apply_filters( 'phase_force_display_nav_shop_icons', $is_wc ) ) { // can be disable just in case
			$cta_content = 'shop_icons';
		}

		if ( 'shop_icons' === $cta_content ) {
			if ( phase_display_account_menu_item() ) : ?>
				<div class="account-container cta-item">
					<?php
						/**
						 * account icon
						 */
						phase_account_menu_item();
					?>
				</div><!-- .cart-container -->
			<?php endif;
			
			if ( phase_display_cart_menu_item() ) {
			?>
				<div class="cart-container cta-item">
					<?php
						/**
						 * Cart icon
						 */
						phase_cart_menu_item();
					?>
				</div><!-- .cart-container -->
			<?php
			}
		}
	}
}
add_action( 'phase_secondary_menu', 'phase_output_mobile_complementary_menu', 10, 1 );

if ( ! function_exists( 'phase_release_meta' ) ) {
	/**
	 * Display release meta
	 */
	function phase_release_meta() {
		
		if ( ! class_exists( 'Wolf_Discography' ) ) {
			return;
		}

		$meta = wd_get_meta();
		$release_title = $meta['title'];
		$release_date = $meta['date'];
		$release_catalog = $meta['catalog'];
		$release_format = $meta['format'];
		$artists = get_the_terms( get_the_ID(), 'band' );
		if ( $release_date ) : ?>
		<strong><?php esc_html_e( 'Release Date', 'phase' ); ?></strong> : <?php echo sanitize_text_field( $release_date ); ?><br>
		<?php endif; ?>

		<?php
			if ( $artists ) {
				$artist_label = ( 1 < count( $artists ) ) ? esc_html__( 'Artists', 'phase' ) : esc_html__( 'Artist', 'phase' );
				?>
				<strong><?php echo sanitize_text_field( $artist_label ); ?></strong> : 
				<?php
				$artists_html = '';
				foreach ( $artists as $artist ) {
					$artist_slug = $artist->slug;
					$artist_name = $artist->name;
					$artists_html .= '<a href="' . esc_url( home_url( '/artists/' . $artist_slug ) ) .'">' . sanitize_text_field( $artist_name ) . '</a>, ';
				}

				echo rtrim( $artists_html, ', ' );
				echo '<br>';
			}
		?>
		<?php // Catalog number
		if ( $release_catalog ) : ?>
		<strong><?php esc_html_e( 'Catalog ref.', 'phase' ); ?></strong> : <?php echo sanitize_text_field( $release_catalog ); ?><br>
		<?php endif; ?>

		<?php // Type
		if ( $release_format && wolf_get_release_option( 'display_format' ) ) : ?>
		<strong><?php esc_html_e( 'Format', 'phase' ); ?></strong> : <?php echo sanitize_text_field( $release_format ); ?><br>
		<?php endif; ?>
		<?php edit_post_link( esc_html__( 'Edit', 'phase' ), '<span class="edit-link">', '</span>' );
	}
}

if ( ! function_exists( 'phase_artist_meta' ) ) {
	/**
	 * Display release meta
	 */
	function phase_artist_meta() {
		
		if ( ! class_exists( 'Wolf_Artists' ) ) {
			return;
		}

		$post_id = get_the_ID();

		$output = '';

		/* Location */
		$location = get_post_meta( get_the_ID(), '_artist_location', true );

		if ( $location ) {
			echo '<div class="artist-location artist-meta wvc-element">';
			echo '<h3>';
			esc_html_e( 'Location', 'phase' );
			echo '</h3>';

			echo phase_kses( $location );

			echo '</div>';
		}

		/* Genres */
		$genres = get_the_term_list( $post_id, 'artist_genre', '', esc_html__( ', ', 'phase' ), '' );

		if ( $genres ) {
			echo '<div class="artist-genre artist-meta wvc-element">';
			echo '<h3>';
			esc_html_e( 'Genre', 'phase' );
			echo '</h3>';

			echo phase_kses( $genres );

			echo '</div>';
		}

		/* Socials */

		$artists_socials = ( function_exists( 'wvc_get_team_member_socials' ) ) ? wvc_get_team_member_socials() : array( 'facebook', 'twitter', 'instagram', 'youtube', 'spotify', 'soundcloud', 'bandsintown', 'vimeo', 'email' );

		$has_socials = false;

		foreach ( $artists_socials as $social ) {
			if ( get_post_meta( $post_id, '_artist_' . $social, true ) ) {
				$has_socials = true;
				break;
			}
		}

		if ( $has_socials ) {
			echo '<div class="artist-socials artist-meta wvc-element">';
			echo '<h3>';
			esc_html_e( 'Socials', 'phase' );
			echo '</h3>';

			foreach ( $artists_socials as $social ) {
				$social_meta = get_post_meta( $post_id, '_artist_' . $social, true );

				$icon = $social;
				$prefix = 'fa';

				if ( 'bandsintown' === $social ) {
					$prefix = 'wolficon';
				}

				if ( 'email' === $social ) {
					$icon = 'envelope';
				}

				if ( $social_meta ) {
					?>
					<a href="<?php echo esc_attr( $social_meta ); ?>" target="_blank">
						<?php if ( class_exists( 'Wolf_Visual_Composer' ) ) : ?>
							<i class="fa <?php echo esc_attr( $prefix ); ?>-<?php echo esc_attr( $icon ); ?>"></i>&nbsp;
						<?php endif; ?>
						<span><?php echo esc_attr( $social ); ?></span>
					</a>
					<br>
					<?php
				}
			}
			echo '</div>';
		}

		/* Website */

		$link = get_post_meta( get_the_ID(), '_artist_website_url', true );
		
		if ( $link ) {
			echo '<div class="artist-website artist-meta wvc-element">';
			echo '<h3>';
			esc_html_e( 'Website', 'phase' );
			echo '</h3>';
			$link_text = mb_strimwidth( str_replace( 'http://', '', $link ), 0, 44, '...' );
			?>
			<a href="<?php echo esc_url( $link ); ?>" target="_blank">
				<span><?php echo sanitize_text_field( $link_text ); ?></span>
			</a>
			<?php
			echo '</div>';
		}

		edit_post_link( esc_html__( 'Edit', 'phase' ), '<span class="edit-link">', '</span>' );
	}
}

if ( ! function_exists( 'phase_artist_content' ) ) {
	/**
	 * Display release content
	 */
	function phase_artist_content() {
		
		if ( ! class_exists( 'Wolf_Artists' ) ) {
			return;
		}

		$artist_slug = get_post_field( 'post_name', get_post() );
		$playlist_id = get_post_meta( get_the_ID(), '_artist_playlist_id', true );
		
		$has_bio = get_the_content();

		$has_releases = apply_filters( 'phase_artist_has_releases', get_posts(
			array(
				'post_type' => 'release',
				'posts_per_page' => -1,
				'band' =>  $artist_slug,
			)
		) );
		
		$has_tour = apply_filters( 'phase_artist_has_tour', get_posts(
			array(
				'post_type' => 'event',
				'posts_per_page' => -1,
				'we_artist' =>  $artist_slug,
			)
		) );
		
		$has_videos = apply_filters( 'phase_artist_has_videos', get_posts(
			array(
				'post_type' => 'video',
				'posts_per_page' => -1,
				'video_type' =>  $artist_slug,
			)
		) );

		$has_albums = apply_filters( 'phase_artist_has_albums', get_posts(
			array(
				'post_type' => 'gallery',
				'posts_per_page' => -1,
				'gallery_type' =>  $artist_slug,
			)
		) );

		$has_twitter = ( class_exists( 'Wolf_Twitter' ) && get_post_meta( get_the_ID(), '_artist_twitter', true ) );
		?>
		<?php if ( function_exists( 'wpm_playlist' ) && $playlist_id ) : ?>
			<div class="artist-playlist">
				<?php wpm_playlist( absint( $playlist_id ) ); ?>
			</div>
		<?php endif; ?>
		<div id="artist-tabs" class="artist-tabs-container">
			<?php if ( $has_bio || $has_releases || $has_videos || $has_tour || $has_albums ) : ?>
				<ul class="artist-tabs-menu">
					<?php if ( get_the_content() ) : ?>
						<li>
							<a href="#bio">
								<?php echo apply_filters( 'phase_artist_tab_biography_text', esc_html__( 'Biography', 'phase' ) ); ?>
							</a>
						</li>
					<?php endif; ?>
					<?php if ( $has_releases ) : ?>
						<li>
							<a href="#discogaphy">
								<?php echo apply_filters( 'phase_artist_tab_discography_text', esc_html__( 'Releases', 'phase' ) ); ?>
							</a>
						</li>
					<?php endif; ?>
					<?php if ( $has_tour ) : ?>
						<li>
							<a href="#tour">
								<?php echo apply_filters( 'phase_artist_tab_events_text', esc_html__( 'Tour', 'phase' ) ); ?>
							</a>
						</li>
					<?php endif; ?>
					<?php if ( $has_videos ) : ?>
						<li>
							<a href="#videos">
								<?php echo apply_filters( 'phase_artist_tab_videos_text', esc_html__( 'Videos', 'phase' ) ); ?>
							</a>
						</li>
					<?php endif; ?>
					<?php if ( $has_albums ) : ?>
						<li>
							<a href="#albums">
								<?php echo apply_filters( 'phase_artist_tab_albums_text', esc_html__( 'Photos', 'phase' ) ); ?>
							</a>
						</li>
					<?php endif; ?>
					<?php if ( $has_twitter ) : ?>
						<li>
							<a href="#twitter">
								<?php echo apply_filters( 'phase_artist_tab_twitter_text', esc_html__( 'Updates', 'phase' ) ); ?>
							</a>
						</li>
					<?php endif; ?>
				</ul>
			<?php endif ?>
			<?php if ( get_the_content() ) : ?>
				<div id="bio" class="artist-bio">
					<?php the_content(); ?>
				</div>
			<?php endif; ?>
			<?php if ( $has_releases ) : ?>
				<div id="discogaphy" class="artist-tab artist-discography">
					<?php
						do_action( 'phase_posts', array(
							'el_id' => 'artist-discography-index',
							'posts_per_page' => -1,
							'columns' => 3,
							'post_type' => 'release',
							'release_display' => 'grid',
							'grid_padding' => phase_get_theme_mod( 'release_grid_padding', 'yes' ),
							'item_animation' => phase_get_theme_mod( 'release_item_animation' ),
							'band_include' => $artist_slug,
							'release_category_filter' => false,
						) );
					?>
				</div>
			<?php endif; ?>
			<?php if ( $has_tour ) : ?>
				<div id="tour" class="artist-tab artist-tour">
					<?php
						do_action( 'phase_posts', array(
							'el_id' => 'artist-events-index',
							'posts_per_page' => -1,
							'post_type' => 'event',
							'artist_include' => $artist_slug,
							'artist_category_filter' => false,
						) );
					?>
				</div>
			<?php endif; ?>
			<?php if ( $has_videos ) : ?>
				<div id="videos" class="artist-tab artist-videos">
					<?php
						do_action( 'phase_posts', array(
							'el_id' => 'artist-videos-index',
							'posts_per_page' => -1,
							'post_type' => 'video',
							'video_type_include' => $artist_slug,
							'columns' => 2,
							'video_onclick' => 'lightbox',
							'video_category_filter' => false,
							'video_preview' => false,
						) );
					?>
				</div>
			<?php endif; ?>
			<?php if ( $has_albums ) : ?>
				<div id="albums" class="artist-tab artist-albums">
					<?php
						do_action( 'phase_posts', array(
							'el_id' => 'artist-albums-index',
							'posts_per_page' => -1,
							'post_type' => 'gallery',
							'gallery_type_include' => $artist_slug,
							'columns' => 2,
							'gallery_category_filter' => false,
						) );
					?>
				</div>
			<?php endif; ?>
			<?php if ( $has_twitter ) : ?>
				<div id="twitter" class="artist-tab artist-twitter">
					<?php
						$url = get_post_meta( get_the_ID(), '_artist_twitter', true );
						
						if ( preg_match( '/(http|https):\/\/twitter.com\/([a-zA-Z0-9_]+)/', $url, $matches ) ) {

							if ( isset( $matches[2] ) ) {
								echo do_shortcode( '[wolf_tweet username="' . $matches[2] . '" type="list" count="4"]' );
							}
						}
					?>
				</div>
			<?php endif; ?>
		</div>
		<?php
	}
}

/**
 * Remove unused mods
 */
function phase_unset_mods( $mods ) {
	unset( $mods['shop']['options']['product_display'] );
	unset( $mods['navigation']['options']['menu_hover_style'] );
	unset( $mods['blog']['options']['post_display']['choices']['mosaic'] );
	unset( $mods['blog']['options']['post_display']['choices']['grid'] );

	return $mods;
}
add_filter( 'phase_customizer_mods', 'phase_unset_mods', 20 );

/**
 * Add release hover effects
 */
function phase_add_hover_effects() {
	if ( function_exists( 'vc_add_params' ) ) {
		vc_add_params(
			'wvc_release_index',
			array(
				array(
					'heading' => esc_html__( 'Hover Effect', 'phase' ),
					'param_name' => 'release_hover_effect',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Simple', 'phase' ) => 'simple',
						esc_html__( 'Slide Up', 'phase' ) => 'slide-up',
						esc_html__( 'Film Grain', 'phase' ) => 'filmgrain',
						esc_html__( 'Title Following Cursor', 'phase' ) => 'cursor',
					),
					'description' => esc_html__( 'Settings above may be overwritten.', 'phase' ),
					'dependency' => array(
						'element' => 'release_display',
						'value_not_equal_to' => array( 'lateral' ),
					),
				),
			)
		);

		vc_add_params(
			'wvc_artist_index',
			array(
				array(
					'heading' => esc_html__( 'Hover Effect', 'phase' ),
					'param_name' => 'artist_hover_effect',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Simple', 'phase' ) => 'simple',
						esc_html__( 'Slide Up', 'phase' ) => 'slide-up',
						esc_html__( 'Film Grain', 'phase' ) => 'filmgrain',
						esc_html__( 'Title Following Cursor', 'phase' ) => 'cursor',
					),
					'description' => esc_html__( 'Settings above may be overwritten.', 'phase' ),
					'dependency' => array(
						'element' => 'artist_display',
						'value_not_equal_to' => array( 'lateral' ),
					),
				),
			)
		);

		vc_add_params(
			'wvc_gallery_index',
			array(
				array(
					'heading' => esc_html__( 'Hover Effect', 'phase' ),
					'param_name' => 'gallery_hover_effect',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Simple', 'phase' ) => 'simple',
						esc_html__( 'Slide Up', 'phase' ) => 'slide-up',
						esc_html__( 'Film Grain', 'phase' ) => 'filmgrain',
						esc_html__( 'Title Following Cursor', 'phase' ) => 'cursor',
					),
					'description' => esc_html__( 'Settings above may be overwritten.', 'phase' ),
					'dependency' => array(
						'element' => 'gallery_display',
						'value_not_equal_to' => array( 'lateral' ),
					),
				),
			)
		);
	}
}
add_action( 'init', 'phase_add_hover_effects' );

/**
 *  Set default release hover effect
 *
 * @param string $string
 * @return string $string
 */
function phase_set_release_hover_effect( $string ) {
	return 'phase';
}
add_filter( 'release_default_hover_effect', 'phase_set_release_hover_effect', 40 );


/**
 *  Set default button shape
 *
 * @param string $shape
 * @return string $shape
 */
function phase_set_default_wvc_button_shape( $shape ) {
	return 'boxed';
}
add_filter( 'wvc_default_button_shape', 'phase_set_default_wvc_button_shape', 40 );

/**
 *  Set default button shape
 *
 * @param string $shape
 * @return string $shape
 */
function phase_set_default_theme_button_shape( $shape ) {
	return 'square';
}
add_filter( 'phase_mod_button_style', 'phase_set_default_theme_button_shape', 40 );

/**
 *  Set default button font weight
 *
 * @param string $shape
 * @return string $shape
 */
function phase_set_default_wvc_button_font_weight( $font_weight ) {
	return 700;
}
add_filter( 'wvc_button_default_font_weight', 'phase_set_default_wvc_button_font_weight', 40 );

/**
 *  Set embed video title
 *
 * @param string $title
 * @return string $title
 */
function wvc_set_embed_video_title( $title ) {

	return esc_html__( '&mdash; %s', 'phase' );
}
add_filter( 'wvc_embed_video_title', 'wvc_set_embed_video_title', 40 );

/**
 *  Set default pie chart line width
 *
 * @param string $width
 * @return string $width
 */
function wvc_set_default_pie_chart_line_width( $width ) {

	return 15;
}
add_filter( 'wvc_default_pie_chart_line_width', 'wvc_set_default_pie_chart_line_width', 40 );

/**
 *  Set embed video title
 *
 * @param string $title
 * @return string $title
 */
function phase_set_default_video_opener_button( $title ) {

	return '<span class="video-opener" data-aos="fade" data-aos-once="true"></span>';
}
add_filter( 'wvc_default_video_opener_button', 'phase_set_default_video_opener_button', 40 );

/**
 *  Set cat list icon
 *
 * @param string $icon
 * @return string $icon
 */
function phase_set_entry_cat_list_icon( $icon ) {

	return '<span class="post-meta-prefix">' . esc_html__( 'In', 'phase' ) . '</span>';
}
add_filter( 'phase_entry_category_list_icon', 'phase_set_entry_cat_list_icon', 40 );

/**
 *  Set tag list icon
 *
 * @param string $icon
 * @return string $icon
 */
function phase_set_entry_tag_list_icon( $icon ) {

	return '<span class="post-meta-prefix">' . esc_html__( 'Tagged as', 'phase' ) . '</span>';
}
add_filter( 'phase_entry_tag_list_icon', 'phase_set_entry_tag_list_icon', 40 );

/**
 *  Set default heading font size
 *
 * @param int $font_size
 * @return int $font_size
 */
function wvc_set_default_custom_heading_font_size( $font_size ) {
	return 48;
}
add_filter( 'wvc_default_custom_heading_font_size', 'wvc_set_default_custom_heading_font_size', 40 );
add_filter( 'wvc_default_advanced_slide_title_font_size', 'wvc_set_default_custom_heading_font_size', 40 );

/**
 *  Set default heading font size
 *
 * @param string $font_size
 * @return string $font_size
 */
function wvc_set_default_cta_font_size( $font_size ) {
	return 48;
}
add_filter( 'wvc_default_cta_font_size', 'wvc_set_default_cta_font_size', 40 );

/**
 *  Set default team member title font size
 *
 * @param string $font_size
 * @return string $font_size
 */
function wvc_set_default_team_member_font_size( $font_size ) {
	return 18;
}
add_filter( 'wvc_default_team_member_title_font_size', 'wvc_set_default_team_member_font_size', 40 );
add_filter( 'wvc_default_single_image_title_font_size', 'wvc_set_default_team_member_font_size', 40 );

/**
 * Primary buttons class
 *
 * @param string $string
 * @return string
 */
function phase_set_primary_button_class( $class ) {

	$phase_button_class = 'phase_button_alt';

	$class = $phase_button_class . ' wvc-button wvc-button-size-xs';

	return $class;
}
add_filter( 'wvc_last_posts_big_slide_button_class', 'phase_set_primary_button_class' );
add_filter( 'phase_404_button_class', 'phase_set_primary_button_class' );
add_filter( 'phase_single_event_buy_ticket_button_class', 'phase_set_primary_button_class' );

/**
 * Event ticket button class
 *
 * @param string $string
 * @return string
 */
function phase_set_event_ticket_button_class( $class ) {

	$phase_button_class = 'phase_button_alt2';

	$class = $phase_button_class . ' wvc-button wvc-button-size-xs ticket-button';

	return $class;
}
add_filter( 'we_ticket_link_class', 'phase_set_event_ticket_button_class', 40 );

/**
 * Main buttons class
 *
 * @param string $string
 * @return string
 */
function phase_set_alt_button_class( $class ) {

	$phase_button_class = 'phase_button_alt2';

	$class = $phase_button_class . ' wvc-button wvc-button-size-xs';

	return $class;
}
add_filter( 'phase_loadmore_button_class', 'phase_set_alt_button_class' );
add_filter( 'phase_more_link_button_class', 'phase_set_alt_button_class' );
add_filter( 'phase_release_button_class', 'phase_set_alt_button_class' );

/**
 * Author box buttons class
 *
 * @param string $string
 * @return string
 */
function phase_set_author_box_button_class( $class ) {

	$class = ' wvc-button wvc-button-size-xs phase_button_alt2';

	return $class;
}
add_filter( 'phase_author_page_link_button_class', 'phase_set_author_box_button_class' );


/**
 * Excerpt more
 *
 * Add span to allow more CSS tricks
 *
 * @return string
 */
function phase_custom_more_text( $string ) {

	$text = '<span>' . esc_html__( 'Continue reading', 'phase' ) . '</span>';

	return $text;
}
add_filter( 'phase_more_text', 'phase_custom_more_text', 40 );

/**
 * Set related posts text
 *
 * @param string $string
 * @return string
 */
function phase_set_related_posts_text( $text ) {

	return esc_html__( 'More Posts', 'phase' );
}
add_filter( 'phase_related_posts_text', 'phase_set_related_posts_text' );

/**
 *  Set default item overlay color
 *
 * @param string $color
 * @return string $color
 */
function phase_set_default_item_overlay_color( $color ) {
	return 'accent';
}
add_filter( 'wvc_default_item_overlay_color', 'phase_set_default_item_overlay_color', 40 );

/**
 *  Set default item overlay text color
 *
 * @param string $color
 * @return string $color
 */
function phase_set_item_overlay_text_color( $color ) {
	return 'white';
}
add_filter( 'wvc_default_item_overlay_text_color', 'phase_set_item_overlay_text_color', 40 );

/**
 *  Set default item overlay opacity
 *
 * @param int $color
 * @return int $color
 */
function phase_set_item_overlay_opacity( $opacity ) {
	return 90;
}
add_filter( 'wvc_default_item_overlay_opacity', 'phase_set_item_overlay_opacity', 40 );

/**
 * Excerpt length hook
 * Set the number of character to display in the excerpt
 *
 * @param int $length
 * @return int
 */
function phase_overwrite_excerpt_length( $length ) {

	return 23;
}
add_filter( 'phase_excerpt_length', 'phase_overwrite_excerpt_length' );

/**
 * Excerpt length hook
 * Set the number of character to display in the excerpt
 *
 * @param int $length
 * @return int
 */
function phase_overwrite_sticky_menu_height( $length ) {

	return 55;
}
add_filter( 'phase_sticky_menu_height', 'phase_overwrite_sticky_menu_height' );

/**
 * Set menu hover effect
 *
 * @param string $string
 * @return string
 */
function phase_set_menu_hover_style( $string ) {
	return 'phase';
}
add_filter( 'phase_mod_menu_hover_style', 'phase_set_menu_hover_style' );

/**
 * Set shop display
 *
 * @param string $string
 * @return string
 */
function phase_set_product_display( $string ) {

	return 'grid_overlay';
}
add_filter( 'phase_mod_product_display', 'phase_set_product_display' );

/**
 * Filter sidebar footer class
 */
function phase_set_sidebar_footer_class( $class ) {

	if ( 'light' === phase_get_color_tone( phase_get_theme_mod( 'footer_bg_color' ) ) ) {

		$class .= 'wvc-font-dark';

	} else {
		$class .= 'wvc-font-light';
	}

	return $class;
}
add_filter( 'phase_sidebar_footer_class', 'phase_set_sidebar_footer_class' );

/**
 * Set team member social
 */
function phase_set_team_member_socials( $socials ) {

	return array( 'facebook', 'twitter', 'instagram', 'youtube', 'spotify', 'soundcloud', 'bandsintown', 'vimeo', 'email' );

}
add_filter( 'wvc_team_member_socials', 'phase_set_team_member_socials' );

/**
 * Add mods
 */
function phase_add_mods( $mods ) {

	$color_scheme = phase_get_color_scheme();

	$mods['colors']['options']['secondary_accent_color'] = array(
		'id' => 'secondary_accent_color',
		'label' => esc_html__( 'Secondary Accent Color', 'phase' ),
		'type' => 'color',
		'transport' => 'postMessage',
		'default' => $color_scheme[8],
	);

	$mods['loading'] = array(

		'id' => 'loading',
		'title' => esc_html__( 'Loading', 'phase' ),
		'icon' => 'update',
		'options' => array(

			array(
				'label' => esc_html__( 'Loading Animation Type', 'phase' ),
				'id' => 'loading_animation_type',
				'type' => 'select',
				'choices' => array(
					'none' => esc_html__( 'None', 'phase' ),
		 			'overlay' => esc_html__( 'Overlay', 'phase' ),
		 			'phase' => esc_html__( 'Overlay with text animation', 'phase' ),
				),
			),

			'loading_text' => array(
				'label' => esc_html__( 'Loading Text', 'phase' ),
				'id' => 'loading_text',
				'description' => esc_html__( 'For the overlay with text loading animation. By default, the site title will be used', 'phase' ),
				'label' => esc_html__( 'Loading Text', 'phase' ),
			),
		),
	);

	$mods['blog']['options']['post_hero_layout'] = array(
		'label'	=> esc_html__( 'Single Post Header Layout', 'phase' ),
		'id'	=> 'post_hero_layout',
		'type'	=> 'select',
		'choices' => array(
			'' => esc_html__( 'Default', 'phase' ),
			'standard' => esc_html__( 'Standard', 'phase' ),
			'big' => esc_html__( 'Big', 'phase' ),
			'small' => esc_html__( 'Small', 'phase' ),
			'fullheight' => esc_html__( 'Full Height', 'phase' ),
			'none' => esc_html__( 'No header', 'phase' ),
		),
	);

	$mods['navigation']['options']['nav_bar_bg_img'] = array(
		'label'	=> esc_html__( 'Sticky Navigation Bar Background', 'phase' ),
		'id'	=> 'nav_bar_bg_img',
		'type'	=> 'image',
	);

	$mods['navigation']['options']['mega_menu_bg_img'] = array(
		'label'	=> esc_html__( 'Mega Menu Background', 'phase' ),
		'id'	=> 'mega_menu_bg_img',
		'type'	=> 'image',
	);

	$mods['navigation']['options']['side_panel_bg_img'] = array(
		'label'	=> esc_html__( 'Side Panel Background', 'phase' ),
		'id'	=> 'side_panel_bg_img',
		'type'	=> 'image',
	);

	$mods['navigation']['options']['overlay_menu_bg_img'] = array(
		'label'	=> esc_html__( 'Overlay Menu Background', 'phase' ),
		'id'	=> 'overlay_menu_bg_img',
		'type'	=> 'image',
	);

	$mods['navigation']['options']['lateral_menu_bg_img'] = array(
		'label'	=> esc_html__( 'Lateral Menu Background', 'phase' ),
		'id'	=> 'lateral_menu_bg_img',
		'type'	=> 'image',
	);

	$mods['navigation']['options']['mobile_menu_bg_img'] = array(
		'label'	=> esc_html__( 'Mobile Menu Background', 'phase' ),
		'id'	=> 'mobile_menu_bg_img',
		'type'	=> 'image',
	);

	if ( isset( $mods['wolf_videos'] ) ) {
		$mods['wolf_videos']['options']['video_hero_layout'] = array(
			'label'	=> esc_html__( 'Single Video Header Layout', 'phase' ),
			'id'	=> 'video_hero_layout',
			'type'	=> 'select',
			'choices' => array(
				'' => esc_html__( 'Default', 'phase' ),
				'standard' => esc_html__( 'Standard', 'phase' ),
				'big' => esc_html__( 'Big', 'phase' ),
				'small' => esc_html__( 'Small', 'phase' ),
				'fullheight' => esc_html__( 'Full Height', 'phase' ),
				'none' => esc_html__( 'No header', 'phase' ),
			),
		);

		$mods['wolf_videos']['options']['video_category_filter'] = array(
			'id' => 'video_category_filter',
			'label' => esc_html__( 'Category filter (not recommended with a lot of videos)', 'phase' ),
			'type' => 'checkbox',
		);

		$mods['wolf_videos']['options']['products_per_page'] = array(
			'label' => esc_html__( 'Videos per Page', 'phase' ),
			'id' => 'videos_per_page',
			'type' => 'text',
		);

		$mods['wolf_videos']['options']['video_pagination'] = array(
			'id' =>'video_pagination',
			'label' => esc_html__( 'Video Archive Pagination', 'phase' ),
			'type' => 'select',
			'choices' => array(
				'standard_pagination' => esc_html__( 'Numeric Pagination', 'phase' ),
				'load_more' => esc_html__( 'Load More Button', 'phase' ),
			),
		);

		$mods['wolf_videos']['options']['video_display_elements'] = array(
			'id' => 'video_display_elements',
			'label' => esc_html__( 'Post meta to show in single video page', 'phase' ),
			'type' => 'group_checkbox',
			'choices' => array(
				'show_date' => esc_html__( 'Date', 'phase' ),
				'show_author' => esc_html__( 'Author', 'phase' ),
				'show_category' => esc_html__( 'Category', 'phase' ),
				'show_tags' => esc_html__( 'Tags', 'phase' ),
				'show_extra_meta' => esc_html__( 'Extra Meta', 'phase' ),
			),
			'description' => esc_html__( 'Note that some options may be ignored depending on the post display.', 'phase' ),
		);

		if ( class_exists( 'Wolf_Custom_Post_Meta' ) ) {

			$mods['wolf_videos']['options'][] = array(
				'label' => esc_html__( 'Enable Custom Post Meta', 'phase' ),
				'id' => 'video_enable_custom_post_meta',
				'type' => 'group_checkbox',
				'choices' => array(
					'video_enable_views' => esc_html__( 'Views', 'phase' ),
					'video_enable_likes' => esc_html__( 'Likes', 'phase' ),
				),
			);
		}
	}

	if ( isset( $mods['wolf_artists'] ) ) {

		$mods['wolf_artists']['options']['artist_hero_layout'] = array(
			'label'	=> esc_html__( 'Single Artist Header Layout', 'phase' ),
			'id'	=> 'artist_hero_layout',
			'type'	=> 'select',
			'choices' => array(
				'' => esc_html__( 'Default', 'phase' ),
				'standard' => esc_html__( 'Standard', 'phase' ),
				'big' => esc_html__( 'Big', 'phase' ),
				'small' => esc_html__( 'Small', 'phase' ),
				'fullheight' => esc_html__( 'Full Height', 'phase' ),
				'none' => esc_html__( 'No header', 'phase' ),
			),
		);

		$mods['wolf_artists']['options']['artist_single_width'] = array(
			'label'	=> esc_html__( 'Single Artist Content Width', 'phase' ),
			'id'	=> 'artist_single_width',
			'type'	=> 'select',
			'choices' => array(
				'standard' => esc_html__( 'Standard', 'phase' ),
				'wide' => esc_html__( 'Wide', 'phase' ),
			),
		);

		$mods['wolf_artists']['options']['artist_single_layout'] = array(
			'label'	=> esc_html__( 'Single Artist Content Layout', 'phase' ),
			'id'	=> 'artist_single_layout',
			'type'	=> 'select',
			'choices' => array(
				'sidebar-left' => esc_html__( 'Info at Left', 'phase' ),
				'sidebar-right' => esc_html__( 'Info at Right', 'phase' ),
				'centered' => esc_html__( 'Centered', 'phase' ),
				'custom' => esc_html__( 'Custom', 'phase' ),
			),
		);

		if ( class_exists( 'Wolf_Discography' ) ) {
			$mods['wolf_artists']['options']['discography_terms_artist_sync'] = array(
				'label'	=> esc_html__( 'Synchronize discography category automatically when an artist post is created or updated', 'phase' ),
				'id'	=> 'discography_terms_artist_sync',
				'type'	=> 'checkbox',
			);
		}

		if ( class_exists( 'Wolf_Events' ) ) {
			$mods['wolf_artists']['options']['events_terms_artist_sync'] = array(
				'label'	=> esc_html__( 'Synchronize event category automatically when an artist post is created or updated', 'phase' ),
				'id'	=> 'events_terms_artist_sync',
				'type'	=> 'checkbox',
			);
		}

		if ( class_exists( 'Wolf_Videos' ) ) {
			$mods['wolf_artists']['options']['videos_terms_artist_sync'] = array(
				'label'	=> esc_html__( 'Synchronize video category automatically when an artist post is created or updated', 'phase' ),
				'id'	=> 'videos_terms_artist_sync',
				'type'	=> 'checkbox',
			);
		}

		if ( class_exists( 'Wolf_Albums' ) ) {
			$mods['wolf_artists']['options']['albums_terms_artist_sync'] = array(
				'label'	=> esc_html__( 'Synchronize album category automatically when an artist post is created or updated', 'phase' ),
				'id'	=> 'albums_terms_artist_sync',
				'type'	=> 'checkbox',
			);
		}
	}

	if ( isset( $mods['wolf_albums'] ) ) {

		$mods['wolf_albums']['options']['gallery_hero_layout'] = array(
			'label'	=> esc_html__( 'Single Gallery Header Layout', 'phase' ),
			'id'	=> 'gallery_hero_layout',
			'type'	=> 'select',
			'choices' => array(
				'' => esc_html__( 'Default', 'phase' ),
				'standard' => esc_html__( 'Standard', 'phase' ),
				'big' => esc_html__( 'Big', 'phase' ),
				'small' => esc_html__( 'Small', 'phase' ),
				'fullheight' => esc_html__( 'Full Height', 'phase' ),
				'none' => esc_html__( 'No header', 'phase' ),
			),
		);
	}

	if ( isset( $mods['wolf_discography'] ) ) {

		$mods['wolf_discography']['options']['release_hero_layout'] = array(
			'label'	=> esc_html__( 'Single Release Header Layout', 'phase' ),
			'id'	=> 'release_hero_layout',
			'type'	=> 'select',
			'choices' => array(
				'' => esc_html__( 'Default', 'phase' ),
				'standard' => esc_html__( 'Standard', 'phase' ),
				'big' => esc_html__( 'Big', 'phase' ),
				'small' => esc_html__( 'Small', 'phase' ),
				'fullheight' => esc_html__( 'Full Height', 'phase' ),
				'none' => esc_html__( 'No header', 'phase' ),
			),
		);
	}

	if ( isset( $mods['wolf_events'] ) ) {

		$mods['wolf_events']['options']['event_hero_layout'] = array(
			'label'	=> esc_html__( 'Single Event Header Layout', 'phase' ),
			'id'	=> 'event_hero_layout',
			'type'	=> 'select',
			'choices' => array(
				'' => esc_html__( 'Default', 'phase' ),
				'standard' => esc_html__( 'Standard', 'phase' ),
				'big' => esc_html__( 'Big', 'phase' ),
				'small' => esc_html__( 'Small', 'phase' ),
				'fullheight' => esc_html__( 'Full Height', 'phase' ),
				'none' => esc_html__( 'No header', 'phase' ),
			),
		);
	}

	return $mods;
}
add_filter( 'phase_customizer_mods', 'phase_add_mods', 40 );

/**
 * Filter WVC theme accent color
 *
 * @param string $color
 * @return string $color
 */
function phase_set_wvc_secondary_theme_accent_color( $color ) {
	return phase_get_inherit_mod( 'secondary_accent_color' );
}
add_filter( 'wvc_theme_secondary_accent_color', 'phase_set_wvc_theme_secondary_accent_color' );

/**
 * Add theme secondary accent color to shared colors
 *
 * @param array $colors
 * @return array $colors
 */
function phase_wvc_add_secondary_accent_color_option( $colors ) {

	$colors = array( esc_html__( 'Theme Secondary Accent Color', 'phase' ) => 'secondary_accent' ) + $colors;

	return $colors;
}
add_filter( 'wvc_shared_colors', 'phase_wvc_add_secondary_accent_color_option' );

/**
 * Filter WVC shared color hex
 *
 * @param array $colors
 * @return array $colors
 */
function phase_add_secondary_accent_color_hex( $colors ) {
	
	$secondary_accent_color = get_theme_mod( 'secondary_accent_color' );

	if ( $secondary_accent_color ) {
		$colors['secondary_accent'] = $secondary_accent_color;
	}

	return $colors;
}
add_filter( 'wvc_shared_colors_hex', 'phase_add_secondary_accent_color_hex' );

/**
 * Disable single post pagination
 *
 * @param bool $bool
 * @return bool
 */
function phase_do_disable_single_pagination( $bool ) {

	if ( is_singular( 'product' ) ) {
		return true;
	}
	
}
add_filter( 'phase_disable_single_post_pagination', 'phase_do_disable_single_pagination' );

/**
 * Disable single post pagination
 *
 * @param bool $bool
 * @return bool
 */
function phase_disable_single_post_pagination_background( $bool ) {
	return false;
	
}

/**
 * Force show loading overlay
 *
 * @param bool $bool
 * @return bool
 */
function phase_force_display_loading_overlay( $bool ) {
	return true;
}
add_filter( 'phase_display_loading_overlay', 'phase_force_display_loading_overlay' );

/**
 * Force show loading logo
 *
 * @param bool $bool
 * @return bool
 */
function phase_force_display_loading_logo( $bool ) {
	return true;
}
add_filter( 'phase_display_loading_logo', 'phase_force_display_loading_logo' );

/**
 * Add overlay brightness class
 *
 * @param array $classes
 * @return array $classes
 */
function phase_set_overlay_brightness_class( $classes ) {

	if ( 'light' === phase_get_color_tone( phase_get_inherit_mod( 'accent_color', '#1D1D1D' ) ) ) {
		$classes[] = 'overlay-color-light';
	} else {
		$classes[] = 'overlay-color-dark';
	}

	return $classes;

}

/**
 * Loading title markup
 *
 * @param bool $bool
 * @return bool
 */
function phase_loading_title_markup( $html ) {

	if ( 'phase' === phase_get_inherit_mod( 'loading_animation_type' ) ) {

		$title = ( get_theme_mod( 'loading_text' ) ) ? get_theme_mod( 'loading_text' ) : get_bloginfo( 'name' );
		
		ob_start();
		?>
		<div class="phase-loader">
			<div class="phase-loading-spinner-holder">
				<div class="phase-loading-text heading-font"><?php echo esc_attr( $title ); ?><span id="phase-loading-point">.</span></div>
			</div>
		</div>
		<?php
		return ob_get_clean();
	}
}
add_filter( 'phase_loading_logo', 'phase_loading_title_markup' );

/**
 * Set page loaded delay
 *
 * @param int $int
 * @return int
 */
function phase_set_page_loaded_delay( $int ) {

	if ( 'phase' === phase_get_inherit_mod( 'loading_animation_type' ) ) {
		$int = 2000;
	}

	return $int;
}
add_filter( 'phase_page_loaded_delay', 'phase_set_page_loaded_delay' );

/**
 * Albums masonry thumbnail size
 */
function phase_set_album_masonry_thumbnail_size( $size ) {

	return 'phase-masonry-small';

}
add_filter( 'phase_album_masonry_thumbnail_size', 'phase_set_album_masonry_thumbnail_size' );

/**
 * Set sticky menu scrollpoint
 *
 * @param int $int
 * @return int
 */
function phase_set_sticky_menu_scrollpoint( $int ) {

	return 200;
}
add_filter( 'phase_sticky_menu_scrollpoint', 'phase_set_sticky_menu_scrollpoint' );

/**
 * Custom button types
 */
function phase_custom_button_types() {
	return array(
		esc_html__( 'Default', 'phase' ) => 'default',
		esc_html__( 'Slide Hover Effect Primary', 'phase' ) => 'phase_button',
		esc_html__( 'Slide Hover Effect Secondary', 'phase' ) => 'phase_button2',
		esc_html__( 'Theme Style Primary ', 'phase' ) => 'phase_button_alt',
		esc_html__( 'Theme Style Secondary', 'phase' ) => 'phase_button_alt2',
		esc_html__( 'Theme Style Text', 'phase' ) => 'phase_button_text',
	);
}

/**
 * Custom backgorund effect output
 */
function phase_output_row_bg_effect( $html ) {

	ob_start();
	?>
	<div class="phase-bg-overlay"></div>
	<?php
	$html = ob_get_clean();

	return $html;
}
add_filter( 'wvc_background_effect', 'phase_output_row_bg_effect' );

/**
 *  Add phase background effect
 *
 * @param string $effects
 * @return string $effects
 */
function phase_add_wvc_custom_background_effect( $effects ) {
	
	if ( function_exists( 'vc_add_param' ) ) {
		vc_add_param(
			'vc_row',
			array(
				'type' => 'checkbox',
				'heading' => esc_html__( 'Add Film Grain Effect', 'phase' ),
				'param_name' => 'add_effect',
				'group' => esc_html__( 'Style', 'phase' ),
			)
		);

		vc_add_param(
			'vc_column',
			array(
				'type' => 'checkbox',
				'heading' => esc_html__( 'Add Film Grain Effect', 'phase' ),
				'param_name' => 'add_effect',
				'group' => esc_html__( 'Style', 'phase' ),
			)
		);
	}
}
add_action( 'init', 'phase_add_wvc_custom_background_effect' );

/**
 * Remove some params
 */
function phase_remove_vc_params() {

	if ( function_exists( 'vc_remove_param' ) ) {
		
		vc_remove_param( 'wvc_product_index', 'product_display' );
		vc_remove_param( 'wvc_product_index', 'product_text_align' );
		
		vc_remove_param( 'wvc_gallery_index', 'caption_text_alignment' );
		vc_remove_param( 'wvc_release_index', 'caption_text_alignment' );
		vc_remove_param( 'wvc_artist_index', 'caption_text_alignment' );
		vc_remove_param( 'wvc_event_index', 'caption_text_alignment' );
		
		vc_remove_param( 'wvc_interactive_links', 'align' );
		vc_remove_param( 'wvc_interactive_links', 'display' );
		vc_remove_param( 'wvc_interactive_overlays', 'align' );
		vc_remove_param( 'wvc_interactive_overlays', 'display' );
	}
}
add_action( 'init', 'phase_remove_vc_params' );

/**
 * Add button dependencies
 */
function phase_add_button_dependency_params() {

	if ( ! class_exists( 'WPBMap' ) || ! class_exists( 'Wolf_Visual_Composer' ) || ! defined( 'WVC_OK' ) || ! WVC_OK ) {
		return;
	}

	$param = WPBMap::getParam( 'vc_button', 'color' );
	$param['dependency'] = array(
		'element' => 'button_type',
		'value' => 'default',
	);
	vc_update_shortcode_param( 'vc_button', $param );

	$param = WPBMap::getParam( 'vc_button', 'shape' );
	$param['dependency'] = array(
		'element' => 'button_type',
		'value' => 'default',
	);
	vc_update_shortcode_param( 'vc_button', $param );

	$param = WPBMap::getParam( 'vc_button', 'hover_effect' );
	$param['dependency'] = array(
		'element' => 'button_type',
		'value' => 'default',
	);
	vc_update_shortcode_param( 'vc_button', $param );

	$param = WPBMap::getParam( 'vc_cta', 'btn_color' );
	$param['dependency'] = array(
		'element' => 'btn_button_type',
		'value' => 'default',
	);
	vc_update_shortcode_param( 'vc_cta', $param );

	$param = WPBMap::getParam( 'vc_cta', 'btn_shape' );
	$param['dependency'] = array(
		'element' => 'btn_button_type',
		'value' => 'default',
	);
	vc_update_shortcode_param( 'vc_cta', $param );

	$param = WPBMap::getParam( 'vc_cta', 'btn_hover_effect' );
	$param['dependency'] = array(
		'element' => 'btn_button_type',
		'value' => 'default',
	);
	vc_update_shortcode_param( 'vc_cta', $param );

	$param = WPBMap::getParam( 'wvc_advanced_slide', 'b1_color' );
	$param['dependency'] = array(
		'element' => 'b1_button_type',
		'value' => 'default',
	);
	vc_update_shortcode_param( 'wvc_advanced_slide', $param );

	$param = WPBMap::getParam( 'wvc_advanced_slide', 'b1_shape' );
	$param['dependency'] = array(
		'element' => 'b1_button_type',
		'value' => 'default',
	);
	vc_update_shortcode_param( 'wvc_advanced_slide', $param );

	$param = WPBMap::getParam( 'wvc_advanced_slide', 'b1_hover_effect' );
	$param['dependency'] = array(
		'element' => 'b1_button_type',
		'value' => 'default',
	);
	vc_update_shortcode_param( 'wvc_advanced_slide', $param );

	$param = WPBMap::getParam( 'wvc_advanced_slide', 'b2_color' );
	$param['dependency'] = array(
		'element' => 'b2_button_type',
		'value' => 'default',
	);
	vc_update_shortcode_param( 'wvc_advanced_slide', $param );

	$param = WPBMap::getParam( 'wvc_advanced_slide', 'b2_shape' );
	$param['dependency'] = array(
		'element' => 'b2_button_type',
		'value' => 'default',
	);
	vc_update_shortcode_param( 'wvc_advanced_slide', $param );

	$param = WPBMap::getParam( 'wvc_advanced_slide', 'b2_hover_effect' );
	$param['dependency'] = array(
		'element' => 'b2_button_type',
		'value' => 'default',
	);
	vc_update_shortcode_param( 'wvc_advanced_slide', $param );
}
add_action( 'init', 'phase_add_button_dependency_params' );

/**
 * Filter button attribute
 *
 * @param array $atts
 * @return array $atts
 */
function woltheme_filter_button_atts( $atts ) {
	if ( isset( $atts['button_type'] ) && 'default' !== $atts['button_type'] ) {
		$atts['shape'] = '';
		$atts['color'] = '';
		$atts['hover_effect'] = '';
		$atts['el_class'] .= ' ' . $atts['button_type'];
	}

	return $atts;
}
add_filter( 'wvc_button_atts', 'woltheme_filter_button_atts' );

/**
 * Filter CTA button attribute
 *
 * @param array $atts the shortcode atts we get
 * @param array $btn_params the button attribute to filter
 * @return array $btn_params
 */
function woltheme_filter_cta_button_atts( $btn_params, $atts ) {
	if ( isset( $atts['btn_button_type'] ) && 'default' !== $atts['btn_button_type'] ) {
		$btn_params['shape'] = '';
		$btn_params['color'] = '';
		$btn_params['hover_effect'] = '';
		$btn_params['el_class'] .= ' ' . $atts['btn_button_type'];
	}

	return $btn_params;
}
add_filter( 'wvc_cta_button_atts', 'woltheme_filter_cta_button_atts', 10, 2 );

/**
 * Filter advanced slider button 1 attribute
 *
 * @param array $atts the shortcode atts we get
 * @param array $b1_params the button attribute to filter
 * @return array $b1_params
 */
function woltheme_filter_b1_button_atts( $b1_params, $atts ) {
	if ( isset( $atts['b1_button_type'] ) && 'default' !== $atts['b1_button_type'] ) {
		$b1_params['shape'] = '';
		$b1_params['color'] = '';
		$b1_params['hover_effect'] = '';
		$b1_params['el_class'] .= ' ' . $atts['b1_button_type'];
	}

	return $b1_params;
}
add_filter( 'wvc_advanced_slider_b1_button_atts', 'woltheme_filter_b1_button_atts', 10, 2 );

/**
 * Filter advanced slider button 1 attribute
 *
 * @param array $atts the shortcode atts we get
 * @param array $b2_params the button attribute to filter
 * @return array $b2_params
 */
function woltheme_filter_b2_button_atts( $b2_params, $atts ) {
	if ( isset( $atts['b2_button_type'] ) && 'default' !== $atts['b2_button_type'] ) {
		$b2_params['shape'] = '';
		$b2_params['color'] = '';
		$b2_params['hover_effect'] = '';
		$b2_params['el_class'] .= ' ' . $atts['b2_button_type'];
	}

	return $b2_params;
}
add_filter( 'wvc_advanced_slider_b2_button_atts', 'woltheme_filter_b2_button_atts', 10, 2 );

/**
 * Add theme button option to Button element
 */
function phase_add_theme_buttons() {

	if ( function_exists( 'vc_add_params' ) ) {
		vc_add_params(
			'vc_button',
			array(
				array(
					'heading' => esc_html__( 'Button Type', 'phase' ),
					'param_name' => 'button_type',
					'type' => 'dropdown',
					'value' => phase_custom_button_types(),
					'weight' => 1000,
				),
			)
		);

		vc_add_params(
			'vc_cta',
			array(
				array(
					'heading' => esc_html__( 'Button Type', 'phase' ),
					'param_name' => 'btn_button_type',
					'type' => 'dropdown',
					'value' => phase_custom_button_types(),
					'weight' => 10,
					'group' => esc_html__( 'Button', 'phase' ),
				),
			)
		);

		vc_add_params(
			'wvc_advanced_slide',
			array(
				array(
					'heading' => esc_html__( 'Button Type', 'phase' ),
					'param_name' => 'b1_button_type',
					'type' => 'dropdown',
					'value' => phase_custom_button_types(),
					'weight' => 10,
					'group' => esc_html__( 'Button 1', 'phase' ),
					'dependency' => array(
						'element' => 'add_button_1',
						'value' => array( 'true' ),
					),
				),
			)
		);

		vc_add_params(
			'wvc_advanced_slide',
			array(
				array(
					'heading' => esc_html__( 'Button Type', 'phase' ),
					'param_name' => 'b2_button_type',
					'type' => 'dropdown',
					'value' => phase_custom_button_types(),
					'weight' => 10,
					'group' => esc_html__( 'Button 2', 'phase' ),
					'dependency' => array(
						'element' => 'add_button_2',
						'value' => array( 'true' ),
					),
				),
			)
		);
	}
}
add_action( 'init', 'phase_add_theme_buttons' );

/**
 * Page grid thumbnail size
 */
function phase_set_page_grid_overlay_thumbnail_size( $size ) {

	return array( 565, 220 );

}
add_filter( 'phase_page_grid_overlay_thumbnail_size', 'phase_set_page_grid_overlay_thumbnail_size' );
add_filter( 'phase_page_grid_thumbnail_size', 'phase_set_page_grid_overlay_thumbnail_size' );

/**
 * Add single audio skins
 */
function phase_add_single_audio_skins() {
	if ( function_exists( 'vc_add_params' ) ) {
		vc_add_params(
			'wvc_audio',
			array(
				array(
					'heading' => esc_html__( 'Skin', 'phase' ),
					'param_name' => 'skin',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Dark', 'phase' ) => 'default',
						esc_html__( 'Transparent', 'phase' ) => 'transparent',
					),
				),
			)
		);
	}
}
add_action( 'init', 'phase_add_single_audio_skins' );

/**
 * Add style option to tabs element
 */
function phase_add_vc_accordion_and_tabs_options() {
	if ( function_exists( 'vc_add_params' ) ) {
		vc_add_params(
			'vc_tabs',
			array(
				array(
					'heading' => esc_html__( 'Background', 'phase' ),
					'param_name' => 'background',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Solid', 'phase' ) => 'solid',
						esc_html__( 'Transparent', 'phase' ) => 'transparent',
					),
					'weight' => 1000,
				),
			)
		);
	}

	if ( function_exists( 'vc_add_params' ) ) {
		vc_add_params(
			'vc_accordion',
			array(
				array(
					'heading' => esc_html__( 'Background', 'phase' ),
					'param_name' => 'background',
					'type' => 'dropdown',
					'value' => array(
						esc_html__( 'Solid', 'phase' ) => 'solid',
						esc_html__( 'Transparent', 'phase' ) => 'transparent',
					),
					'weight' => 1000,
				),
			)
		);
	}
}
add_action( 'init', 'phase_add_vc_accordion_and_tabs_options' );

/**
 * Filter tabs shortcode attribute
 */
function phase_add_vc_tabs_params( $params ) {

	if ( isset( $params['background'] ) ) {
		$params['el_class'] = $params['el_class'] . ' wvc-tabs-background-' . $params['background'];
	}

	return $params;
}
add_filter( 'shortcode_atts_vc_tabs', 'phase_add_vc_tabs_params' );

/**
 * Filter accordion shortcode attribute
 */
function phase_add_vc_accordion_params( $params ) {

	if ( isset( $params['background'] ) ) {
		$params['el_class'] = $params['el_class'] . ' wvc-accordion-background-' . $params['background'];
	}

	return $params;
}
add_filter( 'shortcode_atts_vc_accordion', 'phase_add_vc_accordion_params' );


/**
 * Add additional JS scripts and functions
 */
function phase_enqueue_additional_scripts() {
	
	$version = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? time() : phase_get_theme_version();

	
	if ( ! phase_is_wvc_activated() ) {
		wp_register_style( 'ionicons', get_template_directory_uri() . '/assets/css/lib/font/ionicons/ionicons.min.css', array(), phase_get_theme_version() );
		wp_register_style( 'elegant-icons', get_template_directory_uri() . '/assets/css/lib/fonts/elegant-icons/elegant-icons.min.css', array(), phase_get_theme_version() );
	}

	wp_enqueue_style( 'vc_linecons' );
	wp_enqueue_style( 'ionicons' );
	wp_enqueue_style( 'elegant-icons' );

	wp_enqueue_script( 'jquery-effects-core' );
	wp_enqueue_script( 'parallax-scroll' );
	wp_enqueue_script( 'phase-custom', get_template_directory_uri() . '/assets/js/t/phase.js', array( 'jquery' ), $version, true );
}
add_action( 'wp_enqueue_scripts', 'phase_enqueue_additional_scripts', 40 );

/**
 *  Filter WVC bg object fit
 *
 * Diable oject fit if "phase" bg effect is used
 *
 * @param string $do_of
 * @return string $do_of
 */
function phase_filters_wvc_bg_object_fit( $do_of, $args ) {
	
	if ( isset( $args['background_effect'] ) && 'phase' === $args['background_effect'] ) {
		$do_of = false;
	}

	return $do_of;
}

/**
 *  Set smooth scroll speed
 *
 * @param string $speed
 * @return string $speed
 */
function phase_set_smooth_scroll_speed( $speed ) {
	return 1500;
}
add_filter( 'phase_smooth_scroll_speed', 'phase_set_smooth_scroll_speed' );
add_filter( 'wvc_smooth_scroll_speed', 'phase_set_smooth_scroll_speed' );

/**
 *  Set smooth scroll easing effect
 *
 * @param string $ease
 * @return string $ease
 */
function phase_set_smooth_scroll_ease( $ease ) {
	return 'easeOutCubic';
}
add_filter( 'phase_smooth_scroll_ease', 'phase_set_smooth_scroll_ease' );
add_filter( 'wvc_smooth_scroll_ease', 'phase_set_smooth_scroll_ease' );
add_filter( 'wvc_fp_easing', 'phase_set_smooth_scroll_ease' );

/**
 * Returns CSS for the color schemes.
 *
 * @param array $colors Color scheme colors.
 * @return string Color scheme CSS.
 */
function phase_edit_color_scheme_css( $output, $colors ) {

	extract( $colors );

	$output = '';

	$border_color = vsprintf( 'rgba( %s, 0.08)', phase_hex_to_rgb( $strong_text_color ) );
	$overlay_panel_bg_color = vsprintf( 'rgba( %s, 0.95)', phase_hex_to_rgb( $submenu_background_color ) );

	$link_selector = '.link, p:not(.attachment) > a:not(.no-link-style):not(.button):not(.button-download):not(.added_to_cart):not(.button-secondary):not(.menu-link):not(.filter-link):not(.entry-link):not(.more-link):not(.wvc-image-inner):not(.wvc-button):not(.wvc-bigtext-link):not(.wvc-fittext-link):not(.ui-tabs-anchor):not(.wvc-icon-title-link):not(.wvc-icon-link):not(.wvc-social-icon-link):not(.wvc-team-member-social):not(.wolf-tweet-link):not(.author-link):not(.gallery-quickview)';
	$link_selector_after = '.link:after, p:not(.attachment) > a:not(.no-link-style):not(.button):not(.button-download):not(.added_to_cart):not(.button-secondary):not(.menu-link):not(.filter-link):not(.entry-link):not(.more-link):not(.wvc-image-inner):not(.wvc-button):not(.wvc-bigtext-link):not(.wvc-fittext-link):not(.ui-tabs-anchor):not(.wvc-icon-title-link):not(.wvc-icon-link):not(.wvc-social-icon-link):not(.wvc-team-member-social):not(.wolf-tweet-link):not(.author-link):not(.gallery-quickview):after';

	$output .= "/* Color Scheme */

	/* Body Background Color */
	body,
	.frame-border{
		background-color: $body_background_color;
	}

	/* Page Background Color */
	.site-header,
	.post-header-container,
	.content-inner,
	#logo-bar,
	.nav-bar,
	.loading-overlay,
	.no-hero #hero,
	.wvc-font-default,
	#topbar{
		background-color: $page_background_color;
	}

	.wvc-interactive-overlays-inner:before,
	.wvc-interactive-links-inner:before{
	}

	.spinner:before,
	.spinner:after{
		background-color: $page_background_color;
	}

	/* Submenu color */
	#site-navigation-primary-desktop .mega-menu-panel,
	#site-navigation-primary-desktop ul.sub-menu,
	#mobile-menu-panel,
	.mobile-menu-toggle .nav-bar,
	.offcanvas-menu-panel,
	.lateral-menu-panel,
	.side-panel{
		background:$submenu_background_color;
	}

	.menu-hover-style-border-top .nav-menu li:hover,
	.menu-hover-style-border-top .nav-menu li.current_page_item,
	.menu-hover-style-border-top .nav-menu li.current-menu-parent,
	.menu-hover-style-border-top .nav-menu li.current-menu-ancestor,
	.menu-hover-style-border-top .nav-menu li.current-menu-item,
	.menu-hover-style-border-top .nav-menu li.menu-link-active{
		box-shadow: inset 0px 5px 0px 0px $submenu_background_color;
	}

	.menu-hover-style-plain .nav-menu li:hover,
	.menu-hover-style-plain .nav-menu li.current_page_item,
	.menu-hover-style-plain .nav-menu li.current-menu-parent,
	.menu-hover-style-plain .nav-menu li.current-menu-ancestor,
	.menu-hover-style-plain .nav-menu li.current-menu-item,
	.menu-hover-style-plain .nav-menu li.menu-link-active{
		background:$submenu_background_color;
	}

	.panel-closer-overlay{
		background:$submenu_background_color;
	}

	.overlay-menu-panel{
		background:$overlay_panel_bg_color;
	}

	/* Sub menu Font Color */
	.nav-menu-desktop li ul li:not(.menu-button-primary):not(.menu-button-secondary) .menu-item-text-container,
	.nav-menu-desktop li ul.sub-menu li:not(.menu-button-primary):not(.menu-button-secondary).menu-item-has-children > a:before,
	.nav-menu-desktop li ul li.not-linked > a:first-child .menu-item-text-container,
	.mobile-menu-toggle .nav-bar .hamburger-icon .line{
		color: $submenu_font_color;
	}

	.nav-menu-vertical li a,
	.nav-menu-mobile li a,
	.nav-menu-vertical li.menu-item-has-children:before,
	.nav-menu-vertical li.page_item_has_children:before,
	.nav-menu-vertical li.active:before,
	.nav-menu-mobile li.menu-item-has-children:before,
	.nav-menu-mobile li.page_item_has_children:before,
	.nav-menu-mobile li.active:before{
		color: $submenu_font_color!important;
	}

	.nav-menu-desktop li ul.sub-menu li.menu-item-has-children > a:before{
		color: $submenu_font_color;
	}

	body.wolf.mobile-menu-toggle .hamburger-icon .line,
	body.wolf.overlay-menu-toggle.menu-style-transparent .hamburger-icon .line,
	body.wolf.overlay-menu-toggle.menu-style-semi-transparent-white .hamburger-icon .line,
	body.wolf.overlay-menu-toggle.menu-style-semi-transparent-black .hamburger-icon .line,
	body.wolf.offcanvas-menu-toggle.menu-style-transparent .hamburger-icon .line,
	body.wolf.offcanvas-menu-toggle.menu-style-semi-transparent-white .hamburger-icon .line,
	body.wolf.offcanvas-menu-toggle.menu-style-semi-transparent-black .hamburger-icon .line,
	body.wolf.side-panel-toggle.menu-style-transparent .hamburger-icon .line,
	body.wolf.side-panel-toggle.menu-style-semi-transparent-white .hamburger-icon .line,
	body.wolf.side-panel-toggle.menu-style-semi-transparent-black .hamburger-icon .line {
		background-color: $submenu_font_color !important;
	}

	.overlay-menu-toggle .nav-bar,
	.overlay-menu-toggle .nav-bar a,
	.overlay-menu-toggle .nav-bar strong {
		color: $submenu_font_color !important;
	}

	.overlay-menu-toggle.menu-style-transparent.hero-font-light a,
	.overlay-menu-toggle.menu-style-semi-transparent-black.hero-font-light a,
	.overlay-menu-toggle.menu-style-semi-transparent-white.hero-font-light a,
	.menu-layout-overlay.desktop .overlay-menu-panel a,
	.menu-layout-lateral.desktop .lateral-menu-panel a,
	.lateral-menu-panel-inner,
	.lateral-menu-panel-inner a{
		color: $submenu_font_color;
	}

	.mobile-menu-toggle.menu-style-transparent.hero-font-light .logo-svg *,
	.overlay-menu-toggle.menu-style-transparent.hero-font-light .logo-svg *,
	.overlay-menu-toggle.menu-style-semi-transparent-black.hero-font-light .logo-svg *,
	.overlay-menu-toggle.menu-style-semi-transparent-white.hero-font-light .logo-svg *,
	.menu-layout-overlay.desktop .overlay-menu-panel .logo-svg *,
	.menu-layout-lateral.desktop .lateral-menu-panel .logo-svg *,
	.lateral-menu-panel-inner .logo-svg *{
		fill:$submenu_font_color!important;
	}

	.cart-panel,
	.cart-panel a,
	.cart-panel strong,
	.cart-panel b{
		color: $submenu_font_color!important;
	}

	/* Accent Color */
	.accent{
		color:$accent_color;
	}

	#phase-loading-point{
		color:$accent_color;
	}

	.wvc-single-image-overlay-title span:after{
		color:$accent_color;
	}

	$link_selector:hover{
		color:$accent_color;
		border-color:$accent_color;
	}

	$link_selector_after{
		background-color:$accent_color!important;
	}

	.wolf-bigtweet-content a{
		color:$accent_color!important;
	}

	.nav-menu li.sale .menu-item-text-container:before,
	.nav-menu-mobile li.sale .menu-item-text-container:before{
		background:$accent_color!important;
	}

	.nav-menu-desktop li ul.sub-menu li:not(.menu-button-primary):not(.menu-button-secondary) a:hover .menu-item-inner .menu-item-text-container, .nav-menu-desktop li ul.sub-menu li:not(.menu-button-primary):not(.menu-button-secondary) a:focus .menu-item-inner .menu-item-text-container {
		color:$accent_color;
	}

	.entry-post-standard .entry-title a:hover,
	.entry-artist-list a:hover{
		color:$accent_color!important;
	}

	.entry-product .woocommerce-Price-amount{
		color:$accent_color;
	}

	.entry-post-grid_classic:hover .entry-title,
	.entry-post-masonry:hover .entry-title,
	.entry-post-list:hover .entry-title,
	.entry-post-masonry_modern.format-standard:hover .entry-title,
	.entry-post-masonry_modern.format-chat:hover .entry-title,
	.wolf-tweet-link:hover{
		color:$accent_color;
	}

	.single-artist .artist-meta a>span{
		color:$accent_color;
	}
	.proof-photo.selected .proof-photo__bg,
	.widget_price_filter .ui-slider .ui-slider-range,
	mark,
	p.demo_store,
	.woocommerce-store-notice{
		background-color:$accent_color;
	}

	.button-secondary{
		background-color:$accent_color;
		border-color:$accent_color;
	}

	.nav-menu li.menu-button-primary > a:first-child > .menu-item-inner{
		border-color:$accent_color;
		background-color:$accent_color;
	}

	.nav-menu li.menu-button-secondary > a:first-child > .menu-item-inner{
		border-color:$accent_color;
	}

	.nav-menu li.menu-button-secondary > a:first-child > .menu-item-inner:hover{
		background-color:$accent_color;
	}

	.fancybox-thumbs>ul>li:before{
		border-color:$accent_color;
	}

	input[type=text]:focus, input[type=search]:focus, input[type=tel]:focus, input[type=time]:focus, input[type=url]:focus, input[type=week]:focus, input[type=password]:focus, input[type=color]:focus, input[type=date]:focus, input[type=datetime]:focus, input[type=datetime-local]:focus, input[type=email]:focus, input[type=month]:focus, input[type=number]:focus, textarea:focus{
	}

	.button,
	.button-download,
	.added_to_cart,
	input[type='submit'],
	.more-link{
		background-color:$accent_color;
		border-color:$accent_color;
	}

	span.onsale,
	.wvc-background-color-accent,
	.entry-post-grid_classic .category-label:hover,
	.entry-post-grid_modern .category-label:hover,
	.entry-post-masonry .category-label:hover,
	.entry-post-masonry_modern .category-label:hover,
	.entry-post-metro .category-label:hover,
	.entry-post-metro_modern .category-label:hover,
	.entry-post-mosaic .category-label:hover,
	.entry-post-list .category-label:hover,
	.entry-post-lateral .category-label:hover,
	{
		background-color:$accent_color;
	}

	span.onsale{
		background-color:$accent_color!important;
	}

	.page-numbers.current{
		background-color:$accent_color!important;
	}

	.wvc-highlight-accent{
		background-color:$accent_color;
		color:#fff;
	}

	.wvc-icon-background-color-accent{
		box-shadow:0 0 0 0 $accent_color;
		background-color:$accent_color;
		color:$accent_color;
		border-color:$accent_color;
	}

	.wvc-icon-background-color-accent .wvc-icon-background-fill{
		box-shadow:0 0 0 0 $accent_color;
		background-color:$accent_color;
	}

	.wvc-button-background-color-accent{
		background-color:$accent_color;
		color:$accent_color;
		border-color:$accent_color;
	}

	.wvc-button-background-color-accent .wvc-button-background-fill{
		box-shadow:0 0 0 0 $accent_color;
		background-color:$accent_color;
	}

	.wvc-svg-icon-color-accent svg * {
		stroke:$accent_color!important;
	}

	.wvc-one-page-nav-bullet-tip{
		background-color: $accent_color;
	}

	.wvc-one-page-nav-bullet-tip:before{
		border-color: transparent transparent transparent $accent_color;
	}

	.accent,
	.comment-reply-link,
	.bypostauthor .avatar,
	.wolf-bigtweet-content:before{
		color:$accent_color;
	}

	.wvc-button-color-button-accent,
	.more-link,
	.buton-accent{
		background-color: $accent_color;
		border-color: $accent_color;
	}

	.wvc-ils-active .wvc-ils-item-title:after,
	.wvc-interactive-link-item a:hover .wvc-ils-item-title:after {
	    color:$accent_color;
	}

	.wvc-io-active .wvc-io-item-title:after,
	.wvc-interactive-overlay-item a:hover .wvc-io-item-title:after {
	    color:$accent_color;
	}

	/*.wvc-ils-item-title:before,
	.wvc-io-item-title:before{
		background-color: $accent_color;
	}*/
	
	/* WVC icons */
	.wvc-icon-color-accent{
		color:$accent_color;
	}

	.wvc-icon-background-color-accent{
		box-shadow:0 0 0 0 $accent_color;
		background-color:$accent_color;
		color:$accent_color;
		border-color:$accent_color;
	}

	.wvc-icon-background-color-accent .wvc-icon-background-fill{
		box-shadow:0 0 0 0 $accent_color;
		background-color:$accent_color;
	}

	#ajax-progress-bar,
	.side-panel,
	.cart-icon-product-count{
		background:$accent_color;
	}

	.background-accent,
	.mejs-container .mejs-controls .mejs-time-rail .mejs-time-current,
	.mejs-container .mejs-controls .mejs-time-rail .mejs-time-current, .mejs-container .mejs-controls .mejs-horizontal-volume-slider .mejs-horizontal-volume-current{
		background: $accent_color!important;
	}

	.trigger{
		background-color: $accent_color!important;
		border : solid 1px $accent_color;
	}

	.bypostauthor .avatar {
		border: 3px solid $accent_color;
	}

	::selection {
		background: $accent_color;
	}
	::-moz-selection {
		background: $accent_color;
	}

	.spinner{
		color:$accent_color;
	}

	/*********************
		WVC
	***********************/

	.wvc-icon-box.wvc-icon-type-circle .wvc-icon-no-custom-style.wvc-hover-fill-in:hover, .wvc-icon-box.wvc-icon-type-square .wvc-icon-no-custom-style.wvc-hover-fill-in:hover {
		-webkit-box-shadow: inset 0 0 0 1em $accent_color;
		box-shadow: inset 0 0 0 1em $accent_color;
		border-color: $accent_color;
	}

	.wvc-pricing-table-featured-text,
	.wvc-pricing-table-price-strike:before,
	.wvc-pricing-table-button a{
		background: $accent_color;
	}

	.wvc-pricing-table-price,
	.wvc-pricing-table-currency{
		color: $accent_color;
	}

	.wvc-team-member-social-container a:hover{
		color: $accent_color;
	}

	/* Main Text Color */
	body,
	.nav-label{
		color:$main_text_color;
	}

	.spinner-color, .sk-child:before, .sk-circle:before, .sk-cube:before{
		background-color: $main_text_color!important;
	}

	/* Secondary Text Color */

	/* Strong Text Color */
	a,strong,
	.products li .price,
	.products li .star-rating,
	.wr-print-button,
	table.cart thead, #content table.cart thead{
		color: $strong_text_color;
	}

	.menu-hover-style-underline .nav-menu-desktop li a span.menu-item-text-container:after,
	.menu-hover-style-underline-centered .nav-menu-desktop li a span.menu-item-text-container:after{
		background: $strong_text_color;
	}

	.menu-hover-style-line .nav-menu li a span.menu-item-text-container:after{
		background-color: $strong_text_color;
	}

	.bit-widget-container,
	.entry-link{
		color: $strong_text_color;
	}

	.wr-stars>span.wr-star-voted:before, .wr-stars>span.wr-star-voted~span:before{
		color: $strong_text_color!important;
	}

	/* Border Color */
	.author-box,
	input[type=text],
	input[type=search],
	input[type=tel],
	input[type=time],
	input[type=url],
	input[type=week],
	input[type=password],
	input[type=checkbox],
	input[type=color],
	input[type=date],
	input[type=datetime],
	input[type=datetime-local],
	input[type=email],
	input[type=month],
	input[type=number],
	select,
	textarea{
		border-color:$border_color;
	}

	.widget-title,
	.woocommerce-tabs ul.tabs{
		border-bottom-color:$border_color;
	}

	.widget_layered_nav_filters ul li a{
		border-color:$border_color;
	}

	hr{
		background:$border_color;
	}
	";

	$link_selector_after = '.link:after, .underline:after, p:not(.attachment) > a:not(.no-link-style):not(.button):not(.button-download):not(.added_to_cart):not(.button-secondary):not(.menu-link):not(.filter-link):not(.entry-link):not(.more-link):not(.wvc-image-inner):not(.wvc-button):not(.wvc-bigtext-link):not(.wvc-fittext-link):not(.ui-tabs-anchor):not(.wvc-icon-title-link):not(.wvc-icon-link):not(.wvc-social-icon-link):not(.wvc-team-member-social):not(.wolf-tweet-link):not(.author-link):after';
	$link_selector_before = '.link:before, .underline:before, p:not(.attachment) > a:not(.no-link-style):not(.button):not(.button-download):not(.added_to_cart):not(.button-secondary):not(.menu-link):not(.filter-link):not(.entry-link):not(.more-link):not(.wvc-image-inner):not(.wvc-button):not(.wvc-bigtext-link):not(.wvc-fittext-link):not(.ui-tabs-anchor):not(.wvc-icon-title-link):not(.wvc-icon-link):not(.wvc-social-icon-link):not(.wvc-team-member-social):not(.wolf-tweet-link):not(.author-link):before';

	$output .= "

		$link_selector_after,
		$link_selector_before{
			background: $accent_color!important;
		}

		.category-filter ul li a:before{
			background-color:$accent_color!important;
		}

		.category-label,
		#back-to-top:hover{
			background:$accent_color!important;
		}

		.entry-video:hover .video-play-button,
		.video-opener:hover{
			border-left-color:$accent_color!important;
		}

	
		.widget.widget_pages ul li a:hover,
		.widget.widget_recent_entries ul li a:hover,
		.widget.widget_recent_comments ul li a:hover,
		.widget.widget_archive ul li a:hover,
		.widget.widget_categories ul li a:hover,
		.widget.widget_meta ul li a:hover,
		.widget.widget_product_categories ul li a:hover,
		.widget.widget_nav_menu ul li a:hover,

		.wvc-font-dark .widget.widget_pages ul li a:hover,
		.wvc-font-dark .widget.widget_recent_entries ul li a:hover,
		.wvc-font-dark .widget.widget_recent_comments ul li a:hover,
		.wvc-font-dark .widget.widget_archive ul li a:hover,
		.wvc-font-dark .widget.widget_categories ul li a:hover,
		.wvc-font-dark .widget.widget_meta ul li a:hover,
		.wvc-font-dark .widget.widget_product_categories ul li a:hover,
		.wvc-font-dark .widget.widget_nav_menu ul li a:hover,

		.wvc-font-light .widget.widget_pages ul li a:hover,
		.wvc-font-light .widget.widget_recent_entries ul li a:hover,
		.wvc-font-light .widget.widget_recent_comments ul li a:hover,
		.wvc-font-light .widget.widget_archive ul li a:hover,
		.wvc-font-light .widget.widget_categories ul li a:hover,
		.wvc-font-light .widget.widget_meta ul li a:hover,
		.wvc-font-light .widget.widget_product_categories ul li a:hover,
		.wvc-font-light .widget.widget_nav_menu ul li a:hover{
			color:$accent_color!important;
		}
	
		.widget.widget_tag_cloud .tagcloud a:hover,
		.wvc-font-dark .widget.widget_tag_cloud .tagcloud a:hover,
		.wvc-font-light .widget.widget_tag_cloud .tagcloud a:hover{
			color:$accent_color!important;
		}

		.wvc-breadcrumb a:hover{
			color:$accent_color!important;
		}

		.nav-menu-desktop > li:not(.menu-button-primary):not(.menu-button-secondary) > a:first-child .menu-item-text-container:before{
			color:$accent_color;
		}

		.accent-color-light .category-label{
			color:#333!important;
		}

		.accent-color-dark .category-label{
			color:#fff!important;
		}

		.accent-color-light #back-to-top:hover:after{
			color:#333!important;
		}

		.accent-color-dark #back-to-top:hover:after{
			color:#fff!important;
		}

		.phase_button{
			background:$accent_color;
		}

		.phase_button2 .wvc-button-background-fill{
			background:$accent_color;
		}

		.phase_button_text:hover{
			color: $accent_color;
		}
		
		.phase_button_alt:not(:hover){
			background:$accent_color;
			border-color:$accent_color;
		}

		.phase_button_alt2:hover{
			background:$accent_color!important;
			border-color:$accent_color!important;
		}

		.wvc-mailchimp-email{
			border-color:$accent_color!important;
		}

	
		.wpcf7-submit,
		.wpcf7-button-primary,
		.wvc-mailchimp-submit,
		input[type=submit]{
			background:$accent_color!important;
			border-color:$accent_color!important;
		}

		.single_add_to_cart_button{
			background:$accent_color!important;
			border-color:$accent_color!important;
		}

		.single-product .quantity .qty{
			border-color:$accent_color;
		}

		.single_add_to_cart_button:hover{
			border-color:$accent_color!important;
		}

		input.wvc-mailchimp-submit:hover{
			border-color: $accent_color!important;
			color: $accent_color!important;
		}
					
		.wvc-ils-item-title:after{
		}

		ul.wc-tabs li:hover a,
		ul.wc-tabs li.ui-tabs-active a,
		ul.wc-tabs li.active a,
		ul.wvc-tabs-menu li:hover a,
		ul.wvc-tabs-menu li.ui-tabs-active a,
		ul.wvc-tabs-menu li.active a{
			box-shadow: inset 0 -2px 0 0 $accent_color!important;
		}

		ul.wvc-tabs-menu li:hover a, ul.wvc-tabs-menu li.ui-tabs-active a,
		ul.wvc-tabs-menu li.active a,
		ul.wc-tabs li:hover a,
		ul.wc-tabs li.ui-tabs-active a,
		ul.wc-tabs li.active a{
			color: $accent_color!important;
		}

		.wvc-accordion .wvc-accordion-tab.ui-state-active {
    			border-bottom-color: $accent_color;
    		}

		/* Secondary accent color */
		.wvc-text-color-secondary_accent{
			color:$secondary_accent_color;
		}

		.single-product .entry-single.sale ins .woocommerce-Price-amount{
			color:$accent_color;
		}

		.wolf-bigtweet-content:before,
		.wolf-bigtweet-content a{
			color:$accent_color!important;
		}

		.wvc-background-color-secondary_accent{
			background-color:$secondary_accent_color;
		}

		.wvc-highlight-secondary_accent{
			background-color:$secondary_accent_color;
			color:#fff;
		}

		.wvc-icon-background-color-secondary_accent{
			box-shadow:0 0 0 0 $secondary_accent_color;
			background-color:$secondary_accent_color;
			color:$secondary_accent_color;
			border-color:$secondary_accent_color;
		}

		.wvc-icon-background-color-secondary_accent .wvc-icon-background-fill{
			box-shadow:0 0 0 0 $secondary_accent_color;
			background-color:$secondary_accent_color;
		}

		.wvc-button-background-color-secondary_accent{
			background-color:$secondary_accent_color;
			color:$secondary_accent_color;
			border-color:$secondary_accent_color;
		}

		.wvc-button-background-color-secondary_accent .wvc-button-background-fill{
			box-shadow:0 0 0 0 $secondary_accent_color;
			background-color:$secondary_accent_color;
		}

		.wvc-svg-icon-color-secondary_accent svg * {
			stroke:$secondary_accent_color!important;
		}

		.wvc-button-color-button-secondary_accent{
			background-color: $secondary_accent_color;
			border-color: $secondary_accent_color;
		}

		.wvc-pricing-table-price,
		.wvc-pricing-table-currency {
			color: $secondary_accent_color;
		}
		
		.wvc-pricing-table-button a,
		.wvc-pricing-table-price-strike:before {
			background-color: $secondary_accent_color;
		}

		.wvc-pricing-table-featured .wvc-pricing-table-price,
		.wvc-pricing-table-featured .wvc-pricing-table-currency {
			color: $accent_color;
		}
		
		.wvc-pricing-table-featured .wvc-pricing-table-button a,
		.wvc-pricing-table-featured .wvc-pricing-table-price-strike:before {
			background-color: $accent_color;
		}
		
		/* WVC icons */
		.wvc-icon-color-secondary_accent{
			color:$secondary_accent_color;
		}

		.wvc-icon-background-color-secondary_accent{
			box-shadow:0 0 0 0 $secondary_accent_color;
			background-color:$secondary_accent_color;
			color:$secondary_accent_color;
			border-color:$secondary_accent_color;
		}

		.wvc-icon-background-color-secondary_accent .wvc-icon-background-fill{
			box-shadow:0 0 0 0 $secondary_accent_color;
			background-color:$secondary_accent_color;
		}

	";
	if ( preg_match( '/dark/', phase_get_theme_mod( 'color_scheme' ) ) ) {
		$output .= ".wvc-background-color-default.wvc-font-light{
			background-color:$page_background_color;
		}";
	}
	if ( preg_match( '/light/', phase_get_theme_mod( 'color_scheme' ) ) ) {
		$output .= ".wvc-background-color-default.wvc-font-dark{
			background-color:$page_background_color;
		}";
	}

	return $output;
}
add_filter( 'phase_color_scheme_output', 'phase_edit_color_scheme_css', 10, 2 );

/**
 * Add form in no result page
 *
 * @param string $string
 * @return string $string
 */
function phase_set_entry_tag_list_separator( $string ) {
	
	$string = ', ';

	return $string;
}
add_action( 'phase_entry_tag_list_separator', 'phase_set_entry_tag_list_separator' );
/**
 * Add MP3 player on single product page
 */
function phase_add_audio_player_on_single_product_page() {

	$output = '';
	$audio_meta = get_post_meta( get_the_ID(), '_post_product_mp3', true );

	if ( $audio_meta ) {
		$audio_attrs = array(
			'src' => esc_url( $audio_meta ),
			'loop' => false,
			'autoplay' => false,
			'preload'  => 'auto',
		);

		$output = wp_audio_shortcode( $audio_attrs );
	}

	echo $output;
}
add_action( 'woocommerce_single_product_summary', 'phase_add_audio_player_on_single_product_page', 14 );

/**
 * Minimal player
 *
 * Displays a play/pause audio player on product grid
 */
function phase_minimal_player( $post_id = null ) {
	$post_id = ( $post_id ) ? $post_id : get_the_ID();
	$audio_meta = get_post_meta( get_the_ID(), '_post_product_mp3', true );
	$rand = rand( 0, 99999 );

	if ( ! $audio_meta ) {
		return;
	}
	?>
	<a href="#" class="minimal-player-play-button">
	<i class="minimal-player-icon minimal-player-play"></i><i class="minimal-player-icon minimal-player-pause"></i>
	</a>
	<audio class="minimal-player-audio" id="minimal-player-audio-<?php echo absint( $rand ); ?>" src="<?php echo esc_url( $audio_meta ); ?> "></audio>
	<?php
}
/* Output player in loop */
add_action( 'phase_product_minimal_player', 'phase_minimal_player' );

/**
 * Overwrite release button
 */
function phase_release_buttons( $html ) {

	$meta = wd_get_meta();
	$release_itunes = $meta['itunes'];
	$release_google_play = $meta['google_play'];
	$release_amazon = $meta['amazon'];
	$release_spotify = $meta['spotify'];
	$release_buy = $meta['buy'];
	$release_free = $meta['free'];

	$product_id = get_post_meta( get_the_ID(), '_post_wc_product_id', true );

	ob_start();
	?>
	<span class="wolf-release-buttons">

		<?php if ( $release_free ) : ?>
		<span class="wolf-release-button">
			<a class="wolf-release-free" href="<?php echo esc_url( $release_free ); ?>"><?php esc_html_e( 'Free Download', 'phase' ); ?></a>
		</span>
		<?php else : ?>
			<?php if ( $release_spotify ) : ?>
			<span class="wolf-release-button">
				<a target="_blank" title="<?php printf( esc_html__( 'Listen on %s', 'phase' ), 'Spotify' ); ?>" class="wolf-release-spotify <?php echo apply_filters( 'phase_release_button_class', 'button' ); ?>" href="<?php echo esc_url( $release_spotify ); ?>"><?php esc_html_e( 'Spotify', 'phase' ); ?></a>
			</span>
			<?php endif; ?>
			<?php if ( $release_itunes ) : ?>
			<span class="wolf-release-button">
				<a target="_blank" title="<?php printf( esc_html__( 'Buy on %s', 'phase' ), 'iTunes' ); ?>" class="wolf-release-itunes <?php echo apply_filters( 'phase_release_button_class', 'button' ); ?>" href="<?php echo esc_url( $release_itunes ); ?>"><?php esc_html_e( 'iTunes', 'phase' ); ?></a>
			</span>
			<?php endif; ?>
			<?php if ( $release_amazon ) : ?>
			<span class="wolf-release-button">
				<a target="_blank" title="<?php printf( esc_html__( 'Buy on %s', 'phase' ), 'amazon' ); ?>" class="wolf-release-amazon <?php echo apply_filters( 'phase_release_button_class', 'button' ); ?>" href="<?php echo esc_url( $release_amazon ); ?>"><?php esc_html_e( 'Amazon', 'phase' ); ?></a>
			</span>
			<?php endif; ?>
			<?php if ( $release_google_play ) : ?>
			<span class="wolf-release-button">
				<a target="_blank" title="<?php printf( esc_html__( 'Buy on %s', 'phase' ), 'Google Play' ); ?>" class="wolf-release-google_play <?php echo apply_filters( 'phase_release_button_class', 'button' ); ?>" href="<?php echo esc_url( $release_google_play ); ?>"><?php esc_html_e( 'Google Play', 'phase' ); ?></a>
			</span>
			<?php endif; ?>
			<?php if ( $release_buy ) : ?>
			<span class="wolf-release-button">
				<a target="_blank" title="<?php esc_html_e( 'Buy Now', 'phase' ); ?>" class="wolf-release-buy <?php echo apply_filters( 'phase_release_button_class', 'button' ); ?>" href="<?php echo esc_url( $release_buy ); ?>"><?php esc_html_e( 'Buy', 'phase' ); ?></a>
			</span>
			<?php endif; ?>
			<?php if ( $product_id ) : ?>
				<span class="wolf-release-button">
					<?php echo phase_add_to_cart( $product_id, 'wolf-release-add-to-cart ' . apply_filters( 'phase_release_button_class', 'button' ), '<span class="wolf-release-add-to-cart-button-title" title="' . esc_html__( 'Add to cart', 'phase' ) . '"></span>' ); ?>
				</span>
			<?php endif; ?>
		<?php endif; ?>
	</span><!-- .wolf-release-buttons -->
	<?php
	$html = ob_get_clean();

	return $html;
}
add_filter( 'wolf_discography_release_buttons', 'phase_release_buttons' );

if ( ! function_exists( 'phase_gallery_meta' ) ) {
	/**
	 * Gallery meta
	 */
	function phase_gallery_meta() {

		?>
		<a href="#" data-gallery-params="<?php echo esc_js( json_encode( phase_get_gallery_params() ) ); ?>" class="gallery-quickview" title="<?php esc_html_e( 'Quickview', 'phase' ); ?>">
		<?php
			/**
			 * Photo count
			 */
			printf( esc_html__( '%d photos', 'phase' ), phase_get_first_gallery_image_count() );
		?></a><?php if ( get_the_term_list( get_the_ID(), 'gallery_type', '', ' / ', '' ) ) { ?><span class="gallery-meta-separator">&mdash;</span><?php
				/**
				 * Gallery taxonomy
				 */
				echo get_the_term_list( get_the_ID(), 'gallery_type', '', ' / ', '' );

		}
	}
}

/*----------------------------------------------------------------------------------

	Playlist function

--------------------------------------------------------------------------------------*/

/**
 * Can we display a player?
 *
 * @return bool
 */
function phase_sticky_playlist_id() {
	if ( is_page() && get_post_meta( get_the_ID(), '_post_sticky_playlist_id', true ) ) {
		$playlist_id = get_post_meta( get_the_ID(), '_post_sticky_playlist_id', true );

		if ( $playlist_id && 'none' !== $playlist_id ) {
			return $playlist_id;
		}
	}
}

/**
 * Add body classes
 *
 * @param  array $classes
 * @return array
 */
function phase_sticky_player_body_class( $classes ) {

	if ( phase_sticky_playlist_id() ) {
		$classes[] = 'is-wpm-bar-player';
	}

	return $classes;
}
add_filter( 'body_class', 'phase_sticky_player_body_class' );


/**
 * Output bottom bar holder
 *
 * @param  array $classes
 * @return array
 */
function phase_output_sticky_playlist_holder() {

	if ( phase_sticky_playlist_id() ) {
		echo '<div class="wpm-bar-holder"></div>';
	}
}
add_action( 'wp_footer', 'phase_output_sticky_playlist_holder' );

/**
 * Output bottom bar player
 */
function phase_output_sticky_playlist() {

	if ( phase_sticky_playlist_id() ) {

		$playlist_id = phase_sticky_playlist_id();
		$skin = get_post_meta( get_the_ID(), '_post_sticky_playlist_skin', true );

		$attrs = array(
			'show_tracklist' => false,
			'is_sticky_player' => true,
		);

		if ( $skin ) {
			$attrs['theme'] = $skin;
		}

		if ( function_exists( 'wpm_playlist' ) ) {
			wpm_playlist( $playlist_id, $attrs );
		}
	}
}
add_action( 'phase_body_start', 'phase_output_sticky_playlist' );